campus

package
v1.18.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 3, 2026 License: BSD-3-Clause Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the campus type in the database.
	Label = "campus"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldNameFold holds the string denoting the name_fold field in the database.
	FieldNameFold = "name_fold"
	// FieldOrgID holds the string denoting the org_id field in the database.
	FieldOrgID = "org_id"
	// FieldAka holds the string denoting the aka field in the database.
	FieldAka = "aka"
	// FieldCity holds the string denoting the city field in the database.
	FieldCity = "city"
	// FieldCountry holds the string denoting the country field in the database.
	FieldCountry = "country"
	FieldLogo = "logo"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldNameLong holds the string denoting the name_long field in the database.
	FieldNameLong = "name_long"
	// FieldNotes holds the string denoting the notes field in the database.
	FieldNotes = "notes"
	// FieldSocialMedia holds the string denoting the social_media field in the database.
	FieldSocialMedia = "social_media"
	// FieldState holds the string denoting the state field in the database.
	FieldState = "state"
	// FieldWebsite holds the string denoting the website field in the database.
	FieldWebsite = "website"
	// FieldZipcode holds the string denoting the zipcode field in the database.
	FieldZipcode = "zipcode"
	// FieldOrgName holds the string denoting the org_name field in the database.
	FieldOrgName = "org_name"
	// FieldCreated holds the string denoting the created field in the database.
	FieldCreated = "created"
	// FieldUpdated holds the string denoting the updated field in the database.
	FieldUpdated = "updated"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// EdgeFacilities holds the string denoting the facilities edge name in mutations.
	EdgeFacilities = "facilities"
	// EdgeOrganization holds the string denoting the organization edge name in mutations.
	EdgeOrganization = "organization"
	// Table holds the table name of the campus in the database.
	Table = "campuses"
	// FacilitiesTable is the table that holds the facilities relation/edge.
	FacilitiesTable = "facilities"
	// FacilitiesInverseTable is the table name for the Facility entity.
	// It exists in this package in order to avoid circular dependency with the "facility" package.
	FacilitiesInverseTable = "facilities"
	// FacilitiesColumn is the table column denoting the facilities relation/edge.
	FacilitiesColumn = "campus_id"
	// OrganizationTable is the table that holds the organization relation/edge.
	OrganizationTable = "campuses"
	// OrganizationInverseTable is the table name for the Organization entity.
	// It exists in this package in order to avoid circular dependency with the "organization" package.
	OrganizationInverseTable = "organizations"
	// OrganizationColumn is the table column denoting the organization relation/edge.
	OrganizationColumn = "org_id"
)

Variables

var (
	// DefaultNameFold holds the default value on creation for the "name_fold" field.
	DefaultNameFold string
	// DefaultCity holds the default value on creation for the "city" field.
	DefaultCity string
	// DefaultCountry holds the default value on creation for the "country" field.
	DefaultCountry string
	// DefaultNotes holds the default value on creation for the "notes" field.
	DefaultNotes string
	// DefaultState holds the default value on creation for the "state" field.
	DefaultState string
	// DefaultWebsite holds the default value on creation for the "website" field.
	DefaultWebsite string
	// DefaultZipcode holds the default value on creation for the "zipcode" field.
	DefaultZipcode string
	// DefaultOrgName holds the default value on creation for the "org_name" field.
	DefaultOrgName string
	// DefaultStatus holds the default value on creation for the "status" field.
	DefaultStatus string
	// IDValidator is a validator for the "id" field. It is called by the builders before save.
	IDValidator func(int) error
)

Columns holds all SQL columns for campus fields.

Functions

func Aka

func Aka(v string) predicate.Campus

Aka applies equality check predicate on the "aka" field. It's identical to AkaEQ.

func AkaContains

func AkaContains(v string) predicate.Campus

AkaContains applies the Contains predicate on the "aka" field.

func AkaContainsFold

func AkaContainsFold(v string) predicate.Campus

AkaContainsFold applies the ContainsFold predicate on the "aka" field.

func AkaEQ

func AkaEQ(v string) predicate.Campus

AkaEQ applies the EQ predicate on the "aka" field.

func AkaEqualFold

func AkaEqualFold(v string) predicate.Campus

AkaEqualFold applies the EqualFold predicate on the "aka" field.

func AkaGT

func AkaGT(v string) predicate.Campus

AkaGT applies the GT predicate on the "aka" field.

func AkaGTE

func AkaGTE(v string) predicate.Campus

AkaGTE applies the GTE predicate on the "aka" field.

func AkaHasPrefix

func AkaHasPrefix(v string) predicate.Campus

AkaHasPrefix applies the HasPrefix predicate on the "aka" field.

func AkaHasSuffix

func AkaHasSuffix(v string) predicate.Campus

AkaHasSuffix applies the HasSuffix predicate on the "aka" field.

func AkaIn

func AkaIn(vs ...string) predicate.Campus

AkaIn applies the In predicate on the "aka" field.

func AkaIsNil

func AkaIsNil() predicate.Campus

AkaIsNil applies the IsNil predicate on the "aka" field.

func AkaLT

func AkaLT(v string) predicate.Campus

AkaLT applies the LT predicate on the "aka" field.

func AkaLTE

func AkaLTE(v string) predicate.Campus

AkaLTE applies the LTE predicate on the "aka" field.

func AkaNEQ

func AkaNEQ(v string) predicate.Campus

AkaNEQ applies the NEQ predicate on the "aka" field.

func AkaNotIn

func AkaNotIn(vs ...string) predicate.Campus

AkaNotIn applies the NotIn predicate on the "aka" field.

func AkaNotNil

func AkaNotNil() predicate.Campus

AkaNotNil applies the NotNil predicate on the "aka" field.

func And

func And(predicates ...predicate.Campus) predicate.Campus

And groups predicates with the AND operator between them.

func City

func City(v string) predicate.Campus

City applies equality check predicate on the "city" field. It's identical to CityEQ.

func CityContains

func CityContains(v string) predicate.Campus

CityContains applies the Contains predicate on the "city" field.

func CityContainsFold

func CityContainsFold(v string) predicate.Campus

CityContainsFold applies the ContainsFold predicate on the "city" field.

func CityEQ

func CityEQ(v string) predicate.Campus

CityEQ applies the EQ predicate on the "city" field.

func CityEqualFold

func CityEqualFold(v string) predicate.Campus

CityEqualFold applies the EqualFold predicate on the "city" field.

func CityGT

func CityGT(v string) predicate.Campus

CityGT applies the GT predicate on the "city" field.

func CityGTE

func CityGTE(v string) predicate.Campus

CityGTE applies the GTE predicate on the "city" field.

func CityHasPrefix

func CityHasPrefix(v string) predicate.Campus

CityHasPrefix applies the HasPrefix predicate on the "city" field.

func CityHasSuffix

func CityHasSuffix(v string) predicate.Campus

CityHasSuffix applies the HasSuffix predicate on the "city" field.

func CityIn

func CityIn(vs ...string) predicate.Campus

CityIn applies the In predicate on the "city" field.

func CityIsNil

func CityIsNil() predicate.Campus

CityIsNil applies the IsNil predicate on the "city" field.

func CityLT

func CityLT(v string) predicate.Campus

CityLT applies the LT predicate on the "city" field.

func CityLTE

func CityLTE(v string) predicate.Campus

CityLTE applies the LTE predicate on the "city" field.

func CityNEQ

func CityNEQ(v string) predicate.Campus

CityNEQ applies the NEQ predicate on the "city" field.

func CityNotIn

func CityNotIn(vs ...string) predicate.Campus

CityNotIn applies the NotIn predicate on the "city" field.

func CityNotNil

func CityNotNil() predicate.Campus

CityNotNil applies the NotNil predicate on the "city" field.

func Country

func Country(v string) predicate.Campus

Country applies equality check predicate on the "country" field. It's identical to CountryEQ.

func CountryContains

func CountryContains(v string) predicate.Campus

CountryContains applies the Contains predicate on the "country" field.

func CountryContainsFold

func CountryContainsFold(v string) predicate.Campus

CountryContainsFold applies the ContainsFold predicate on the "country" field.

func CountryEQ

func CountryEQ(v string) predicate.Campus

CountryEQ applies the EQ predicate on the "country" field.

func CountryEqualFold

func CountryEqualFold(v string) predicate.Campus

CountryEqualFold applies the EqualFold predicate on the "country" field.

func CountryGT

func CountryGT(v string) predicate.Campus

CountryGT applies the GT predicate on the "country" field.

func CountryGTE

func CountryGTE(v string) predicate.Campus

CountryGTE applies the GTE predicate on the "country" field.

func CountryHasPrefix

func CountryHasPrefix(v string) predicate.Campus

CountryHasPrefix applies the HasPrefix predicate on the "country" field.

func CountryHasSuffix

func CountryHasSuffix(v string) predicate.Campus

CountryHasSuffix applies the HasSuffix predicate on the "country" field.

func CountryIn

func CountryIn(vs ...string) predicate.Campus

CountryIn applies the In predicate on the "country" field.

func CountryIsNil

func CountryIsNil() predicate.Campus

CountryIsNil applies the IsNil predicate on the "country" field.

func CountryLT

func CountryLT(v string) predicate.Campus

CountryLT applies the LT predicate on the "country" field.

func CountryLTE

func CountryLTE(v string) predicate.Campus

CountryLTE applies the LTE predicate on the "country" field.

func CountryNEQ

func CountryNEQ(v string) predicate.Campus

CountryNEQ applies the NEQ predicate on the "country" field.

func CountryNotIn

func CountryNotIn(vs ...string) predicate.Campus

CountryNotIn applies the NotIn predicate on the "country" field.

func CountryNotNil

func CountryNotNil() predicate.Campus

CountryNotNil applies the NotNil predicate on the "country" field.

func Created

func Created(v time.Time) predicate.Campus

Created applies equality check predicate on the "created" field. It's identical to CreatedEQ.

func CreatedEQ

func CreatedEQ(v time.Time) predicate.Campus

CreatedEQ applies the EQ predicate on the "created" field.

func CreatedGT

func CreatedGT(v time.Time) predicate.Campus

CreatedGT applies the GT predicate on the "created" field.

func CreatedGTE

func CreatedGTE(v time.Time) predicate.Campus

CreatedGTE applies the GTE predicate on the "created" field.

func CreatedIn

func CreatedIn(vs ...time.Time) predicate.Campus

CreatedIn applies the In predicate on the "created" field.

func CreatedLT

func CreatedLT(v time.Time) predicate.Campus

CreatedLT applies the LT predicate on the "created" field.

func CreatedLTE

func CreatedLTE(v time.Time) predicate.Campus

CreatedLTE applies the LTE predicate on the "created" field.

func CreatedNEQ

func CreatedNEQ(v time.Time) predicate.Campus

CreatedNEQ applies the NEQ predicate on the "created" field.

func CreatedNotIn

func CreatedNotIn(vs ...time.Time) predicate.Campus

CreatedNotIn applies the NotIn predicate on the "created" field.

func HasFacilities

func HasFacilities() predicate.Campus

HasFacilities applies the HasEdge predicate on the "facilities" edge.

func HasFacilitiesWith

func HasFacilitiesWith(preds ...predicate.Facility) predicate.Campus

HasFacilitiesWith applies the HasEdge predicate on the "facilities" edge with a given conditions (other predicates).

func HasOrganization

func HasOrganization() predicate.Campus

HasOrganization applies the HasEdge predicate on the "organization" edge.

func HasOrganizationWith

func HasOrganizationWith(preds ...predicate.Organization) predicate.Campus

HasOrganizationWith applies the HasEdge predicate on the "organization" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.Campus

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Campus

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Campus

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Campus

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Campus

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Campus

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Campus

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Campus

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Campus

IDNotIn applies the NotIn predicate on the ID field.

func Logo(v string) predicate.Campus

Logo applies equality check predicate on the "logo" field. It's identical to LogoEQ.

func LogoContains

func LogoContains(v string) predicate.Campus

LogoContains applies the Contains predicate on the "logo" field.

func LogoContainsFold

func LogoContainsFold(v string) predicate.Campus

LogoContainsFold applies the ContainsFold predicate on the "logo" field.

func LogoEQ

func LogoEQ(v string) predicate.Campus

LogoEQ applies the EQ predicate on the "logo" field.

func LogoEqualFold

func LogoEqualFold(v string) predicate.Campus

LogoEqualFold applies the EqualFold predicate on the "logo" field.

func LogoGT

func LogoGT(v string) predicate.Campus

LogoGT applies the GT predicate on the "logo" field.

func LogoGTE

func LogoGTE(v string) predicate.Campus

LogoGTE applies the GTE predicate on the "logo" field.

func LogoHasPrefix

func LogoHasPrefix(v string) predicate.Campus

LogoHasPrefix applies the HasPrefix predicate on the "logo" field.

func LogoHasSuffix

func LogoHasSuffix(v string) predicate.Campus

LogoHasSuffix applies the HasSuffix predicate on the "logo" field.

func LogoIn

func LogoIn(vs ...string) predicate.Campus

LogoIn applies the In predicate on the "logo" field.

func LogoIsNil

func LogoIsNil() predicate.Campus

LogoIsNil applies the IsNil predicate on the "logo" field.

func LogoLT

func LogoLT(v string) predicate.Campus

LogoLT applies the LT predicate on the "logo" field.

func LogoLTE

func LogoLTE(v string) predicate.Campus

LogoLTE applies the LTE predicate on the "logo" field.

func LogoNEQ

func LogoNEQ(v string) predicate.Campus

LogoNEQ applies the NEQ predicate on the "logo" field.

func LogoNotIn

func LogoNotIn(vs ...string) predicate.Campus

LogoNotIn applies the NotIn predicate on the "logo" field.

func LogoNotNil

func LogoNotNil() predicate.Campus

LogoNotNil applies the NotNil predicate on the "logo" field.

func Name

func Name(v string) predicate.Campus

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Campus

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Campus

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Campus

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Campus

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameFold added in v1.16.0

func NameFold(v string) predicate.Campus

NameFold applies equality check predicate on the "name_fold" field. It's identical to NameFoldEQ.

func NameFoldContains added in v1.16.0

func NameFoldContains(v string) predicate.Campus

NameFoldContains applies the Contains predicate on the "name_fold" field.

func NameFoldContainsFold added in v1.16.0

func NameFoldContainsFold(v string) predicate.Campus

NameFoldContainsFold applies the ContainsFold predicate on the "name_fold" field.

func NameFoldEQ added in v1.16.0

func NameFoldEQ(v string) predicate.Campus

NameFoldEQ applies the EQ predicate on the "name_fold" field.

func NameFoldEqualFold added in v1.16.0

func NameFoldEqualFold(v string) predicate.Campus

NameFoldEqualFold applies the EqualFold predicate on the "name_fold" field.

func NameFoldGT added in v1.16.0

func NameFoldGT(v string) predicate.Campus

NameFoldGT applies the GT predicate on the "name_fold" field.

func NameFoldGTE added in v1.16.0

func NameFoldGTE(v string) predicate.Campus

NameFoldGTE applies the GTE predicate on the "name_fold" field.

func NameFoldHasPrefix added in v1.16.0

func NameFoldHasPrefix(v string) predicate.Campus

NameFoldHasPrefix applies the HasPrefix predicate on the "name_fold" field.

func NameFoldHasSuffix added in v1.16.0

func NameFoldHasSuffix(v string) predicate.Campus

NameFoldHasSuffix applies the HasSuffix predicate on the "name_fold" field.

func NameFoldIn added in v1.16.0

func NameFoldIn(vs ...string) predicate.Campus

NameFoldIn applies the In predicate on the "name_fold" field.

func NameFoldIsNil added in v1.16.0

func NameFoldIsNil() predicate.Campus

NameFoldIsNil applies the IsNil predicate on the "name_fold" field.

func NameFoldLT added in v1.16.0

func NameFoldLT(v string) predicate.Campus

NameFoldLT applies the LT predicate on the "name_fold" field.

func NameFoldLTE added in v1.16.0

func NameFoldLTE(v string) predicate.Campus

NameFoldLTE applies the LTE predicate on the "name_fold" field.

func NameFoldNEQ added in v1.16.0

func NameFoldNEQ(v string) predicate.Campus

NameFoldNEQ applies the NEQ predicate on the "name_fold" field.

func NameFoldNotIn added in v1.16.0

func NameFoldNotIn(vs ...string) predicate.Campus

NameFoldNotIn applies the NotIn predicate on the "name_fold" field.

func NameFoldNotNil added in v1.16.0

func NameFoldNotNil() predicate.Campus

NameFoldNotNil applies the NotNil predicate on the "name_fold" field.

func NameGT

func NameGT(v string) predicate.Campus

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Campus

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Campus

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Campus

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Campus

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Campus

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Campus

NameLTE applies the LTE predicate on the "name" field.

func NameLong

func NameLong(v string) predicate.Campus

NameLong applies equality check predicate on the "name_long" field. It's identical to NameLongEQ.

func NameLongContains

func NameLongContains(v string) predicate.Campus

NameLongContains applies the Contains predicate on the "name_long" field.

func NameLongContainsFold

func NameLongContainsFold(v string) predicate.Campus

NameLongContainsFold applies the ContainsFold predicate on the "name_long" field.

func NameLongEQ

func NameLongEQ(v string) predicate.Campus

NameLongEQ applies the EQ predicate on the "name_long" field.

func NameLongEqualFold

func NameLongEqualFold(v string) predicate.Campus

NameLongEqualFold applies the EqualFold predicate on the "name_long" field.

func NameLongGT

func NameLongGT(v string) predicate.Campus

NameLongGT applies the GT predicate on the "name_long" field.

func NameLongGTE

func NameLongGTE(v string) predicate.Campus

NameLongGTE applies the GTE predicate on the "name_long" field.

func NameLongHasPrefix

func NameLongHasPrefix(v string) predicate.Campus

NameLongHasPrefix applies the HasPrefix predicate on the "name_long" field.

func NameLongHasSuffix

func NameLongHasSuffix(v string) predicate.Campus

NameLongHasSuffix applies the HasSuffix predicate on the "name_long" field.

func NameLongIn

func NameLongIn(vs ...string) predicate.Campus

NameLongIn applies the In predicate on the "name_long" field.

func NameLongIsNil

func NameLongIsNil() predicate.Campus

NameLongIsNil applies the IsNil predicate on the "name_long" field.

func NameLongLT

func NameLongLT(v string) predicate.Campus

NameLongLT applies the LT predicate on the "name_long" field.

func NameLongLTE

func NameLongLTE(v string) predicate.Campus

NameLongLTE applies the LTE predicate on the "name_long" field.

func NameLongNEQ

func NameLongNEQ(v string) predicate.Campus

NameLongNEQ applies the NEQ predicate on the "name_long" field.

func NameLongNotIn

func NameLongNotIn(vs ...string) predicate.Campus

NameLongNotIn applies the NotIn predicate on the "name_long" field.

func NameLongNotNil

func NameLongNotNil() predicate.Campus

NameLongNotNil applies the NotNil predicate on the "name_long" field.

func NameNEQ

func NameNEQ(v string) predicate.Campus

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Campus

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Notes

func Notes(v string) predicate.Campus

Notes applies equality check predicate on the "notes" field. It's identical to NotesEQ.

func NotesContains

func NotesContains(v string) predicate.Campus

NotesContains applies the Contains predicate on the "notes" field.

func NotesContainsFold

func NotesContainsFold(v string) predicate.Campus

NotesContainsFold applies the ContainsFold predicate on the "notes" field.

func NotesEQ

func NotesEQ(v string) predicate.Campus

NotesEQ applies the EQ predicate on the "notes" field.

func NotesEqualFold

func NotesEqualFold(v string) predicate.Campus

NotesEqualFold applies the EqualFold predicate on the "notes" field.

func NotesGT

func NotesGT(v string) predicate.Campus

NotesGT applies the GT predicate on the "notes" field.

func NotesGTE

func NotesGTE(v string) predicate.Campus

NotesGTE applies the GTE predicate on the "notes" field.

func NotesHasPrefix

func NotesHasPrefix(v string) predicate.Campus

NotesHasPrefix applies the HasPrefix predicate on the "notes" field.

func NotesHasSuffix

func NotesHasSuffix(v string) predicate.Campus

NotesHasSuffix applies the HasSuffix predicate on the "notes" field.

func NotesIn

func NotesIn(vs ...string) predicate.Campus

NotesIn applies the In predicate on the "notes" field.

func NotesIsNil

func NotesIsNil() predicate.Campus

NotesIsNil applies the IsNil predicate on the "notes" field.

func NotesLT

func NotesLT(v string) predicate.Campus

NotesLT applies the LT predicate on the "notes" field.

func NotesLTE

func NotesLTE(v string) predicate.Campus

NotesLTE applies the LTE predicate on the "notes" field.

func NotesNEQ

func NotesNEQ(v string) predicate.Campus

NotesNEQ applies the NEQ predicate on the "notes" field.

func NotesNotIn

func NotesNotIn(vs ...string) predicate.Campus

NotesNotIn applies the NotIn predicate on the "notes" field.

func NotesNotNil

func NotesNotNil() predicate.Campus

NotesNotNil applies the NotNil predicate on the "notes" field.

func Or

func Or(predicates ...predicate.Campus) predicate.Campus

Or groups predicates with the OR operator between them.

func OrgID

func OrgID(v int) predicate.Campus

OrgID applies equality check predicate on the "org_id" field. It's identical to OrgIDEQ.

func OrgIDEQ

func OrgIDEQ(v int) predicate.Campus

OrgIDEQ applies the EQ predicate on the "org_id" field.

func OrgIDIn

func OrgIDIn(vs ...int) predicate.Campus

OrgIDIn applies the In predicate on the "org_id" field.

func OrgIDIsNil

func OrgIDIsNil() predicate.Campus

OrgIDIsNil applies the IsNil predicate on the "org_id" field.

func OrgIDNEQ

func OrgIDNEQ(v int) predicate.Campus

OrgIDNEQ applies the NEQ predicate on the "org_id" field.

func OrgIDNotIn

func OrgIDNotIn(vs ...int) predicate.Campus

OrgIDNotIn applies the NotIn predicate on the "org_id" field.

func OrgIDNotNil

func OrgIDNotNil() predicate.Campus

OrgIDNotNil applies the NotNil predicate on the "org_id" field.

func OrgName

func OrgName(v string) predicate.Campus

OrgName applies equality check predicate on the "org_name" field. It's identical to OrgNameEQ.

func OrgNameContains

func OrgNameContains(v string) predicate.Campus

OrgNameContains applies the Contains predicate on the "org_name" field.

func OrgNameContainsFold

func OrgNameContainsFold(v string) predicate.Campus

OrgNameContainsFold applies the ContainsFold predicate on the "org_name" field.

func OrgNameEQ

func OrgNameEQ(v string) predicate.Campus

OrgNameEQ applies the EQ predicate on the "org_name" field.

func OrgNameEqualFold

func OrgNameEqualFold(v string) predicate.Campus

OrgNameEqualFold applies the EqualFold predicate on the "org_name" field.

func OrgNameGT

func OrgNameGT(v string) predicate.Campus

OrgNameGT applies the GT predicate on the "org_name" field.

func OrgNameGTE

func OrgNameGTE(v string) predicate.Campus

OrgNameGTE applies the GTE predicate on the "org_name" field.

func OrgNameHasPrefix

func OrgNameHasPrefix(v string) predicate.Campus

OrgNameHasPrefix applies the HasPrefix predicate on the "org_name" field.

func OrgNameHasSuffix

func OrgNameHasSuffix(v string) predicate.Campus

OrgNameHasSuffix applies the HasSuffix predicate on the "org_name" field.

func OrgNameIn

func OrgNameIn(vs ...string) predicate.Campus

OrgNameIn applies the In predicate on the "org_name" field.

func OrgNameIsNil

func OrgNameIsNil() predicate.Campus

OrgNameIsNil applies the IsNil predicate on the "org_name" field.

func OrgNameLT

func OrgNameLT(v string) predicate.Campus

OrgNameLT applies the LT predicate on the "org_name" field.

func OrgNameLTE

func OrgNameLTE(v string) predicate.Campus

OrgNameLTE applies the LTE predicate on the "org_name" field.

func OrgNameNEQ

func OrgNameNEQ(v string) predicate.Campus

OrgNameNEQ applies the NEQ predicate on the "org_name" field.

func OrgNameNotIn

func OrgNameNotIn(vs ...string) predicate.Campus

OrgNameNotIn applies the NotIn predicate on the "org_name" field.

func OrgNameNotNil

func OrgNameNotNil() predicate.Campus

OrgNameNotNil applies the NotNil predicate on the "org_name" field.

func SocialMediaIsNil

func SocialMediaIsNil() predicate.Campus

SocialMediaIsNil applies the IsNil predicate on the "social_media" field.

func SocialMediaNotNil

func SocialMediaNotNil() predicate.Campus

SocialMediaNotNil applies the NotNil predicate on the "social_media" field.

func State

func State(v string) predicate.Campus

State applies equality check predicate on the "state" field. It's identical to StateEQ.

func StateContains

func StateContains(v string) predicate.Campus

StateContains applies the Contains predicate on the "state" field.

func StateContainsFold

func StateContainsFold(v string) predicate.Campus

StateContainsFold applies the ContainsFold predicate on the "state" field.

func StateEQ

func StateEQ(v string) predicate.Campus

StateEQ applies the EQ predicate on the "state" field.

func StateEqualFold

func StateEqualFold(v string) predicate.Campus

StateEqualFold applies the EqualFold predicate on the "state" field.

func StateGT

func StateGT(v string) predicate.Campus

StateGT applies the GT predicate on the "state" field.

func StateGTE

func StateGTE(v string) predicate.Campus

StateGTE applies the GTE predicate on the "state" field.

func StateHasPrefix

func StateHasPrefix(v string) predicate.Campus

StateHasPrefix applies the HasPrefix predicate on the "state" field.

func StateHasSuffix

func StateHasSuffix(v string) predicate.Campus

StateHasSuffix applies the HasSuffix predicate on the "state" field.

func StateIn

func StateIn(vs ...string) predicate.Campus

StateIn applies the In predicate on the "state" field.

func StateIsNil

func StateIsNil() predicate.Campus

StateIsNil applies the IsNil predicate on the "state" field.

func StateLT

func StateLT(v string) predicate.Campus

StateLT applies the LT predicate on the "state" field.

func StateLTE

func StateLTE(v string) predicate.Campus

StateLTE applies the LTE predicate on the "state" field.

func StateNEQ

func StateNEQ(v string) predicate.Campus

StateNEQ applies the NEQ predicate on the "state" field.

func StateNotIn

func StateNotIn(vs ...string) predicate.Campus

StateNotIn applies the NotIn predicate on the "state" field.

func StateNotNil

func StateNotNil() predicate.Campus

StateNotNil applies the NotNil predicate on the "state" field.

func Status

func Status(v string) predicate.Campus

Status applies equality check predicate on the "status" field. It's identical to StatusEQ.

func StatusContains

func StatusContains(v string) predicate.Campus

StatusContains applies the Contains predicate on the "status" field.

func StatusContainsFold

func StatusContainsFold(v string) predicate.Campus

StatusContainsFold applies the ContainsFold predicate on the "status" field.

func StatusEQ

func StatusEQ(v string) predicate.Campus

StatusEQ applies the EQ predicate on the "status" field.

func StatusEqualFold

func StatusEqualFold(v string) predicate.Campus

StatusEqualFold applies the EqualFold predicate on the "status" field.

func StatusGT

func StatusGT(v string) predicate.Campus

StatusGT applies the GT predicate on the "status" field.

func StatusGTE

func StatusGTE(v string) predicate.Campus

StatusGTE applies the GTE predicate on the "status" field.

func StatusHasPrefix

func StatusHasPrefix(v string) predicate.Campus

StatusHasPrefix applies the HasPrefix predicate on the "status" field.

func StatusHasSuffix

func StatusHasSuffix(v string) predicate.Campus

StatusHasSuffix applies the HasSuffix predicate on the "status" field.

func StatusIn

func StatusIn(vs ...string) predicate.Campus

StatusIn applies the In predicate on the "status" field.

func StatusLT

func StatusLT(v string) predicate.Campus

StatusLT applies the LT predicate on the "status" field.

func StatusLTE

func StatusLTE(v string) predicate.Campus

StatusLTE applies the LTE predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v string) predicate.Campus

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...string) predicate.Campus

StatusNotIn applies the NotIn predicate on the "status" field.

func Updated

func Updated(v time.Time) predicate.Campus

Updated applies equality check predicate on the "updated" field. It's identical to UpdatedEQ.

func UpdatedEQ

func UpdatedEQ(v time.Time) predicate.Campus

UpdatedEQ applies the EQ predicate on the "updated" field.

func UpdatedGT

func UpdatedGT(v time.Time) predicate.Campus

UpdatedGT applies the GT predicate on the "updated" field.

func UpdatedGTE

func UpdatedGTE(v time.Time) predicate.Campus

UpdatedGTE applies the GTE predicate on the "updated" field.

func UpdatedIn

func UpdatedIn(vs ...time.Time) predicate.Campus

UpdatedIn applies the In predicate on the "updated" field.

func UpdatedLT

func UpdatedLT(v time.Time) predicate.Campus

UpdatedLT applies the LT predicate on the "updated" field.

func UpdatedLTE

func UpdatedLTE(v time.Time) predicate.Campus

UpdatedLTE applies the LTE predicate on the "updated" field.

func UpdatedNEQ

func UpdatedNEQ(v time.Time) predicate.Campus

UpdatedNEQ applies the NEQ predicate on the "updated" field.

func UpdatedNotIn

func UpdatedNotIn(vs ...time.Time) predicate.Campus

UpdatedNotIn applies the NotIn predicate on the "updated" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func Website

func Website(v string) predicate.Campus

Website applies equality check predicate on the "website" field. It's identical to WebsiteEQ.

func WebsiteContains

func WebsiteContains(v string) predicate.Campus

WebsiteContains applies the Contains predicate on the "website" field.

func WebsiteContainsFold

func WebsiteContainsFold(v string) predicate.Campus

WebsiteContainsFold applies the ContainsFold predicate on the "website" field.

func WebsiteEQ

func WebsiteEQ(v string) predicate.Campus

WebsiteEQ applies the EQ predicate on the "website" field.

func WebsiteEqualFold

func WebsiteEqualFold(v string) predicate.Campus

WebsiteEqualFold applies the EqualFold predicate on the "website" field.

func WebsiteGT

func WebsiteGT(v string) predicate.Campus

WebsiteGT applies the GT predicate on the "website" field.

func WebsiteGTE

func WebsiteGTE(v string) predicate.Campus

WebsiteGTE applies the GTE predicate on the "website" field.

func WebsiteHasPrefix

func WebsiteHasPrefix(v string) predicate.Campus

WebsiteHasPrefix applies the HasPrefix predicate on the "website" field.

func WebsiteHasSuffix

func WebsiteHasSuffix(v string) predicate.Campus

WebsiteHasSuffix applies the HasSuffix predicate on the "website" field.

func WebsiteIn

func WebsiteIn(vs ...string) predicate.Campus

WebsiteIn applies the In predicate on the "website" field.

func WebsiteIsNil

func WebsiteIsNil() predicate.Campus

WebsiteIsNil applies the IsNil predicate on the "website" field.

func WebsiteLT

func WebsiteLT(v string) predicate.Campus

WebsiteLT applies the LT predicate on the "website" field.

func WebsiteLTE

func WebsiteLTE(v string) predicate.Campus

WebsiteLTE applies the LTE predicate on the "website" field.

func WebsiteNEQ

func WebsiteNEQ(v string) predicate.Campus

WebsiteNEQ applies the NEQ predicate on the "website" field.

func WebsiteNotIn

func WebsiteNotIn(vs ...string) predicate.Campus

WebsiteNotIn applies the NotIn predicate on the "website" field.

func WebsiteNotNil

func WebsiteNotNil() predicate.Campus

WebsiteNotNil applies the NotNil predicate on the "website" field.

func Zipcode

func Zipcode(v string) predicate.Campus

Zipcode applies equality check predicate on the "zipcode" field. It's identical to ZipcodeEQ.

func ZipcodeContains

func ZipcodeContains(v string) predicate.Campus

ZipcodeContains applies the Contains predicate on the "zipcode" field.

func ZipcodeContainsFold

func ZipcodeContainsFold(v string) predicate.Campus

ZipcodeContainsFold applies the ContainsFold predicate on the "zipcode" field.

func ZipcodeEQ

func ZipcodeEQ(v string) predicate.Campus

ZipcodeEQ applies the EQ predicate on the "zipcode" field.

func ZipcodeEqualFold

func ZipcodeEqualFold(v string) predicate.Campus

ZipcodeEqualFold applies the EqualFold predicate on the "zipcode" field.

func ZipcodeGT

func ZipcodeGT(v string) predicate.Campus

ZipcodeGT applies the GT predicate on the "zipcode" field.

func ZipcodeGTE

func ZipcodeGTE(v string) predicate.Campus

ZipcodeGTE applies the GTE predicate on the "zipcode" field.

func ZipcodeHasPrefix

func ZipcodeHasPrefix(v string) predicate.Campus

ZipcodeHasPrefix applies the HasPrefix predicate on the "zipcode" field.

func ZipcodeHasSuffix

func ZipcodeHasSuffix(v string) predicate.Campus

ZipcodeHasSuffix applies the HasSuffix predicate on the "zipcode" field.

func ZipcodeIn

func ZipcodeIn(vs ...string) predicate.Campus

ZipcodeIn applies the In predicate on the "zipcode" field.

func ZipcodeIsNil

func ZipcodeIsNil() predicate.Campus

ZipcodeIsNil applies the IsNil predicate on the "zipcode" field.

func ZipcodeLT

func ZipcodeLT(v string) predicate.Campus

ZipcodeLT applies the LT predicate on the "zipcode" field.

func ZipcodeLTE

func ZipcodeLTE(v string) predicate.Campus

ZipcodeLTE applies the LTE predicate on the "zipcode" field.

func ZipcodeNEQ

func ZipcodeNEQ(v string) predicate.Campus

ZipcodeNEQ applies the NEQ predicate on the "zipcode" field.

func ZipcodeNotIn

func ZipcodeNotIn(vs ...string) predicate.Campus

ZipcodeNotIn applies the NotIn predicate on the "zipcode" field.

func ZipcodeNotNil

func ZipcodeNotNil() predicate.Campus

ZipcodeNotNil applies the NotNil predicate on the "zipcode" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Campus queries.

func ByAka

func ByAka(opts ...sql.OrderTermOption) OrderOption

ByAka orders the results by the aka field.

func ByCity

func ByCity(opts ...sql.OrderTermOption) OrderOption

ByCity orders the results by the city field.

func ByCountry

func ByCountry(opts ...sql.OrderTermOption) OrderOption

ByCountry orders the results by the country field.

func ByCreated

func ByCreated(opts ...sql.OrderTermOption) OrderOption

ByCreated orders the results by the created field.

func ByFacilities

func ByFacilities(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByFacilities orders the results by facilities terms.

func ByFacilitiesCount

func ByFacilitiesCount(opts ...sql.OrderTermOption) OrderOption

ByFacilitiesCount orders the results by facilities count.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByLogo(opts ...sql.OrderTermOption) OrderOption

ByLogo orders the results by the logo field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByNameFold added in v1.16.0

func ByNameFold(opts ...sql.OrderTermOption) OrderOption

ByNameFold orders the results by the name_fold field.

func ByNameLong

func ByNameLong(opts ...sql.OrderTermOption) OrderOption

ByNameLong orders the results by the name_long field.

func ByNotes

func ByNotes(opts ...sql.OrderTermOption) OrderOption

ByNotes orders the results by the notes field.

func ByOrgID

func ByOrgID(opts ...sql.OrderTermOption) OrderOption

ByOrgID orders the results by the org_id field.

func ByOrgName

func ByOrgName(opts ...sql.OrderTermOption) OrderOption

ByOrgName orders the results by the org_name field.

func ByOrganizationField

func ByOrganizationField(field string, opts ...sql.OrderTermOption) OrderOption

ByOrganizationField orders the results by organization field.

func ByState

func ByState(opts ...sql.OrderTermOption) OrderOption

ByState orders the results by the state field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByUpdated

func ByUpdated(opts ...sql.OrderTermOption) OrderOption

ByUpdated orders the results by the updated field.

func ByWebsite

func ByWebsite(opts ...sql.OrderTermOption) OrderOption

ByWebsite orders the results by the website field.

func ByZipcode

func ByZipcode(opts ...sql.OrderTermOption) OrderOption

ByZipcode orders the results by the zipcode field.

Jump to