carrier

package
v1.18.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 3, 2026 License: BSD-3-Clause Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the carrier type in the database.
	Label = "carrier"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldNameFold holds the string denoting the name_fold field in the database.
	FieldNameFold = "name_fold"
	// FieldAkaFold holds the string denoting the aka_fold field in the database.
	FieldAkaFold = "aka_fold"
	// FieldOrgID holds the string denoting the org_id field in the database.
	FieldOrgID = "org_id"
	// FieldAka holds the string denoting the aka field in the database.
	FieldAka = "aka"
	FieldLogo = "logo"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldNameLong holds the string denoting the name_long field in the database.
	FieldNameLong = "name_long"
	// FieldNotes holds the string denoting the notes field in the database.
	FieldNotes = "notes"
	// FieldSocialMedia holds the string denoting the social_media field in the database.
	FieldSocialMedia = "social_media"
	// FieldWebsite holds the string denoting the website field in the database.
	FieldWebsite = "website"
	// FieldOrgName holds the string denoting the org_name field in the database.
	FieldOrgName = "org_name"
	// FieldFacCount holds the string denoting the fac_count field in the database.
	FieldFacCount = "fac_count"
	// FieldCreated holds the string denoting the created field in the database.
	FieldCreated = "created"
	// FieldUpdated holds the string denoting the updated field in the database.
	FieldUpdated = "updated"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// EdgeCarrierFacilities holds the string denoting the carrier_facilities edge name in mutations.
	EdgeCarrierFacilities = "carrier_facilities"
	// EdgeOrganization holds the string denoting the organization edge name in mutations.
	EdgeOrganization = "organization"
	// Table holds the table name of the carrier in the database.
	Table = "carriers"
	// CarrierFacilitiesTable is the table that holds the carrier_facilities relation/edge.
	CarrierFacilitiesTable = "carrier_facilities"
	// CarrierFacilitiesInverseTable is the table name for the CarrierFacility entity.
	// It exists in this package in order to avoid circular dependency with the "carrierfacility" package.
	CarrierFacilitiesInverseTable = "carrier_facilities"
	// CarrierFacilitiesColumn is the table column denoting the carrier_facilities relation/edge.
	CarrierFacilitiesColumn = "carrier_id"
	// OrganizationTable is the table that holds the organization relation/edge.
	OrganizationTable = "carriers"
	// OrganizationInverseTable is the table name for the Organization entity.
	// It exists in this package in order to avoid circular dependency with the "organization" package.
	OrganizationInverseTable = "organizations"
	// OrganizationColumn is the table column denoting the organization relation/edge.
	OrganizationColumn = "org_id"
)

Variables

var (
	// DefaultNameFold holds the default value on creation for the "name_fold" field.
	DefaultNameFold string
	// DefaultAkaFold holds the default value on creation for the "aka_fold" field.
	DefaultAkaFold string
	// DefaultAka holds the default value on creation for the "aka" field.
	DefaultAka string
	// DefaultNameLong holds the default value on creation for the "name_long" field.
	DefaultNameLong string
	// DefaultNotes holds the default value on creation for the "notes" field.
	DefaultNotes string
	// DefaultWebsite holds the default value on creation for the "website" field.
	DefaultWebsite string
	// DefaultOrgName holds the default value on creation for the "org_name" field.
	DefaultOrgName string
	// DefaultFacCount holds the default value on creation for the "fac_count" field.
	DefaultFacCount int
	// DefaultStatus holds the default value on creation for the "status" field.
	DefaultStatus string
	// IDValidator is a validator for the "id" field. It is called by the builders before save.
	IDValidator func(int) error
)

Columns holds all SQL columns for carrier fields.

Functions

func Aka

func Aka(v string) predicate.Carrier

Aka applies equality check predicate on the "aka" field. It's identical to AkaEQ.

func AkaContains

func AkaContains(v string) predicate.Carrier

AkaContains applies the Contains predicate on the "aka" field.

func AkaContainsFold

func AkaContainsFold(v string) predicate.Carrier

AkaContainsFold applies the ContainsFold predicate on the "aka" field.

func AkaEQ

func AkaEQ(v string) predicate.Carrier

AkaEQ applies the EQ predicate on the "aka" field.

func AkaEqualFold

func AkaEqualFold(v string) predicate.Carrier

AkaEqualFold applies the EqualFold predicate on the "aka" field.

func AkaFold added in v1.16.0

func AkaFold(v string) predicate.Carrier

AkaFold applies equality check predicate on the "aka_fold" field. It's identical to AkaFoldEQ.

func AkaFoldContains added in v1.16.0

func AkaFoldContains(v string) predicate.Carrier

AkaFoldContains applies the Contains predicate on the "aka_fold" field.

func AkaFoldContainsFold added in v1.16.0

func AkaFoldContainsFold(v string) predicate.Carrier

AkaFoldContainsFold applies the ContainsFold predicate on the "aka_fold" field.

func AkaFoldEQ added in v1.16.0

func AkaFoldEQ(v string) predicate.Carrier

AkaFoldEQ applies the EQ predicate on the "aka_fold" field.

func AkaFoldEqualFold added in v1.16.0

func AkaFoldEqualFold(v string) predicate.Carrier

AkaFoldEqualFold applies the EqualFold predicate on the "aka_fold" field.

func AkaFoldGT added in v1.16.0

func AkaFoldGT(v string) predicate.Carrier

AkaFoldGT applies the GT predicate on the "aka_fold" field.

func AkaFoldGTE added in v1.16.0

func AkaFoldGTE(v string) predicate.Carrier

AkaFoldGTE applies the GTE predicate on the "aka_fold" field.

func AkaFoldHasPrefix added in v1.16.0

func AkaFoldHasPrefix(v string) predicate.Carrier

AkaFoldHasPrefix applies the HasPrefix predicate on the "aka_fold" field.

func AkaFoldHasSuffix added in v1.16.0

func AkaFoldHasSuffix(v string) predicate.Carrier

AkaFoldHasSuffix applies the HasSuffix predicate on the "aka_fold" field.

func AkaFoldIn added in v1.16.0

func AkaFoldIn(vs ...string) predicate.Carrier

AkaFoldIn applies the In predicate on the "aka_fold" field.

func AkaFoldIsNil added in v1.16.0

func AkaFoldIsNil() predicate.Carrier

AkaFoldIsNil applies the IsNil predicate on the "aka_fold" field.

func AkaFoldLT added in v1.16.0

func AkaFoldLT(v string) predicate.Carrier

AkaFoldLT applies the LT predicate on the "aka_fold" field.

func AkaFoldLTE added in v1.16.0

func AkaFoldLTE(v string) predicate.Carrier

AkaFoldLTE applies the LTE predicate on the "aka_fold" field.

func AkaFoldNEQ added in v1.16.0

func AkaFoldNEQ(v string) predicate.Carrier

AkaFoldNEQ applies the NEQ predicate on the "aka_fold" field.

func AkaFoldNotIn added in v1.16.0

func AkaFoldNotIn(vs ...string) predicate.Carrier

AkaFoldNotIn applies the NotIn predicate on the "aka_fold" field.

func AkaFoldNotNil added in v1.16.0

func AkaFoldNotNil() predicate.Carrier

AkaFoldNotNil applies the NotNil predicate on the "aka_fold" field.

func AkaGT

func AkaGT(v string) predicate.Carrier

AkaGT applies the GT predicate on the "aka" field.

func AkaGTE

func AkaGTE(v string) predicate.Carrier

AkaGTE applies the GTE predicate on the "aka" field.

func AkaHasPrefix

func AkaHasPrefix(v string) predicate.Carrier

AkaHasPrefix applies the HasPrefix predicate on the "aka" field.

func AkaHasSuffix

func AkaHasSuffix(v string) predicate.Carrier

AkaHasSuffix applies the HasSuffix predicate on the "aka" field.

func AkaIn

func AkaIn(vs ...string) predicate.Carrier

AkaIn applies the In predicate on the "aka" field.

func AkaIsNil

func AkaIsNil() predicate.Carrier

AkaIsNil applies the IsNil predicate on the "aka" field.

func AkaLT

func AkaLT(v string) predicate.Carrier

AkaLT applies the LT predicate on the "aka" field.

func AkaLTE

func AkaLTE(v string) predicate.Carrier

AkaLTE applies the LTE predicate on the "aka" field.

func AkaNEQ

func AkaNEQ(v string) predicate.Carrier

AkaNEQ applies the NEQ predicate on the "aka" field.

func AkaNotIn

func AkaNotIn(vs ...string) predicate.Carrier

AkaNotIn applies the NotIn predicate on the "aka" field.

func AkaNotNil

func AkaNotNil() predicate.Carrier

AkaNotNil applies the NotNil predicate on the "aka" field.

func And

func And(predicates ...predicate.Carrier) predicate.Carrier

And groups predicates with the AND operator between them.

func Created

func Created(v time.Time) predicate.Carrier

Created applies equality check predicate on the "created" field. It's identical to CreatedEQ.

func CreatedEQ

func CreatedEQ(v time.Time) predicate.Carrier

CreatedEQ applies the EQ predicate on the "created" field.

func CreatedGT

func CreatedGT(v time.Time) predicate.Carrier

CreatedGT applies the GT predicate on the "created" field.

func CreatedGTE

func CreatedGTE(v time.Time) predicate.Carrier

CreatedGTE applies the GTE predicate on the "created" field.

func CreatedIn

func CreatedIn(vs ...time.Time) predicate.Carrier

CreatedIn applies the In predicate on the "created" field.

func CreatedLT

func CreatedLT(v time.Time) predicate.Carrier

CreatedLT applies the LT predicate on the "created" field.

func CreatedLTE

func CreatedLTE(v time.Time) predicate.Carrier

CreatedLTE applies the LTE predicate on the "created" field.

func CreatedNEQ

func CreatedNEQ(v time.Time) predicate.Carrier

CreatedNEQ applies the NEQ predicate on the "created" field.

func CreatedNotIn

func CreatedNotIn(vs ...time.Time) predicate.Carrier

CreatedNotIn applies the NotIn predicate on the "created" field.

func FacCount

func FacCount(v int) predicate.Carrier

FacCount applies equality check predicate on the "fac_count" field. It's identical to FacCountEQ.

func FacCountEQ

func FacCountEQ(v int) predicate.Carrier

FacCountEQ applies the EQ predicate on the "fac_count" field.

func FacCountGT

func FacCountGT(v int) predicate.Carrier

FacCountGT applies the GT predicate on the "fac_count" field.

func FacCountGTE

func FacCountGTE(v int) predicate.Carrier

FacCountGTE applies the GTE predicate on the "fac_count" field.

func FacCountIn

func FacCountIn(vs ...int) predicate.Carrier

FacCountIn applies the In predicate on the "fac_count" field.

func FacCountIsNil

func FacCountIsNil() predicate.Carrier

FacCountIsNil applies the IsNil predicate on the "fac_count" field.

func FacCountLT

func FacCountLT(v int) predicate.Carrier

FacCountLT applies the LT predicate on the "fac_count" field.

func FacCountLTE

func FacCountLTE(v int) predicate.Carrier

FacCountLTE applies the LTE predicate on the "fac_count" field.

func FacCountNEQ

func FacCountNEQ(v int) predicate.Carrier

FacCountNEQ applies the NEQ predicate on the "fac_count" field.

func FacCountNotIn

func FacCountNotIn(vs ...int) predicate.Carrier

FacCountNotIn applies the NotIn predicate on the "fac_count" field.

func FacCountNotNil

func FacCountNotNil() predicate.Carrier

FacCountNotNil applies the NotNil predicate on the "fac_count" field.

func HasCarrierFacilities

func HasCarrierFacilities() predicate.Carrier

HasCarrierFacilities applies the HasEdge predicate on the "carrier_facilities" edge.

func HasCarrierFacilitiesWith

func HasCarrierFacilitiesWith(preds ...predicate.CarrierFacility) predicate.Carrier

HasCarrierFacilitiesWith applies the HasEdge predicate on the "carrier_facilities" edge with a given conditions (other predicates).

func HasOrganization

func HasOrganization() predicate.Carrier

HasOrganization applies the HasEdge predicate on the "organization" edge.

func HasOrganizationWith

func HasOrganizationWith(preds ...predicate.Organization) predicate.Carrier

HasOrganizationWith applies the HasEdge predicate on the "organization" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.Carrier

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Carrier

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Carrier

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Carrier

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Carrier

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Carrier

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Carrier

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Carrier

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Carrier

IDNotIn applies the NotIn predicate on the ID field.

func Logo(v string) predicate.Carrier

Logo applies equality check predicate on the "logo" field. It's identical to LogoEQ.

func LogoContains

func LogoContains(v string) predicate.Carrier

LogoContains applies the Contains predicate on the "logo" field.

func LogoContainsFold

func LogoContainsFold(v string) predicate.Carrier

LogoContainsFold applies the ContainsFold predicate on the "logo" field.

func LogoEQ

func LogoEQ(v string) predicate.Carrier

LogoEQ applies the EQ predicate on the "logo" field.

func LogoEqualFold

func LogoEqualFold(v string) predicate.Carrier

LogoEqualFold applies the EqualFold predicate on the "logo" field.

func LogoGT

func LogoGT(v string) predicate.Carrier

LogoGT applies the GT predicate on the "logo" field.

func LogoGTE

func LogoGTE(v string) predicate.Carrier

LogoGTE applies the GTE predicate on the "logo" field.

func LogoHasPrefix

func LogoHasPrefix(v string) predicate.Carrier

LogoHasPrefix applies the HasPrefix predicate on the "logo" field.

func LogoHasSuffix

func LogoHasSuffix(v string) predicate.Carrier

LogoHasSuffix applies the HasSuffix predicate on the "logo" field.

func LogoIn

func LogoIn(vs ...string) predicate.Carrier

LogoIn applies the In predicate on the "logo" field.

func LogoIsNil

func LogoIsNil() predicate.Carrier

LogoIsNil applies the IsNil predicate on the "logo" field.

func LogoLT

func LogoLT(v string) predicate.Carrier

LogoLT applies the LT predicate on the "logo" field.

func LogoLTE

func LogoLTE(v string) predicate.Carrier

LogoLTE applies the LTE predicate on the "logo" field.

func LogoNEQ

func LogoNEQ(v string) predicate.Carrier

LogoNEQ applies the NEQ predicate on the "logo" field.

func LogoNotIn

func LogoNotIn(vs ...string) predicate.Carrier

LogoNotIn applies the NotIn predicate on the "logo" field.

func LogoNotNil

func LogoNotNil() predicate.Carrier

LogoNotNil applies the NotNil predicate on the "logo" field.

func Name

func Name(v string) predicate.Carrier

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Carrier

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Carrier

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Carrier

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Carrier

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameFold added in v1.16.0

func NameFold(v string) predicate.Carrier

NameFold applies equality check predicate on the "name_fold" field. It's identical to NameFoldEQ.

func NameFoldContains added in v1.16.0

func NameFoldContains(v string) predicate.Carrier

NameFoldContains applies the Contains predicate on the "name_fold" field.

func NameFoldContainsFold added in v1.16.0

func NameFoldContainsFold(v string) predicate.Carrier

NameFoldContainsFold applies the ContainsFold predicate on the "name_fold" field.

func NameFoldEQ added in v1.16.0

func NameFoldEQ(v string) predicate.Carrier

NameFoldEQ applies the EQ predicate on the "name_fold" field.

func NameFoldEqualFold added in v1.16.0

func NameFoldEqualFold(v string) predicate.Carrier

NameFoldEqualFold applies the EqualFold predicate on the "name_fold" field.

func NameFoldGT added in v1.16.0

func NameFoldGT(v string) predicate.Carrier

NameFoldGT applies the GT predicate on the "name_fold" field.

func NameFoldGTE added in v1.16.0

func NameFoldGTE(v string) predicate.Carrier

NameFoldGTE applies the GTE predicate on the "name_fold" field.

func NameFoldHasPrefix added in v1.16.0

func NameFoldHasPrefix(v string) predicate.Carrier

NameFoldHasPrefix applies the HasPrefix predicate on the "name_fold" field.

func NameFoldHasSuffix added in v1.16.0

func NameFoldHasSuffix(v string) predicate.Carrier

NameFoldHasSuffix applies the HasSuffix predicate on the "name_fold" field.

func NameFoldIn added in v1.16.0

func NameFoldIn(vs ...string) predicate.Carrier

NameFoldIn applies the In predicate on the "name_fold" field.

func NameFoldIsNil added in v1.16.0

func NameFoldIsNil() predicate.Carrier

NameFoldIsNil applies the IsNil predicate on the "name_fold" field.

func NameFoldLT added in v1.16.0

func NameFoldLT(v string) predicate.Carrier

NameFoldLT applies the LT predicate on the "name_fold" field.

func NameFoldLTE added in v1.16.0

func NameFoldLTE(v string) predicate.Carrier

NameFoldLTE applies the LTE predicate on the "name_fold" field.

func NameFoldNEQ added in v1.16.0

func NameFoldNEQ(v string) predicate.Carrier

NameFoldNEQ applies the NEQ predicate on the "name_fold" field.

func NameFoldNotIn added in v1.16.0

func NameFoldNotIn(vs ...string) predicate.Carrier

NameFoldNotIn applies the NotIn predicate on the "name_fold" field.

func NameFoldNotNil added in v1.16.0

func NameFoldNotNil() predicate.Carrier

NameFoldNotNil applies the NotNil predicate on the "name_fold" field.

func NameGT

func NameGT(v string) predicate.Carrier

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Carrier

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Carrier

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Carrier

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Carrier

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Carrier

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Carrier

NameLTE applies the LTE predicate on the "name" field.

func NameLong

func NameLong(v string) predicate.Carrier

NameLong applies equality check predicate on the "name_long" field. It's identical to NameLongEQ.

func NameLongContains

func NameLongContains(v string) predicate.Carrier

NameLongContains applies the Contains predicate on the "name_long" field.

func NameLongContainsFold

func NameLongContainsFold(v string) predicate.Carrier

NameLongContainsFold applies the ContainsFold predicate on the "name_long" field.

func NameLongEQ

func NameLongEQ(v string) predicate.Carrier

NameLongEQ applies the EQ predicate on the "name_long" field.

func NameLongEqualFold

func NameLongEqualFold(v string) predicate.Carrier

NameLongEqualFold applies the EqualFold predicate on the "name_long" field.

func NameLongGT

func NameLongGT(v string) predicate.Carrier

NameLongGT applies the GT predicate on the "name_long" field.

func NameLongGTE

func NameLongGTE(v string) predicate.Carrier

NameLongGTE applies the GTE predicate on the "name_long" field.

func NameLongHasPrefix

func NameLongHasPrefix(v string) predicate.Carrier

NameLongHasPrefix applies the HasPrefix predicate on the "name_long" field.

func NameLongHasSuffix

func NameLongHasSuffix(v string) predicate.Carrier

NameLongHasSuffix applies the HasSuffix predicate on the "name_long" field.

func NameLongIn

func NameLongIn(vs ...string) predicate.Carrier

NameLongIn applies the In predicate on the "name_long" field.

func NameLongIsNil

func NameLongIsNil() predicate.Carrier

NameLongIsNil applies the IsNil predicate on the "name_long" field.

func NameLongLT

func NameLongLT(v string) predicate.Carrier

NameLongLT applies the LT predicate on the "name_long" field.

func NameLongLTE

func NameLongLTE(v string) predicate.Carrier

NameLongLTE applies the LTE predicate on the "name_long" field.

func NameLongNEQ

func NameLongNEQ(v string) predicate.Carrier

NameLongNEQ applies the NEQ predicate on the "name_long" field.

func NameLongNotIn

func NameLongNotIn(vs ...string) predicate.Carrier

NameLongNotIn applies the NotIn predicate on the "name_long" field.

func NameLongNotNil

func NameLongNotNil() predicate.Carrier

NameLongNotNil applies the NotNil predicate on the "name_long" field.

func NameNEQ

func NameNEQ(v string) predicate.Carrier

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Carrier

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Notes

func Notes(v string) predicate.Carrier

Notes applies equality check predicate on the "notes" field. It's identical to NotesEQ.

func NotesContains

func NotesContains(v string) predicate.Carrier

NotesContains applies the Contains predicate on the "notes" field.

func NotesContainsFold

func NotesContainsFold(v string) predicate.Carrier

NotesContainsFold applies the ContainsFold predicate on the "notes" field.

func NotesEQ

func NotesEQ(v string) predicate.Carrier

NotesEQ applies the EQ predicate on the "notes" field.

func NotesEqualFold

func NotesEqualFold(v string) predicate.Carrier

NotesEqualFold applies the EqualFold predicate on the "notes" field.

func NotesGT

func NotesGT(v string) predicate.Carrier

NotesGT applies the GT predicate on the "notes" field.

func NotesGTE

func NotesGTE(v string) predicate.Carrier

NotesGTE applies the GTE predicate on the "notes" field.

func NotesHasPrefix

func NotesHasPrefix(v string) predicate.Carrier

NotesHasPrefix applies the HasPrefix predicate on the "notes" field.

func NotesHasSuffix

func NotesHasSuffix(v string) predicate.Carrier

NotesHasSuffix applies the HasSuffix predicate on the "notes" field.

func NotesIn

func NotesIn(vs ...string) predicate.Carrier

NotesIn applies the In predicate on the "notes" field.

func NotesIsNil

func NotesIsNil() predicate.Carrier

NotesIsNil applies the IsNil predicate on the "notes" field.

func NotesLT

func NotesLT(v string) predicate.Carrier

NotesLT applies the LT predicate on the "notes" field.

func NotesLTE

func NotesLTE(v string) predicate.Carrier

NotesLTE applies the LTE predicate on the "notes" field.

func NotesNEQ

func NotesNEQ(v string) predicate.Carrier

NotesNEQ applies the NEQ predicate on the "notes" field.

func NotesNotIn

func NotesNotIn(vs ...string) predicate.Carrier

NotesNotIn applies the NotIn predicate on the "notes" field.

func NotesNotNil

func NotesNotNil() predicate.Carrier

NotesNotNil applies the NotNil predicate on the "notes" field.

func Or

func Or(predicates ...predicate.Carrier) predicate.Carrier

Or groups predicates with the OR operator between them.

func OrgID

func OrgID(v int) predicate.Carrier

OrgID applies equality check predicate on the "org_id" field. It's identical to OrgIDEQ.

func OrgIDEQ

func OrgIDEQ(v int) predicate.Carrier

OrgIDEQ applies the EQ predicate on the "org_id" field.

func OrgIDIn

func OrgIDIn(vs ...int) predicate.Carrier

OrgIDIn applies the In predicate on the "org_id" field.

func OrgIDIsNil

func OrgIDIsNil() predicate.Carrier

OrgIDIsNil applies the IsNil predicate on the "org_id" field.

func OrgIDNEQ

func OrgIDNEQ(v int) predicate.Carrier

OrgIDNEQ applies the NEQ predicate on the "org_id" field.

func OrgIDNotIn

func OrgIDNotIn(vs ...int) predicate.Carrier

OrgIDNotIn applies the NotIn predicate on the "org_id" field.

func OrgIDNotNil

func OrgIDNotNil() predicate.Carrier

OrgIDNotNil applies the NotNil predicate on the "org_id" field.

func OrgName

func OrgName(v string) predicate.Carrier

OrgName applies equality check predicate on the "org_name" field. It's identical to OrgNameEQ.

func OrgNameContains

func OrgNameContains(v string) predicate.Carrier

OrgNameContains applies the Contains predicate on the "org_name" field.

func OrgNameContainsFold

func OrgNameContainsFold(v string) predicate.Carrier

OrgNameContainsFold applies the ContainsFold predicate on the "org_name" field.

func OrgNameEQ

func OrgNameEQ(v string) predicate.Carrier

OrgNameEQ applies the EQ predicate on the "org_name" field.

func OrgNameEqualFold

func OrgNameEqualFold(v string) predicate.Carrier

OrgNameEqualFold applies the EqualFold predicate on the "org_name" field.

func OrgNameGT

func OrgNameGT(v string) predicate.Carrier

OrgNameGT applies the GT predicate on the "org_name" field.

func OrgNameGTE

func OrgNameGTE(v string) predicate.Carrier

OrgNameGTE applies the GTE predicate on the "org_name" field.

func OrgNameHasPrefix

func OrgNameHasPrefix(v string) predicate.Carrier

OrgNameHasPrefix applies the HasPrefix predicate on the "org_name" field.

func OrgNameHasSuffix

func OrgNameHasSuffix(v string) predicate.Carrier

OrgNameHasSuffix applies the HasSuffix predicate on the "org_name" field.

func OrgNameIn

func OrgNameIn(vs ...string) predicate.Carrier

OrgNameIn applies the In predicate on the "org_name" field.

func OrgNameIsNil

func OrgNameIsNil() predicate.Carrier

OrgNameIsNil applies the IsNil predicate on the "org_name" field.

func OrgNameLT

func OrgNameLT(v string) predicate.Carrier

OrgNameLT applies the LT predicate on the "org_name" field.

func OrgNameLTE

func OrgNameLTE(v string) predicate.Carrier

OrgNameLTE applies the LTE predicate on the "org_name" field.

func OrgNameNEQ

func OrgNameNEQ(v string) predicate.Carrier

OrgNameNEQ applies the NEQ predicate on the "org_name" field.

func OrgNameNotIn

func OrgNameNotIn(vs ...string) predicate.Carrier

OrgNameNotIn applies the NotIn predicate on the "org_name" field.

func OrgNameNotNil

func OrgNameNotNil() predicate.Carrier

OrgNameNotNil applies the NotNil predicate on the "org_name" field.

func SocialMediaIsNil

func SocialMediaIsNil() predicate.Carrier

SocialMediaIsNil applies the IsNil predicate on the "social_media" field.

func SocialMediaNotNil

func SocialMediaNotNil() predicate.Carrier

SocialMediaNotNil applies the NotNil predicate on the "social_media" field.

func Status

func Status(v string) predicate.Carrier

Status applies equality check predicate on the "status" field. It's identical to StatusEQ.

func StatusContains

func StatusContains(v string) predicate.Carrier

StatusContains applies the Contains predicate on the "status" field.

func StatusContainsFold

func StatusContainsFold(v string) predicate.Carrier

StatusContainsFold applies the ContainsFold predicate on the "status" field.

func StatusEQ

func StatusEQ(v string) predicate.Carrier

StatusEQ applies the EQ predicate on the "status" field.

func StatusEqualFold

func StatusEqualFold(v string) predicate.Carrier

StatusEqualFold applies the EqualFold predicate on the "status" field.

func StatusGT

func StatusGT(v string) predicate.Carrier

StatusGT applies the GT predicate on the "status" field.

func StatusGTE

func StatusGTE(v string) predicate.Carrier

StatusGTE applies the GTE predicate on the "status" field.

func StatusHasPrefix

func StatusHasPrefix(v string) predicate.Carrier

StatusHasPrefix applies the HasPrefix predicate on the "status" field.

func StatusHasSuffix

func StatusHasSuffix(v string) predicate.Carrier

StatusHasSuffix applies the HasSuffix predicate on the "status" field.

func StatusIn

func StatusIn(vs ...string) predicate.Carrier

StatusIn applies the In predicate on the "status" field.

func StatusLT

func StatusLT(v string) predicate.Carrier

StatusLT applies the LT predicate on the "status" field.

func StatusLTE

func StatusLTE(v string) predicate.Carrier

StatusLTE applies the LTE predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v string) predicate.Carrier

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...string) predicate.Carrier

StatusNotIn applies the NotIn predicate on the "status" field.

func Updated

func Updated(v time.Time) predicate.Carrier

Updated applies equality check predicate on the "updated" field. It's identical to UpdatedEQ.

func UpdatedEQ

func UpdatedEQ(v time.Time) predicate.Carrier

UpdatedEQ applies the EQ predicate on the "updated" field.

func UpdatedGT

func UpdatedGT(v time.Time) predicate.Carrier

UpdatedGT applies the GT predicate on the "updated" field.

func UpdatedGTE

func UpdatedGTE(v time.Time) predicate.Carrier

UpdatedGTE applies the GTE predicate on the "updated" field.

func UpdatedIn

func UpdatedIn(vs ...time.Time) predicate.Carrier

UpdatedIn applies the In predicate on the "updated" field.

func UpdatedLT

func UpdatedLT(v time.Time) predicate.Carrier

UpdatedLT applies the LT predicate on the "updated" field.

func UpdatedLTE

func UpdatedLTE(v time.Time) predicate.Carrier

UpdatedLTE applies the LTE predicate on the "updated" field.

func UpdatedNEQ

func UpdatedNEQ(v time.Time) predicate.Carrier

UpdatedNEQ applies the NEQ predicate on the "updated" field.

func UpdatedNotIn

func UpdatedNotIn(vs ...time.Time) predicate.Carrier

UpdatedNotIn applies the NotIn predicate on the "updated" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func Website

func Website(v string) predicate.Carrier

Website applies equality check predicate on the "website" field. It's identical to WebsiteEQ.

func WebsiteContains

func WebsiteContains(v string) predicate.Carrier

WebsiteContains applies the Contains predicate on the "website" field.

func WebsiteContainsFold

func WebsiteContainsFold(v string) predicate.Carrier

WebsiteContainsFold applies the ContainsFold predicate on the "website" field.

func WebsiteEQ

func WebsiteEQ(v string) predicate.Carrier

WebsiteEQ applies the EQ predicate on the "website" field.

func WebsiteEqualFold

func WebsiteEqualFold(v string) predicate.Carrier

WebsiteEqualFold applies the EqualFold predicate on the "website" field.

func WebsiteGT

func WebsiteGT(v string) predicate.Carrier

WebsiteGT applies the GT predicate on the "website" field.

func WebsiteGTE

func WebsiteGTE(v string) predicate.Carrier

WebsiteGTE applies the GTE predicate on the "website" field.

func WebsiteHasPrefix

func WebsiteHasPrefix(v string) predicate.Carrier

WebsiteHasPrefix applies the HasPrefix predicate on the "website" field.

func WebsiteHasSuffix

func WebsiteHasSuffix(v string) predicate.Carrier

WebsiteHasSuffix applies the HasSuffix predicate on the "website" field.

func WebsiteIn

func WebsiteIn(vs ...string) predicate.Carrier

WebsiteIn applies the In predicate on the "website" field.

func WebsiteIsNil

func WebsiteIsNil() predicate.Carrier

WebsiteIsNil applies the IsNil predicate on the "website" field.

func WebsiteLT

func WebsiteLT(v string) predicate.Carrier

WebsiteLT applies the LT predicate on the "website" field.

func WebsiteLTE

func WebsiteLTE(v string) predicate.Carrier

WebsiteLTE applies the LTE predicate on the "website" field.

func WebsiteNEQ

func WebsiteNEQ(v string) predicate.Carrier

WebsiteNEQ applies the NEQ predicate on the "website" field.

func WebsiteNotIn

func WebsiteNotIn(vs ...string) predicate.Carrier

WebsiteNotIn applies the NotIn predicate on the "website" field.

func WebsiteNotNil

func WebsiteNotNil() predicate.Carrier

WebsiteNotNil applies the NotNil predicate on the "website" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Carrier queries.

func ByAka

func ByAka(opts ...sql.OrderTermOption) OrderOption

ByAka orders the results by the aka field.

func ByAkaFold added in v1.16.0

func ByAkaFold(opts ...sql.OrderTermOption) OrderOption

ByAkaFold orders the results by the aka_fold field.

func ByCarrierFacilities

func ByCarrierFacilities(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByCarrierFacilities orders the results by carrier_facilities terms.

func ByCarrierFacilitiesCount

func ByCarrierFacilitiesCount(opts ...sql.OrderTermOption) OrderOption

ByCarrierFacilitiesCount orders the results by carrier_facilities count.

func ByCreated

func ByCreated(opts ...sql.OrderTermOption) OrderOption

ByCreated orders the results by the created field.

func ByFacCount

func ByFacCount(opts ...sql.OrderTermOption) OrderOption

ByFacCount orders the results by the fac_count field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByLogo(opts ...sql.OrderTermOption) OrderOption

ByLogo orders the results by the logo field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByNameFold added in v1.16.0

func ByNameFold(opts ...sql.OrderTermOption) OrderOption

ByNameFold orders the results by the name_fold field.

func ByNameLong

func ByNameLong(opts ...sql.OrderTermOption) OrderOption

ByNameLong orders the results by the name_long field.

func ByNotes

func ByNotes(opts ...sql.OrderTermOption) OrderOption

ByNotes orders the results by the notes field.

func ByOrgID

func ByOrgID(opts ...sql.OrderTermOption) OrderOption

ByOrgID orders the results by the org_id field.

func ByOrgName

func ByOrgName(opts ...sql.OrderTermOption) OrderOption

ByOrgName orders the results by the org_name field.

func ByOrganizationField

func ByOrganizationField(field string, opts ...sql.OrderTermOption) OrderOption

ByOrganizationField orders the results by organization field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByUpdated

func ByUpdated(opts ...sql.OrderTermOption) OrderOption

ByUpdated orders the results by the updated field.

func ByWebsite

func ByWebsite(opts ...sql.OrderTermOption) OrderOption

ByWebsite orders the results by the website field.

Jump to