ixfacility

package
v1.18.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 3, 2026 License: BSD-3-Clause Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the ixfacility type in the database.
	Label = "ix_facility"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldFacID holds the string denoting the fac_id field in the database.
	FieldFacID = "fac_id"
	// FieldIxID holds the string denoting the ix_id field in the database.
	FieldIxID = "ix_id"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldCity holds the string denoting the city field in the database.
	FieldCity = "city"
	// FieldCountry holds the string denoting the country field in the database.
	FieldCountry = "country"
	// FieldCreated holds the string denoting the created field in the database.
	FieldCreated = "created"
	// FieldUpdated holds the string denoting the updated field in the database.
	FieldUpdated = "updated"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// EdgeFacility holds the string denoting the facility edge name in mutations.
	EdgeFacility = "facility"
	// EdgeInternetExchange holds the string denoting the internet_exchange edge name in mutations.
	EdgeInternetExchange = "internet_exchange"
	// Table holds the table name of the ixfacility in the database.
	Table = "ix_facilities"
	// FacilityTable is the table that holds the facility relation/edge.
	FacilityTable = "ix_facilities"
	// FacilityInverseTable is the table name for the Facility entity.
	// It exists in this package in order to avoid circular dependency with the "facility" package.
	FacilityInverseTable = "facilities"
	// FacilityColumn is the table column denoting the facility relation/edge.
	FacilityColumn = "fac_id"
	// InternetExchangeTable is the table that holds the internet_exchange relation/edge.
	InternetExchangeTable = "ix_facilities"
	// InternetExchangeInverseTable is the table name for the InternetExchange entity.
	// It exists in this package in order to avoid circular dependency with the "internetexchange" package.
	InternetExchangeInverseTable = "internet_exchanges"
	// InternetExchangeColumn is the table column denoting the internet_exchange relation/edge.
	InternetExchangeColumn = "ix_id"
)

Variables

var (
	// DefaultName holds the default value on creation for the "name" field.
	DefaultName string
	// DefaultCity holds the default value on creation for the "city" field.
	DefaultCity string
	// DefaultCountry holds the default value on creation for the "country" field.
	DefaultCountry string
	// DefaultStatus holds the default value on creation for the "status" field.
	DefaultStatus string
	// IDValidator is a validator for the "id" field. It is called by the builders before save.
	IDValidator func(int) error
)

Columns holds all SQL columns for ixfacility fields.

Functions

func And

func And(predicates ...predicate.IxFacility) predicate.IxFacility

And groups predicates with the AND operator between them.

func City

func City(v string) predicate.IxFacility

City applies equality check predicate on the "city" field. It's identical to CityEQ.

func CityContains

func CityContains(v string) predicate.IxFacility

CityContains applies the Contains predicate on the "city" field.

func CityContainsFold

func CityContainsFold(v string) predicate.IxFacility

CityContainsFold applies the ContainsFold predicate on the "city" field.

func CityEQ

func CityEQ(v string) predicate.IxFacility

CityEQ applies the EQ predicate on the "city" field.

func CityEqualFold

func CityEqualFold(v string) predicate.IxFacility

CityEqualFold applies the EqualFold predicate on the "city" field.

func CityGT

func CityGT(v string) predicate.IxFacility

CityGT applies the GT predicate on the "city" field.

func CityGTE

func CityGTE(v string) predicate.IxFacility

CityGTE applies the GTE predicate on the "city" field.

func CityHasPrefix

func CityHasPrefix(v string) predicate.IxFacility

CityHasPrefix applies the HasPrefix predicate on the "city" field.

func CityHasSuffix

func CityHasSuffix(v string) predicate.IxFacility

CityHasSuffix applies the HasSuffix predicate on the "city" field.

func CityIn

func CityIn(vs ...string) predicate.IxFacility

CityIn applies the In predicate on the "city" field.

func CityIsNil

func CityIsNil() predicate.IxFacility

CityIsNil applies the IsNil predicate on the "city" field.

func CityLT

func CityLT(v string) predicate.IxFacility

CityLT applies the LT predicate on the "city" field.

func CityLTE

func CityLTE(v string) predicate.IxFacility

CityLTE applies the LTE predicate on the "city" field.

func CityNEQ

func CityNEQ(v string) predicate.IxFacility

CityNEQ applies the NEQ predicate on the "city" field.

func CityNotIn

func CityNotIn(vs ...string) predicate.IxFacility

CityNotIn applies the NotIn predicate on the "city" field.

func CityNotNil

func CityNotNil() predicate.IxFacility

CityNotNil applies the NotNil predicate on the "city" field.

func Country

func Country(v string) predicate.IxFacility

Country applies equality check predicate on the "country" field. It's identical to CountryEQ.

func CountryContains

func CountryContains(v string) predicate.IxFacility

CountryContains applies the Contains predicate on the "country" field.

func CountryContainsFold

func CountryContainsFold(v string) predicate.IxFacility

CountryContainsFold applies the ContainsFold predicate on the "country" field.

func CountryEQ

func CountryEQ(v string) predicate.IxFacility

CountryEQ applies the EQ predicate on the "country" field.

func CountryEqualFold

func CountryEqualFold(v string) predicate.IxFacility

CountryEqualFold applies the EqualFold predicate on the "country" field.

func CountryGT

func CountryGT(v string) predicate.IxFacility

CountryGT applies the GT predicate on the "country" field.

func CountryGTE

func CountryGTE(v string) predicate.IxFacility

CountryGTE applies the GTE predicate on the "country" field.

func CountryHasPrefix

func CountryHasPrefix(v string) predicate.IxFacility

CountryHasPrefix applies the HasPrefix predicate on the "country" field.

func CountryHasSuffix

func CountryHasSuffix(v string) predicate.IxFacility

CountryHasSuffix applies the HasSuffix predicate on the "country" field.

func CountryIn

func CountryIn(vs ...string) predicate.IxFacility

CountryIn applies the In predicate on the "country" field.

func CountryIsNil

func CountryIsNil() predicate.IxFacility

CountryIsNil applies the IsNil predicate on the "country" field.

func CountryLT

func CountryLT(v string) predicate.IxFacility

CountryLT applies the LT predicate on the "country" field.

func CountryLTE

func CountryLTE(v string) predicate.IxFacility

CountryLTE applies the LTE predicate on the "country" field.

func CountryNEQ

func CountryNEQ(v string) predicate.IxFacility

CountryNEQ applies the NEQ predicate on the "country" field.

func CountryNotIn

func CountryNotIn(vs ...string) predicate.IxFacility

CountryNotIn applies the NotIn predicate on the "country" field.

func CountryNotNil

func CountryNotNil() predicate.IxFacility

CountryNotNil applies the NotNil predicate on the "country" field.

func Created

func Created(v time.Time) predicate.IxFacility

Created applies equality check predicate on the "created" field. It's identical to CreatedEQ.

func CreatedEQ

func CreatedEQ(v time.Time) predicate.IxFacility

CreatedEQ applies the EQ predicate on the "created" field.

func CreatedGT

func CreatedGT(v time.Time) predicate.IxFacility

CreatedGT applies the GT predicate on the "created" field.

func CreatedGTE

func CreatedGTE(v time.Time) predicate.IxFacility

CreatedGTE applies the GTE predicate on the "created" field.

func CreatedIn

func CreatedIn(vs ...time.Time) predicate.IxFacility

CreatedIn applies the In predicate on the "created" field.

func CreatedLT

func CreatedLT(v time.Time) predicate.IxFacility

CreatedLT applies the LT predicate on the "created" field.

func CreatedLTE

func CreatedLTE(v time.Time) predicate.IxFacility

CreatedLTE applies the LTE predicate on the "created" field.

func CreatedNEQ

func CreatedNEQ(v time.Time) predicate.IxFacility

CreatedNEQ applies the NEQ predicate on the "created" field.

func CreatedNotIn

func CreatedNotIn(vs ...time.Time) predicate.IxFacility

CreatedNotIn applies the NotIn predicate on the "created" field.

func FacID

func FacID(v int) predicate.IxFacility

FacID applies equality check predicate on the "fac_id" field. It's identical to FacIDEQ.

func FacIDEQ

func FacIDEQ(v int) predicate.IxFacility

FacIDEQ applies the EQ predicate on the "fac_id" field.

func FacIDIn

func FacIDIn(vs ...int) predicate.IxFacility

FacIDIn applies the In predicate on the "fac_id" field.

func FacIDIsNil

func FacIDIsNil() predicate.IxFacility

FacIDIsNil applies the IsNil predicate on the "fac_id" field.

func FacIDNEQ

func FacIDNEQ(v int) predicate.IxFacility

FacIDNEQ applies the NEQ predicate on the "fac_id" field.

func FacIDNotIn

func FacIDNotIn(vs ...int) predicate.IxFacility

FacIDNotIn applies the NotIn predicate on the "fac_id" field.

func FacIDNotNil

func FacIDNotNil() predicate.IxFacility

FacIDNotNil applies the NotNil predicate on the "fac_id" field.

func HasFacility

func HasFacility() predicate.IxFacility

HasFacility applies the HasEdge predicate on the "facility" edge.

func HasFacilityWith

func HasFacilityWith(preds ...predicate.Facility) predicate.IxFacility

HasFacilityWith applies the HasEdge predicate on the "facility" edge with a given conditions (other predicates).

func HasInternetExchange

func HasInternetExchange() predicate.IxFacility

HasInternetExchange applies the HasEdge predicate on the "internet_exchange" edge.

func HasInternetExchangeWith

func HasInternetExchangeWith(preds ...predicate.InternetExchange) predicate.IxFacility

HasInternetExchangeWith applies the HasEdge predicate on the "internet_exchange" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.IxFacility

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.IxFacility

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.IxFacility

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.IxFacility

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.IxFacility

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.IxFacility

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.IxFacility

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.IxFacility

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.IxFacility

IDNotIn applies the NotIn predicate on the ID field.

func IxID

func IxID(v int) predicate.IxFacility

IxID applies equality check predicate on the "ix_id" field. It's identical to IxIDEQ.

func IxIDEQ

func IxIDEQ(v int) predicate.IxFacility

IxIDEQ applies the EQ predicate on the "ix_id" field.

func IxIDIn

func IxIDIn(vs ...int) predicate.IxFacility

IxIDIn applies the In predicate on the "ix_id" field.

func IxIDIsNil

func IxIDIsNil() predicate.IxFacility

IxIDIsNil applies the IsNil predicate on the "ix_id" field.

func IxIDNEQ

func IxIDNEQ(v int) predicate.IxFacility

IxIDNEQ applies the NEQ predicate on the "ix_id" field.

func IxIDNotIn

func IxIDNotIn(vs ...int) predicate.IxFacility

IxIDNotIn applies the NotIn predicate on the "ix_id" field.

func IxIDNotNil

func IxIDNotNil() predicate.IxFacility

IxIDNotNil applies the NotNil predicate on the "ix_id" field.

func Name

func Name(v string) predicate.IxFacility

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.IxFacility

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.IxFacility

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.IxFacility

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.IxFacility

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.IxFacility

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.IxFacility

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.IxFacility

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.IxFacility

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.IxFacility

NameIn applies the In predicate on the "name" field.

func NameIsNil

func NameIsNil() predicate.IxFacility

NameIsNil applies the IsNil predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.IxFacility

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.IxFacility

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.IxFacility

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.IxFacility

NameNotIn applies the NotIn predicate on the "name" field.

func NameNotNil

func NameNotNil() predicate.IxFacility

NameNotNil applies the NotNil predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.IxFacility) predicate.IxFacility

Or groups predicates with the OR operator between them.

func Status

func Status(v string) predicate.IxFacility

Status applies equality check predicate on the "status" field. It's identical to StatusEQ.

func StatusContains

func StatusContains(v string) predicate.IxFacility

StatusContains applies the Contains predicate on the "status" field.

func StatusContainsFold

func StatusContainsFold(v string) predicate.IxFacility

StatusContainsFold applies the ContainsFold predicate on the "status" field.

func StatusEQ

func StatusEQ(v string) predicate.IxFacility

StatusEQ applies the EQ predicate on the "status" field.

func StatusEqualFold

func StatusEqualFold(v string) predicate.IxFacility

StatusEqualFold applies the EqualFold predicate on the "status" field.

func StatusGT

func StatusGT(v string) predicate.IxFacility

StatusGT applies the GT predicate on the "status" field.

func StatusGTE

func StatusGTE(v string) predicate.IxFacility

StatusGTE applies the GTE predicate on the "status" field.

func StatusHasPrefix

func StatusHasPrefix(v string) predicate.IxFacility

StatusHasPrefix applies the HasPrefix predicate on the "status" field.

func StatusHasSuffix

func StatusHasSuffix(v string) predicate.IxFacility

StatusHasSuffix applies the HasSuffix predicate on the "status" field.

func StatusIn

func StatusIn(vs ...string) predicate.IxFacility

StatusIn applies the In predicate on the "status" field.

func StatusLT

func StatusLT(v string) predicate.IxFacility

StatusLT applies the LT predicate on the "status" field.

func StatusLTE

func StatusLTE(v string) predicate.IxFacility

StatusLTE applies the LTE predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v string) predicate.IxFacility

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...string) predicate.IxFacility

StatusNotIn applies the NotIn predicate on the "status" field.

func Updated

func Updated(v time.Time) predicate.IxFacility

Updated applies equality check predicate on the "updated" field. It's identical to UpdatedEQ.

func UpdatedEQ

func UpdatedEQ(v time.Time) predicate.IxFacility

UpdatedEQ applies the EQ predicate on the "updated" field.

func UpdatedGT

func UpdatedGT(v time.Time) predicate.IxFacility

UpdatedGT applies the GT predicate on the "updated" field.

func UpdatedGTE

func UpdatedGTE(v time.Time) predicate.IxFacility

UpdatedGTE applies the GTE predicate on the "updated" field.

func UpdatedIn

func UpdatedIn(vs ...time.Time) predicate.IxFacility

UpdatedIn applies the In predicate on the "updated" field.

func UpdatedLT

func UpdatedLT(v time.Time) predicate.IxFacility

UpdatedLT applies the LT predicate on the "updated" field.

func UpdatedLTE

func UpdatedLTE(v time.Time) predicate.IxFacility

UpdatedLTE applies the LTE predicate on the "updated" field.

func UpdatedNEQ

func UpdatedNEQ(v time.Time) predicate.IxFacility

UpdatedNEQ applies the NEQ predicate on the "updated" field.

func UpdatedNotIn

func UpdatedNotIn(vs ...time.Time) predicate.IxFacility

UpdatedNotIn applies the NotIn predicate on the "updated" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the IxFacility queries.

func ByCity

func ByCity(opts ...sql.OrderTermOption) OrderOption

ByCity orders the results by the city field.

func ByCountry

func ByCountry(opts ...sql.OrderTermOption) OrderOption

ByCountry orders the results by the country field.

func ByCreated

func ByCreated(opts ...sql.OrderTermOption) OrderOption

ByCreated orders the results by the created field.

func ByFacID

func ByFacID(opts ...sql.OrderTermOption) OrderOption

ByFacID orders the results by the fac_id field.

func ByFacilityField

func ByFacilityField(field string, opts ...sql.OrderTermOption) OrderOption

ByFacilityField orders the results by facility field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByInternetExchangeField

func ByInternetExchangeField(field string, opts ...sql.OrderTermOption) OrderOption

ByInternetExchangeField orders the results by internet_exchange field.

func ByIxID

func ByIxID(opts ...sql.OrderTermOption) OrderOption

ByIxID orders the results by the ix_id field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByUpdated

func ByUpdated(opts ...sql.OrderTermOption) OrderOption

ByUpdated orders the results by the updated field.

Jump to