ixlan

package
v1.18.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 3, 2026 License: BSD-3-Clause Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the ixlan type in the database.
	Label = "ix_lan"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldIxID holds the string denoting the ix_id field in the database.
	FieldIxID = "ix_id"
	// FieldArpSponge holds the string denoting the arp_sponge field in the database.
	FieldArpSponge = "arp_sponge"
	// FieldDescr holds the string denoting the descr field in the database.
	FieldDescr = "descr"
	// FieldDot1qSupport holds the string denoting the dot1q_support field in the database.
	FieldDot1qSupport = "dot1q_support"
	// FieldIxfIxpImportEnabled holds the string denoting the ixf_ixp_import_enabled field in the database.
	FieldIxfIxpImportEnabled = "ixf_ixp_import_enabled"
	// FieldIxfIxpMemberListURL holds the string denoting the ixf_ixp_member_list_url field in the database.
	FieldIxfIxpMemberListURL = "ixf_ixp_member_list_url"
	// FieldIxfIxpMemberListURLVisible holds the string denoting the ixf_ixp_member_list_url_visible field in the database.
	FieldIxfIxpMemberListURLVisible = "ixf_ixp_member_list_url_visible"
	// FieldMtu holds the string denoting the mtu field in the database.
	FieldMtu = "mtu"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldRsAsn holds the string denoting the rs_asn field in the database.
	FieldRsAsn = "rs_asn"
	// FieldCreated holds the string denoting the created field in the database.
	FieldCreated = "created"
	// FieldUpdated holds the string denoting the updated field in the database.
	FieldUpdated = "updated"
	// FieldStatus holds the string denoting the status field in the database.
	FieldStatus = "status"
	// EdgeInternetExchange holds the string denoting the internet_exchange edge name in mutations.
	EdgeInternetExchange = "internet_exchange"
	// EdgeIxPrefixes holds the string denoting the ix_prefixes edge name in mutations.
	EdgeIxPrefixes = "ix_prefixes"
	// EdgeNetworkIxLans holds the string denoting the network_ix_lans edge name in mutations.
	EdgeNetworkIxLans = "network_ix_lans"
	// Table holds the table name of the ixlan in the database.
	Table = "ix_lans"
	// InternetExchangeTable is the table that holds the internet_exchange relation/edge.
	InternetExchangeTable = "ix_lans"
	// InternetExchangeInverseTable is the table name for the InternetExchange entity.
	// It exists in this package in order to avoid circular dependency with the "internetexchange" package.
	InternetExchangeInverseTable = "internet_exchanges"
	// InternetExchangeColumn is the table column denoting the internet_exchange relation/edge.
	InternetExchangeColumn = "ix_id"
	// IxPrefixesTable is the table that holds the ix_prefixes relation/edge.
	IxPrefixesTable = "ix_prefixes"
	// IxPrefixesInverseTable is the table name for the IxPrefix entity.
	// It exists in this package in order to avoid circular dependency with the "ixprefix" package.
	IxPrefixesInverseTable = "ix_prefixes"
	// IxPrefixesColumn is the table column denoting the ix_prefixes relation/edge.
	IxPrefixesColumn = "ixlan_id"
	// NetworkIxLansTable is the table that holds the network_ix_lans relation/edge.
	NetworkIxLansTable = "network_ix_lans"
	// NetworkIxLansInverseTable is the table name for the NetworkIxLan entity.
	// It exists in this package in order to avoid circular dependency with the "networkixlan" package.
	NetworkIxLansInverseTable = "network_ix_lans"
	// NetworkIxLansColumn is the table column denoting the network_ix_lans relation/edge.
	NetworkIxLansColumn = "ixlan_id"
)

Variables

var (
	// DefaultDescr holds the default value on creation for the "descr" field.
	DefaultDescr string
	// DefaultDot1qSupport holds the default value on creation for the "dot1q_support" field.
	DefaultDot1qSupport bool
	// DefaultIxfIxpImportEnabled holds the default value on creation for the "ixf_ixp_import_enabled" field.
	DefaultIxfIxpImportEnabled bool
	// DefaultIxfIxpMemberListURL holds the default value on creation for the "ixf_ixp_member_list_url" field.
	DefaultIxfIxpMemberListURL string
	// DefaultIxfIxpMemberListURLVisible holds the default value on creation for the "ixf_ixp_member_list_url_visible" field.
	DefaultIxfIxpMemberListURLVisible string
	// DefaultMtu holds the default value on creation for the "mtu" field.
	DefaultMtu int
	// DefaultName holds the default value on creation for the "name" field.
	DefaultName string
	// DefaultRsAsn holds the default value on creation for the "rs_asn" field.
	DefaultRsAsn int
	// DefaultStatus holds the default value on creation for the "status" field.
	DefaultStatus string
	// IDValidator is a validator for the "id" field. It is called by the builders before save.
	IDValidator func(int) error
)

Columns holds all SQL columns for ixlan fields.

Functions

func And

func And(predicates ...predicate.IxLan) predicate.IxLan

And groups predicates with the AND operator between them.

func ArpSponge

func ArpSponge(v string) predicate.IxLan

ArpSponge applies equality check predicate on the "arp_sponge" field. It's identical to ArpSpongeEQ.

func ArpSpongeContains

func ArpSpongeContains(v string) predicate.IxLan

ArpSpongeContains applies the Contains predicate on the "arp_sponge" field.

func ArpSpongeContainsFold

func ArpSpongeContainsFold(v string) predicate.IxLan

ArpSpongeContainsFold applies the ContainsFold predicate on the "arp_sponge" field.

func ArpSpongeEQ

func ArpSpongeEQ(v string) predicate.IxLan

ArpSpongeEQ applies the EQ predicate on the "arp_sponge" field.

func ArpSpongeEqualFold

func ArpSpongeEqualFold(v string) predicate.IxLan

ArpSpongeEqualFold applies the EqualFold predicate on the "arp_sponge" field.

func ArpSpongeGT

func ArpSpongeGT(v string) predicate.IxLan

ArpSpongeGT applies the GT predicate on the "arp_sponge" field.

func ArpSpongeGTE

func ArpSpongeGTE(v string) predicate.IxLan

ArpSpongeGTE applies the GTE predicate on the "arp_sponge" field.

func ArpSpongeHasPrefix

func ArpSpongeHasPrefix(v string) predicate.IxLan

ArpSpongeHasPrefix applies the HasPrefix predicate on the "arp_sponge" field.

func ArpSpongeHasSuffix

func ArpSpongeHasSuffix(v string) predicate.IxLan

ArpSpongeHasSuffix applies the HasSuffix predicate on the "arp_sponge" field.

func ArpSpongeIn

func ArpSpongeIn(vs ...string) predicate.IxLan

ArpSpongeIn applies the In predicate on the "arp_sponge" field.

func ArpSpongeIsNil

func ArpSpongeIsNil() predicate.IxLan

ArpSpongeIsNil applies the IsNil predicate on the "arp_sponge" field.

func ArpSpongeLT

func ArpSpongeLT(v string) predicate.IxLan

ArpSpongeLT applies the LT predicate on the "arp_sponge" field.

func ArpSpongeLTE

func ArpSpongeLTE(v string) predicate.IxLan

ArpSpongeLTE applies the LTE predicate on the "arp_sponge" field.

func ArpSpongeNEQ

func ArpSpongeNEQ(v string) predicate.IxLan

ArpSpongeNEQ applies the NEQ predicate on the "arp_sponge" field.

func ArpSpongeNotIn

func ArpSpongeNotIn(vs ...string) predicate.IxLan

ArpSpongeNotIn applies the NotIn predicate on the "arp_sponge" field.

func ArpSpongeNotNil

func ArpSpongeNotNil() predicate.IxLan

ArpSpongeNotNil applies the NotNil predicate on the "arp_sponge" field.

func Created

func Created(v time.Time) predicate.IxLan

Created applies equality check predicate on the "created" field. It's identical to CreatedEQ.

func CreatedEQ

func CreatedEQ(v time.Time) predicate.IxLan

CreatedEQ applies the EQ predicate on the "created" field.

func CreatedGT

func CreatedGT(v time.Time) predicate.IxLan

CreatedGT applies the GT predicate on the "created" field.

func CreatedGTE

func CreatedGTE(v time.Time) predicate.IxLan

CreatedGTE applies the GTE predicate on the "created" field.

func CreatedIn

func CreatedIn(vs ...time.Time) predicate.IxLan

CreatedIn applies the In predicate on the "created" field.

func CreatedLT

func CreatedLT(v time.Time) predicate.IxLan

CreatedLT applies the LT predicate on the "created" field.

func CreatedLTE

func CreatedLTE(v time.Time) predicate.IxLan

CreatedLTE applies the LTE predicate on the "created" field.

func CreatedNEQ

func CreatedNEQ(v time.Time) predicate.IxLan

CreatedNEQ applies the NEQ predicate on the "created" field.

func CreatedNotIn

func CreatedNotIn(vs ...time.Time) predicate.IxLan

CreatedNotIn applies the NotIn predicate on the "created" field.

func Descr

func Descr(v string) predicate.IxLan

Descr applies equality check predicate on the "descr" field. It's identical to DescrEQ.

func DescrContains

func DescrContains(v string) predicate.IxLan

DescrContains applies the Contains predicate on the "descr" field.

func DescrContainsFold

func DescrContainsFold(v string) predicate.IxLan

DescrContainsFold applies the ContainsFold predicate on the "descr" field.

func DescrEQ

func DescrEQ(v string) predicate.IxLan

DescrEQ applies the EQ predicate on the "descr" field.

func DescrEqualFold

func DescrEqualFold(v string) predicate.IxLan

DescrEqualFold applies the EqualFold predicate on the "descr" field.

func DescrGT

func DescrGT(v string) predicate.IxLan

DescrGT applies the GT predicate on the "descr" field.

func DescrGTE

func DescrGTE(v string) predicate.IxLan

DescrGTE applies the GTE predicate on the "descr" field.

func DescrHasPrefix

func DescrHasPrefix(v string) predicate.IxLan

DescrHasPrefix applies the HasPrefix predicate on the "descr" field.

func DescrHasSuffix

func DescrHasSuffix(v string) predicate.IxLan

DescrHasSuffix applies the HasSuffix predicate on the "descr" field.

func DescrIn

func DescrIn(vs ...string) predicate.IxLan

DescrIn applies the In predicate on the "descr" field.

func DescrIsNil

func DescrIsNil() predicate.IxLan

DescrIsNil applies the IsNil predicate on the "descr" field.

func DescrLT

func DescrLT(v string) predicate.IxLan

DescrLT applies the LT predicate on the "descr" field.

func DescrLTE

func DescrLTE(v string) predicate.IxLan

DescrLTE applies the LTE predicate on the "descr" field.

func DescrNEQ

func DescrNEQ(v string) predicate.IxLan

DescrNEQ applies the NEQ predicate on the "descr" field.

func DescrNotIn

func DescrNotIn(vs ...string) predicate.IxLan

DescrNotIn applies the NotIn predicate on the "descr" field.

func DescrNotNil

func DescrNotNil() predicate.IxLan

DescrNotNil applies the NotNil predicate on the "descr" field.

func Dot1qSupport

func Dot1qSupport(v bool) predicate.IxLan

Dot1qSupport applies equality check predicate on the "dot1q_support" field. It's identical to Dot1qSupportEQ.

func Dot1qSupportEQ

func Dot1qSupportEQ(v bool) predicate.IxLan

Dot1qSupportEQ applies the EQ predicate on the "dot1q_support" field.

func Dot1qSupportNEQ

func Dot1qSupportNEQ(v bool) predicate.IxLan

Dot1qSupportNEQ applies the NEQ predicate on the "dot1q_support" field.

func HasInternetExchange

func HasInternetExchange() predicate.IxLan

HasInternetExchange applies the HasEdge predicate on the "internet_exchange" edge.

func HasInternetExchangeWith

func HasInternetExchangeWith(preds ...predicate.InternetExchange) predicate.IxLan

HasInternetExchangeWith applies the HasEdge predicate on the "internet_exchange" edge with a given conditions (other predicates).

func HasIxPrefixes

func HasIxPrefixes() predicate.IxLan

HasIxPrefixes applies the HasEdge predicate on the "ix_prefixes" edge.

func HasIxPrefixesWith

func HasIxPrefixesWith(preds ...predicate.IxPrefix) predicate.IxLan

HasIxPrefixesWith applies the HasEdge predicate on the "ix_prefixes" edge with a given conditions (other predicates).

func HasNetworkIxLans

func HasNetworkIxLans() predicate.IxLan

HasNetworkIxLans applies the HasEdge predicate on the "network_ix_lans" edge.

func HasNetworkIxLansWith

func HasNetworkIxLansWith(preds ...predicate.NetworkIxLan) predicate.IxLan

HasNetworkIxLansWith applies the HasEdge predicate on the "network_ix_lans" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.IxLan

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.IxLan

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.IxLan

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.IxLan

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.IxLan

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.IxLan

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.IxLan

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.IxLan

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.IxLan

IDNotIn applies the NotIn predicate on the ID field.

func IxID

func IxID(v int) predicate.IxLan

IxID applies equality check predicate on the "ix_id" field. It's identical to IxIDEQ.

func IxIDEQ

func IxIDEQ(v int) predicate.IxLan

IxIDEQ applies the EQ predicate on the "ix_id" field.

func IxIDIn

func IxIDIn(vs ...int) predicate.IxLan

IxIDIn applies the In predicate on the "ix_id" field.

func IxIDIsNil

func IxIDIsNil() predicate.IxLan

IxIDIsNil applies the IsNil predicate on the "ix_id" field.

func IxIDNEQ

func IxIDNEQ(v int) predicate.IxLan

IxIDNEQ applies the NEQ predicate on the "ix_id" field.

func IxIDNotIn

func IxIDNotIn(vs ...int) predicate.IxLan

IxIDNotIn applies the NotIn predicate on the "ix_id" field.

func IxIDNotNil

func IxIDNotNil() predicate.IxLan

IxIDNotNil applies the NotNil predicate on the "ix_id" field.

func IxfIxpImportEnabled

func IxfIxpImportEnabled(v bool) predicate.IxLan

IxfIxpImportEnabled applies equality check predicate on the "ixf_ixp_import_enabled" field. It's identical to IxfIxpImportEnabledEQ.

func IxfIxpImportEnabledEQ

func IxfIxpImportEnabledEQ(v bool) predicate.IxLan

IxfIxpImportEnabledEQ applies the EQ predicate on the "ixf_ixp_import_enabled" field.

func IxfIxpImportEnabledNEQ

func IxfIxpImportEnabledNEQ(v bool) predicate.IxLan

IxfIxpImportEnabledNEQ applies the NEQ predicate on the "ixf_ixp_import_enabled" field.

func IxfIxpMemberListURL added in v1.15.0

func IxfIxpMemberListURL(v string) predicate.IxLan

IxfIxpMemberListURL applies equality check predicate on the "ixf_ixp_member_list_url" field. It's identical to IxfIxpMemberListURLEQ.

func IxfIxpMemberListURLContains added in v1.15.0

func IxfIxpMemberListURLContains(v string) predicate.IxLan

IxfIxpMemberListURLContains applies the Contains predicate on the "ixf_ixp_member_list_url" field.

func IxfIxpMemberListURLContainsFold added in v1.15.0

func IxfIxpMemberListURLContainsFold(v string) predicate.IxLan

IxfIxpMemberListURLContainsFold applies the ContainsFold predicate on the "ixf_ixp_member_list_url" field.

func IxfIxpMemberListURLEQ added in v1.15.0

func IxfIxpMemberListURLEQ(v string) predicate.IxLan

IxfIxpMemberListURLEQ applies the EQ predicate on the "ixf_ixp_member_list_url" field.

func IxfIxpMemberListURLEqualFold added in v1.15.0

func IxfIxpMemberListURLEqualFold(v string) predicate.IxLan

IxfIxpMemberListURLEqualFold applies the EqualFold predicate on the "ixf_ixp_member_list_url" field.

func IxfIxpMemberListURLGT added in v1.15.0

func IxfIxpMemberListURLGT(v string) predicate.IxLan

IxfIxpMemberListURLGT applies the GT predicate on the "ixf_ixp_member_list_url" field.

func IxfIxpMemberListURLGTE added in v1.15.0

func IxfIxpMemberListURLGTE(v string) predicate.IxLan

IxfIxpMemberListURLGTE applies the GTE predicate on the "ixf_ixp_member_list_url" field.

func IxfIxpMemberListURLHasPrefix added in v1.15.0

func IxfIxpMemberListURLHasPrefix(v string) predicate.IxLan

IxfIxpMemberListURLHasPrefix applies the HasPrefix predicate on the "ixf_ixp_member_list_url" field.

func IxfIxpMemberListURLHasSuffix added in v1.15.0

func IxfIxpMemberListURLHasSuffix(v string) predicate.IxLan

IxfIxpMemberListURLHasSuffix applies the HasSuffix predicate on the "ixf_ixp_member_list_url" field.

func IxfIxpMemberListURLIn added in v1.15.0

func IxfIxpMemberListURLIn(vs ...string) predicate.IxLan

IxfIxpMemberListURLIn applies the In predicate on the "ixf_ixp_member_list_url" field.

func IxfIxpMemberListURLIsNil added in v1.15.0

func IxfIxpMemberListURLIsNil() predicate.IxLan

IxfIxpMemberListURLIsNil applies the IsNil predicate on the "ixf_ixp_member_list_url" field.

func IxfIxpMemberListURLLT added in v1.15.0

func IxfIxpMemberListURLLT(v string) predicate.IxLan

IxfIxpMemberListURLLT applies the LT predicate on the "ixf_ixp_member_list_url" field.

func IxfIxpMemberListURLLTE added in v1.15.0

func IxfIxpMemberListURLLTE(v string) predicate.IxLan

IxfIxpMemberListURLLTE applies the LTE predicate on the "ixf_ixp_member_list_url" field.

func IxfIxpMemberListURLNEQ added in v1.15.0

func IxfIxpMemberListURLNEQ(v string) predicate.IxLan

IxfIxpMemberListURLNEQ applies the NEQ predicate on the "ixf_ixp_member_list_url" field.

func IxfIxpMemberListURLNotIn added in v1.15.0

func IxfIxpMemberListURLNotIn(vs ...string) predicate.IxLan

IxfIxpMemberListURLNotIn applies the NotIn predicate on the "ixf_ixp_member_list_url" field.

func IxfIxpMemberListURLNotNil added in v1.15.0

func IxfIxpMemberListURLNotNil() predicate.IxLan

IxfIxpMemberListURLNotNil applies the NotNil predicate on the "ixf_ixp_member_list_url" field.

func IxfIxpMemberListURLVisible

func IxfIxpMemberListURLVisible(v string) predicate.IxLan

IxfIxpMemberListURLVisible applies equality check predicate on the "ixf_ixp_member_list_url_visible" field. It's identical to IxfIxpMemberListURLVisibleEQ.

func IxfIxpMemberListURLVisibleContains

func IxfIxpMemberListURLVisibleContains(v string) predicate.IxLan

IxfIxpMemberListURLVisibleContains applies the Contains predicate on the "ixf_ixp_member_list_url_visible" field.

func IxfIxpMemberListURLVisibleContainsFold

func IxfIxpMemberListURLVisibleContainsFold(v string) predicate.IxLan

IxfIxpMemberListURLVisibleContainsFold applies the ContainsFold predicate on the "ixf_ixp_member_list_url_visible" field.

func IxfIxpMemberListURLVisibleEQ

func IxfIxpMemberListURLVisibleEQ(v string) predicate.IxLan

IxfIxpMemberListURLVisibleEQ applies the EQ predicate on the "ixf_ixp_member_list_url_visible" field.

func IxfIxpMemberListURLVisibleEqualFold

func IxfIxpMemberListURLVisibleEqualFold(v string) predicate.IxLan

IxfIxpMemberListURLVisibleEqualFold applies the EqualFold predicate on the "ixf_ixp_member_list_url_visible" field.

func IxfIxpMemberListURLVisibleGT

func IxfIxpMemberListURLVisibleGT(v string) predicate.IxLan

IxfIxpMemberListURLVisibleGT applies the GT predicate on the "ixf_ixp_member_list_url_visible" field.

func IxfIxpMemberListURLVisibleGTE

func IxfIxpMemberListURLVisibleGTE(v string) predicate.IxLan

IxfIxpMemberListURLVisibleGTE applies the GTE predicate on the "ixf_ixp_member_list_url_visible" field.

func IxfIxpMemberListURLVisibleHasPrefix

func IxfIxpMemberListURLVisibleHasPrefix(v string) predicate.IxLan

IxfIxpMemberListURLVisibleHasPrefix applies the HasPrefix predicate on the "ixf_ixp_member_list_url_visible" field.

func IxfIxpMemberListURLVisibleHasSuffix

func IxfIxpMemberListURLVisibleHasSuffix(v string) predicate.IxLan

IxfIxpMemberListURLVisibleHasSuffix applies the HasSuffix predicate on the "ixf_ixp_member_list_url_visible" field.

func IxfIxpMemberListURLVisibleIn

func IxfIxpMemberListURLVisibleIn(vs ...string) predicate.IxLan

IxfIxpMemberListURLVisibleIn applies the In predicate on the "ixf_ixp_member_list_url_visible" field.

func IxfIxpMemberListURLVisibleIsNil added in v1.4.0

func IxfIxpMemberListURLVisibleIsNil() predicate.IxLan

IxfIxpMemberListURLVisibleIsNil applies the IsNil predicate on the "ixf_ixp_member_list_url_visible" field.

func IxfIxpMemberListURLVisibleLT

func IxfIxpMemberListURLVisibleLT(v string) predicate.IxLan

IxfIxpMemberListURLVisibleLT applies the LT predicate on the "ixf_ixp_member_list_url_visible" field.

func IxfIxpMemberListURLVisibleLTE

func IxfIxpMemberListURLVisibleLTE(v string) predicate.IxLan

IxfIxpMemberListURLVisibleLTE applies the LTE predicate on the "ixf_ixp_member_list_url_visible" field.

func IxfIxpMemberListURLVisibleNEQ

func IxfIxpMemberListURLVisibleNEQ(v string) predicate.IxLan

IxfIxpMemberListURLVisibleNEQ applies the NEQ predicate on the "ixf_ixp_member_list_url_visible" field.

func IxfIxpMemberListURLVisibleNotIn

func IxfIxpMemberListURLVisibleNotIn(vs ...string) predicate.IxLan

IxfIxpMemberListURLVisibleNotIn applies the NotIn predicate on the "ixf_ixp_member_list_url_visible" field.

func IxfIxpMemberListURLVisibleNotNil added in v1.4.0

func IxfIxpMemberListURLVisibleNotNil() predicate.IxLan

IxfIxpMemberListURLVisibleNotNil applies the NotNil predicate on the "ixf_ixp_member_list_url_visible" field.

func Mtu

func Mtu(v int) predicate.IxLan

Mtu applies equality check predicate on the "mtu" field. It's identical to MtuEQ.

func MtuEQ

func MtuEQ(v int) predicate.IxLan

MtuEQ applies the EQ predicate on the "mtu" field.

func MtuGT

func MtuGT(v int) predicate.IxLan

MtuGT applies the GT predicate on the "mtu" field.

func MtuGTE

func MtuGTE(v int) predicate.IxLan

MtuGTE applies the GTE predicate on the "mtu" field.

func MtuIn

func MtuIn(vs ...int) predicate.IxLan

MtuIn applies the In predicate on the "mtu" field.

func MtuIsNil added in v1.4.0

func MtuIsNil() predicate.IxLan

MtuIsNil applies the IsNil predicate on the "mtu" field.

func MtuLT

func MtuLT(v int) predicate.IxLan

MtuLT applies the LT predicate on the "mtu" field.

func MtuLTE

func MtuLTE(v int) predicate.IxLan

MtuLTE applies the LTE predicate on the "mtu" field.

func MtuNEQ

func MtuNEQ(v int) predicate.IxLan

MtuNEQ applies the NEQ predicate on the "mtu" field.

func MtuNotIn

func MtuNotIn(vs ...int) predicate.IxLan

MtuNotIn applies the NotIn predicate on the "mtu" field.

func MtuNotNil added in v1.4.0

func MtuNotNil() predicate.IxLan

MtuNotNil applies the NotNil predicate on the "mtu" field.

func Name

func Name(v string) predicate.IxLan

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.IxLan

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.IxLan

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.IxLan

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.IxLan

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.IxLan

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.IxLan

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.IxLan

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.IxLan

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.IxLan

NameIn applies the In predicate on the "name" field.

func NameIsNil

func NameIsNil() predicate.IxLan

NameIsNil applies the IsNil predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.IxLan

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.IxLan

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.IxLan

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.IxLan

NameNotIn applies the NotIn predicate on the "name" field.

func NameNotNil

func NameNotNil() predicate.IxLan

NameNotNil applies the NotNil predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.IxLan) predicate.IxLan

Or groups predicates with the OR operator between them.

func RsAsn

func RsAsn(v int) predicate.IxLan

RsAsn applies equality check predicate on the "rs_asn" field. It's identical to RsAsnEQ.

func RsAsnEQ

func RsAsnEQ(v int) predicate.IxLan

RsAsnEQ applies the EQ predicate on the "rs_asn" field.

func RsAsnGT

func RsAsnGT(v int) predicate.IxLan

RsAsnGT applies the GT predicate on the "rs_asn" field.

func RsAsnGTE

func RsAsnGTE(v int) predicate.IxLan

RsAsnGTE applies the GTE predicate on the "rs_asn" field.

func RsAsnIn

func RsAsnIn(vs ...int) predicate.IxLan

RsAsnIn applies the In predicate on the "rs_asn" field.

func RsAsnIsNil

func RsAsnIsNil() predicate.IxLan

RsAsnIsNil applies the IsNil predicate on the "rs_asn" field.

func RsAsnLT

func RsAsnLT(v int) predicate.IxLan

RsAsnLT applies the LT predicate on the "rs_asn" field.

func RsAsnLTE

func RsAsnLTE(v int) predicate.IxLan

RsAsnLTE applies the LTE predicate on the "rs_asn" field.

func RsAsnNEQ

func RsAsnNEQ(v int) predicate.IxLan

RsAsnNEQ applies the NEQ predicate on the "rs_asn" field.

func RsAsnNotIn

func RsAsnNotIn(vs ...int) predicate.IxLan

RsAsnNotIn applies the NotIn predicate on the "rs_asn" field.

func RsAsnNotNil

func RsAsnNotNil() predicate.IxLan

RsAsnNotNil applies the NotNil predicate on the "rs_asn" field.

func Status

func Status(v string) predicate.IxLan

Status applies equality check predicate on the "status" field. It's identical to StatusEQ.

func StatusContains

func StatusContains(v string) predicate.IxLan

StatusContains applies the Contains predicate on the "status" field.

func StatusContainsFold

func StatusContainsFold(v string) predicate.IxLan

StatusContainsFold applies the ContainsFold predicate on the "status" field.

func StatusEQ

func StatusEQ(v string) predicate.IxLan

StatusEQ applies the EQ predicate on the "status" field.

func StatusEqualFold

func StatusEqualFold(v string) predicate.IxLan

StatusEqualFold applies the EqualFold predicate on the "status" field.

func StatusGT

func StatusGT(v string) predicate.IxLan

StatusGT applies the GT predicate on the "status" field.

func StatusGTE

func StatusGTE(v string) predicate.IxLan

StatusGTE applies the GTE predicate on the "status" field.

func StatusHasPrefix

func StatusHasPrefix(v string) predicate.IxLan

StatusHasPrefix applies the HasPrefix predicate on the "status" field.

func StatusHasSuffix

func StatusHasSuffix(v string) predicate.IxLan

StatusHasSuffix applies the HasSuffix predicate on the "status" field.

func StatusIn

func StatusIn(vs ...string) predicate.IxLan

StatusIn applies the In predicate on the "status" field.

func StatusLT

func StatusLT(v string) predicate.IxLan

StatusLT applies the LT predicate on the "status" field.

func StatusLTE

func StatusLTE(v string) predicate.IxLan

StatusLTE applies the LTE predicate on the "status" field.

func StatusNEQ

func StatusNEQ(v string) predicate.IxLan

StatusNEQ applies the NEQ predicate on the "status" field.

func StatusNotIn

func StatusNotIn(vs ...string) predicate.IxLan

StatusNotIn applies the NotIn predicate on the "status" field.

func Updated

func Updated(v time.Time) predicate.IxLan

Updated applies equality check predicate on the "updated" field. It's identical to UpdatedEQ.

func UpdatedEQ

func UpdatedEQ(v time.Time) predicate.IxLan

UpdatedEQ applies the EQ predicate on the "updated" field.

func UpdatedGT

func UpdatedGT(v time.Time) predicate.IxLan

UpdatedGT applies the GT predicate on the "updated" field.

func UpdatedGTE

func UpdatedGTE(v time.Time) predicate.IxLan

UpdatedGTE applies the GTE predicate on the "updated" field.

func UpdatedIn

func UpdatedIn(vs ...time.Time) predicate.IxLan

UpdatedIn applies the In predicate on the "updated" field.

func UpdatedLT

func UpdatedLT(v time.Time) predicate.IxLan

UpdatedLT applies the LT predicate on the "updated" field.

func UpdatedLTE

func UpdatedLTE(v time.Time) predicate.IxLan

UpdatedLTE applies the LTE predicate on the "updated" field.

func UpdatedNEQ

func UpdatedNEQ(v time.Time) predicate.IxLan

UpdatedNEQ applies the NEQ predicate on the "updated" field.

func UpdatedNotIn

func UpdatedNotIn(vs ...time.Time) predicate.IxLan

UpdatedNotIn applies the NotIn predicate on the "updated" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the IxLan queries.

func ByArpSponge

func ByArpSponge(opts ...sql.OrderTermOption) OrderOption

ByArpSponge orders the results by the arp_sponge field.

func ByCreated

func ByCreated(opts ...sql.OrderTermOption) OrderOption

ByCreated orders the results by the created field.

func ByDescr

func ByDescr(opts ...sql.OrderTermOption) OrderOption

ByDescr orders the results by the descr field.

func ByDot1qSupport

func ByDot1qSupport(opts ...sql.OrderTermOption) OrderOption

ByDot1qSupport orders the results by the dot1q_support field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByInternetExchangeField

func ByInternetExchangeField(field string, opts ...sql.OrderTermOption) OrderOption

ByInternetExchangeField orders the results by internet_exchange field.

func ByIxID

func ByIxID(opts ...sql.OrderTermOption) OrderOption

ByIxID orders the results by the ix_id field.

func ByIxPrefixes

func ByIxPrefixes(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByIxPrefixes orders the results by ix_prefixes terms.

func ByIxPrefixesCount

func ByIxPrefixesCount(opts ...sql.OrderTermOption) OrderOption

ByIxPrefixesCount orders the results by ix_prefixes count.

func ByIxfIxpImportEnabled

func ByIxfIxpImportEnabled(opts ...sql.OrderTermOption) OrderOption

ByIxfIxpImportEnabled orders the results by the ixf_ixp_import_enabled field.

func ByIxfIxpMemberListURL added in v1.15.0

func ByIxfIxpMemberListURL(opts ...sql.OrderTermOption) OrderOption

ByIxfIxpMemberListURL orders the results by the ixf_ixp_member_list_url field.

func ByIxfIxpMemberListURLVisible

func ByIxfIxpMemberListURLVisible(opts ...sql.OrderTermOption) OrderOption

ByIxfIxpMemberListURLVisible orders the results by the ixf_ixp_member_list_url_visible field.

func ByMtu

func ByMtu(opts ...sql.OrderTermOption) OrderOption

ByMtu orders the results by the mtu field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByNetworkIxLans

func ByNetworkIxLans(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByNetworkIxLans orders the results by network_ix_lans terms.

func ByNetworkIxLansCount

func ByNetworkIxLansCount(opts ...sql.OrderTermOption) OrderOption

ByNetworkIxLansCount orders the results by network_ix_lans count.

func ByRsAsn

func ByRsAsn(opts ...sql.OrderTermOption) OrderOption

ByRsAsn orders the results by the rs_asn field.

func ByStatus

func ByStatus(opts ...sql.OrderTermOption) OrderOption

ByStatus orders the results by the status field.

func ByUpdated

func ByUpdated(opts ...sql.OrderTermOption) OrderOption

ByUpdated orders the results by the updated field.

Jump to