Documentation
¶
Index ¶
- Constants
- Variables
- func Aka(v string) predicate.Campus
- func AkaContains(v string) predicate.Campus
- func AkaContainsFold(v string) predicate.Campus
- func AkaEQ(v string) predicate.Campus
- func AkaEqualFold(v string) predicate.Campus
- func AkaGT(v string) predicate.Campus
- func AkaGTE(v string) predicate.Campus
- func AkaHasPrefix(v string) predicate.Campus
- func AkaHasSuffix(v string) predicate.Campus
- func AkaIn(vs ...string) predicate.Campus
- func AkaIsNil() predicate.Campus
- func AkaLT(v string) predicate.Campus
- func AkaLTE(v string) predicate.Campus
- func AkaNEQ(v string) predicate.Campus
- func AkaNotIn(vs ...string) predicate.Campus
- func AkaNotNil() predicate.Campus
- func And(predicates ...predicate.Campus) predicate.Campus
- func City(v string) predicate.Campus
- func CityContains(v string) predicate.Campus
- func CityContainsFold(v string) predicate.Campus
- func CityEQ(v string) predicate.Campus
- func CityEqualFold(v string) predicate.Campus
- func CityGT(v string) predicate.Campus
- func CityGTE(v string) predicate.Campus
- func CityHasPrefix(v string) predicate.Campus
- func CityHasSuffix(v string) predicate.Campus
- func CityIn(vs ...string) predicate.Campus
- func CityIsNil() predicate.Campus
- func CityLT(v string) predicate.Campus
- func CityLTE(v string) predicate.Campus
- func CityNEQ(v string) predicate.Campus
- func CityNotIn(vs ...string) predicate.Campus
- func CityNotNil() predicate.Campus
- func Country(v string) predicate.Campus
- func CountryContains(v string) predicate.Campus
- func CountryContainsFold(v string) predicate.Campus
- func CountryEQ(v string) predicate.Campus
- func CountryEqualFold(v string) predicate.Campus
- func CountryGT(v string) predicate.Campus
- func CountryGTE(v string) predicate.Campus
- func CountryHasPrefix(v string) predicate.Campus
- func CountryHasSuffix(v string) predicate.Campus
- func CountryIn(vs ...string) predicate.Campus
- func CountryIsNil() predicate.Campus
- func CountryLT(v string) predicate.Campus
- func CountryLTE(v string) predicate.Campus
- func CountryNEQ(v string) predicate.Campus
- func CountryNotIn(vs ...string) predicate.Campus
- func CountryNotNil() predicate.Campus
- func Created(v time.Time) predicate.Campus
- func CreatedEQ(v time.Time) predicate.Campus
- func CreatedGT(v time.Time) predicate.Campus
- func CreatedGTE(v time.Time) predicate.Campus
- func CreatedIn(vs ...time.Time) predicate.Campus
- func CreatedLT(v time.Time) predicate.Campus
- func CreatedLTE(v time.Time) predicate.Campus
- func CreatedNEQ(v time.Time) predicate.Campus
- func CreatedNotIn(vs ...time.Time) predicate.Campus
- func HasFacilities() predicate.Campus
- func HasFacilitiesWith(preds ...predicate.Facility) predicate.Campus
- func HasOrganization() predicate.Campus
- func HasOrganizationWith(preds ...predicate.Organization) predicate.Campus
- func ID(id int) predicate.Campus
- func IDEQ(id int) predicate.Campus
- func IDGT(id int) predicate.Campus
- func IDGTE(id int) predicate.Campus
- func IDIn(ids ...int) predicate.Campus
- func IDLT(id int) predicate.Campus
- func IDLTE(id int) predicate.Campus
- func IDNEQ(id int) predicate.Campus
- func IDNotIn(ids ...int) predicate.Campus
- func Logo(v string) predicate.Campus
- func LogoContains(v string) predicate.Campus
- func LogoContainsFold(v string) predicate.Campus
- func LogoEQ(v string) predicate.Campus
- func LogoEqualFold(v string) predicate.Campus
- func LogoGT(v string) predicate.Campus
- func LogoGTE(v string) predicate.Campus
- func LogoHasPrefix(v string) predicate.Campus
- func LogoHasSuffix(v string) predicate.Campus
- func LogoIn(vs ...string) predicate.Campus
- func LogoIsNil() predicate.Campus
- func LogoLT(v string) predicate.Campus
- func LogoLTE(v string) predicate.Campus
- func LogoNEQ(v string) predicate.Campus
- func LogoNotIn(vs ...string) predicate.Campus
- func LogoNotNil() predicate.Campus
- func Name(v string) predicate.Campus
- func NameContains(v string) predicate.Campus
- func NameContainsFold(v string) predicate.Campus
- func NameEQ(v string) predicate.Campus
- func NameEqualFold(v string) predicate.Campus
- func NameFold(v string) predicate.Campus
- func NameFoldContains(v string) predicate.Campus
- func NameFoldContainsFold(v string) predicate.Campus
- func NameFoldEQ(v string) predicate.Campus
- func NameFoldEqualFold(v string) predicate.Campus
- func NameFoldGT(v string) predicate.Campus
- func NameFoldGTE(v string) predicate.Campus
- func NameFoldHasPrefix(v string) predicate.Campus
- func NameFoldHasSuffix(v string) predicate.Campus
- func NameFoldIn(vs ...string) predicate.Campus
- func NameFoldIsNil() predicate.Campus
- func NameFoldLT(v string) predicate.Campus
- func NameFoldLTE(v string) predicate.Campus
- func NameFoldNEQ(v string) predicate.Campus
- func NameFoldNotIn(vs ...string) predicate.Campus
- func NameFoldNotNil() predicate.Campus
- func NameGT(v string) predicate.Campus
- func NameGTE(v string) predicate.Campus
- func NameHasPrefix(v string) predicate.Campus
- func NameHasSuffix(v string) predicate.Campus
- func NameIn(vs ...string) predicate.Campus
- func NameLT(v string) predicate.Campus
- func NameLTE(v string) predicate.Campus
- func NameLong(v string) predicate.Campus
- func NameLongContains(v string) predicate.Campus
- func NameLongContainsFold(v string) predicate.Campus
- func NameLongEQ(v string) predicate.Campus
- func NameLongEqualFold(v string) predicate.Campus
- func NameLongGT(v string) predicate.Campus
- func NameLongGTE(v string) predicate.Campus
- func NameLongHasPrefix(v string) predicate.Campus
- func NameLongHasSuffix(v string) predicate.Campus
- func NameLongIn(vs ...string) predicate.Campus
- func NameLongIsNil() predicate.Campus
- func NameLongLT(v string) predicate.Campus
- func NameLongLTE(v string) predicate.Campus
- func NameLongNEQ(v string) predicate.Campus
- func NameLongNotIn(vs ...string) predicate.Campus
- func NameLongNotNil() predicate.Campus
- func NameNEQ(v string) predicate.Campus
- func NameNotIn(vs ...string) predicate.Campus
- func Not(p predicate.Campus) predicate.Campus
- func Notes(v string) predicate.Campus
- func NotesContains(v string) predicate.Campus
- func NotesContainsFold(v string) predicate.Campus
- func NotesEQ(v string) predicate.Campus
- func NotesEqualFold(v string) predicate.Campus
- func NotesGT(v string) predicate.Campus
- func NotesGTE(v string) predicate.Campus
- func NotesHasPrefix(v string) predicate.Campus
- func NotesHasSuffix(v string) predicate.Campus
- func NotesIn(vs ...string) predicate.Campus
- func NotesIsNil() predicate.Campus
- func NotesLT(v string) predicate.Campus
- func NotesLTE(v string) predicate.Campus
- func NotesNEQ(v string) predicate.Campus
- func NotesNotIn(vs ...string) predicate.Campus
- func NotesNotNil() predicate.Campus
- func Or(predicates ...predicate.Campus) predicate.Campus
- func OrgID(v int) predicate.Campus
- func OrgIDEQ(v int) predicate.Campus
- func OrgIDIn(vs ...int) predicate.Campus
- func OrgIDIsNil() predicate.Campus
- func OrgIDNEQ(v int) predicate.Campus
- func OrgIDNotIn(vs ...int) predicate.Campus
- func OrgIDNotNil() predicate.Campus
- func OrgName(v string) predicate.Campus
- func OrgNameContains(v string) predicate.Campus
- func OrgNameContainsFold(v string) predicate.Campus
- func OrgNameEQ(v string) predicate.Campus
- func OrgNameEqualFold(v string) predicate.Campus
- func OrgNameGT(v string) predicate.Campus
- func OrgNameGTE(v string) predicate.Campus
- func OrgNameHasPrefix(v string) predicate.Campus
- func OrgNameHasSuffix(v string) predicate.Campus
- func OrgNameIn(vs ...string) predicate.Campus
- func OrgNameIsNil() predicate.Campus
- func OrgNameLT(v string) predicate.Campus
- func OrgNameLTE(v string) predicate.Campus
- func OrgNameNEQ(v string) predicate.Campus
- func OrgNameNotIn(vs ...string) predicate.Campus
- func OrgNameNotNil() predicate.Campus
- func SocialMediaIsNil() predicate.Campus
- func SocialMediaNotNil() predicate.Campus
- func State(v string) predicate.Campus
- func StateContains(v string) predicate.Campus
- func StateContainsFold(v string) predicate.Campus
- func StateEQ(v string) predicate.Campus
- func StateEqualFold(v string) predicate.Campus
- func StateGT(v string) predicate.Campus
- func StateGTE(v string) predicate.Campus
- func StateHasPrefix(v string) predicate.Campus
- func StateHasSuffix(v string) predicate.Campus
- func StateIn(vs ...string) predicate.Campus
- func StateIsNil() predicate.Campus
- func StateLT(v string) predicate.Campus
- func StateLTE(v string) predicate.Campus
- func StateNEQ(v string) predicate.Campus
- func StateNotIn(vs ...string) predicate.Campus
- func StateNotNil() predicate.Campus
- func Status(v string) predicate.Campus
- func StatusContains(v string) predicate.Campus
- func StatusContainsFold(v string) predicate.Campus
- func StatusEQ(v string) predicate.Campus
- func StatusEqualFold(v string) predicate.Campus
- func StatusGT(v string) predicate.Campus
- func StatusGTE(v string) predicate.Campus
- func StatusHasPrefix(v string) predicate.Campus
- func StatusHasSuffix(v string) predicate.Campus
- func StatusIn(vs ...string) predicate.Campus
- func StatusLT(v string) predicate.Campus
- func StatusLTE(v string) predicate.Campus
- func StatusNEQ(v string) predicate.Campus
- func StatusNotIn(vs ...string) predicate.Campus
- func Updated(v time.Time) predicate.Campus
- func UpdatedEQ(v time.Time) predicate.Campus
- func UpdatedGT(v time.Time) predicate.Campus
- func UpdatedGTE(v time.Time) predicate.Campus
- func UpdatedIn(vs ...time.Time) predicate.Campus
- func UpdatedLT(v time.Time) predicate.Campus
- func UpdatedLTE(v time.Time) predicate.Campus
- func UpdatedNEQ(v time.Time) predicate.Campus
- func UpdatedNotIn(vs ...time.Time) predicate.Campus
- func ValidColumn(column string) bool
- func Website(v string) predicate.Campus
- func WebsiteContains(v string) predicate.Campus
- func WebsiteContainsFold(v string) predicate.Campus
- func WebsiteEQ(v string) predicate.Campus
- func WebsiteEqualFold(v string) predicate.Campus
- func WebsiteGT(v string) predicate.Campus
- func WebsiteGTE(v string) predicate.Campus
- func WebsiteHasPrefix(v string) predicate.Campus
- func WebsiteHasSuffix(v string) predicate.Campus
- func WebsiteIn(vs ...string) predicate.Campus
- func WebsiteIsNil() predicate.Campus
- func WebsiteLT(v string) predicate.Campus
- func WebsiteLTE(v string) predicate.Campus
- func WebsiteNEQ(v string) predicate.Campus
- func WebsiteNotIn(vs ...string) predicate.Campus
- func WebsiteNotNil() predicate.Campus
- func Zipcode(v string) predicate.Campus
- func ZipcodeContains(v string) predicate.Campus
- func ZipcodeContainsFold(v string) predicate.Campus
- func ZipcodeEQ(v string) predicate.Campus
- func ZipcodeEqualFold(v string) predicate.Campus
- func ZipcodeGT(v string) predicate.Campus
- func ZipcodeGTE(v string) predicate.Campus
- func ZipcodeHasPrefix(v string) predicate.Campus
- func ZipcodeHasSuffix(v string) predicate.Campus
- func ZipcodeIn(vs ...string) predicate.Campus
- func ZipcodeIsNil() predicate.Campus
- func ZipcodeLT(v string) predicate.Campus
- func ZipcodeLTE(v string) predicate.Campus
- func ZipcodeNEQ(v string) predicate.Campus
- func ZipcodeNotIn(vs ...string) predicate.Campus
- func ZipcodeNotNil() predicate.Campus
- type OrderOption
- func ByAka(opts ...sql.OrderTermOption) OrderOption
- func ByCity(opts ...sql.OrderTermOption) OrderOption
- func ByCountry(opts ...sql.OrderTermOption) OrderOption
- func ByCreated(opts ...sql.OrderTermOption) OrderOption
- func ByFacilities(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByFacilitiesCount(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByLogo(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByNameFold(opts ...sql.OrderTermOption) OrderOption
- func ByNameLong(opts ...sql.OrderTermOption) OrderOption
- func ByNotes(opts ...sql.OrderTermOption) OrderOption
- func ByOrgID(opts ...sql.OrderTermOption) OrderOption
- func ByOrgName(opts ...sql.OrderTermOption) OrderOption
- func ByOrganizationField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByState(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByUpdated(opts ...sql.OrderTermOption) OrderOption
- func ByWebsite(opts ...sql.OrderTermOption) OrderOption
- func ByZipcode(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the campus type in the database. Label = "campus" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldNameFold holds the string denoting the name_fold field in the database. FieldNameFold = "name_fold" // FieldOrgID holds the string denoting the org_id field in the database. FieldOrgID = "org_id" // FieldAka holds the string denoting the aka field in the database. FieldAka = "aka" // FieldCity holds the string denoting the city field in the database. FieldCity = "city" // FieldCountry holds the string denoting the country field in the database. FieldCountry = "country" // FieldLogo holds the string denoting the logo field in the database. FieldLogo = "logo" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldNameLong holds the string denoting the name_long field in the database. FieldNameLong = "name_long" // FieldNotes holds the string denoting the notes field in the database. FieldNotes = "notes" // FieldSocialMedia holds the string denoting the social_media field in the database. FieldSocialMedia = "social_media" // FieldState holds the string denoting the state field in the database. FieldState = "state" // FieldWebsite holds the string denoting the website field in the database. FieldWebsite = "website" // FieldZipcode holds the string denoting the zipcode field in the database. FieldZipcode = "zipcode" // FieldOrgName holds the string denoting the org_name field in the database. FieldOrgName = "org_name" // FieldCreated holds the string denoting the created field in the database. FieldCreated = "created" // FieldUpdated holds the string denoting the updated field in the database. FieldUpdated = "updated" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // EdgeFacilities holds the string denoting the facilities edge name in mutations. EdgeFacilities = "facilities" // EdgeOrganization holds the string denoting the organization edge name in mutations. EdgeOrganization = "organization" // Table holds the table name of the campus in the database. Table = "campuses" // FacilitiesTable is the table that holds the facilities relation/edge. FacilitiesTable = "facilities" // FacilitiesInverseTable is the table name for the Facility entity. // It exists in this package in order to avoid circular dependency with the "facility" package. FacilitiesInverseTable = "facilities" // FacilitiesColumn is the table column denoting the facilities relation/edge. FacilitiesColumn = "campus_id" // OrganizationTable is the table that holds the organization relation/edge. OrganizationTable = "campuses" // OrganizationInverseTable is the table name for the Organization entity. // It exists in this package in order to avoid circular dependency with the "organization" package. OrganizationInverseTable = "organizations" // OrganizationColumn is the table column denoting the organization relation/edge. OrganizationColumn = "org_id" )
Variables ¶
var ( // DefaultNameFold holds the default value on creation for the "name_fold" field. DefaultNameFold string // DefaultCity holds the default value on creation for the "city" field. DefaultCity string // DefaultCountry holds the default value on creation for the "country" field. DefaultCountry string // DefaultNotes holds the default value on creation for the "notes" field. DefaultNotes string // DefaultState holds the default value on creation for the "state" field. DefaultState string // DefaultWebsite holds the default value on creation for the "website" field. DefaultWebsite string // DefaultZipcode holds the default value on creation for the "zipcode" field. DefaultZipcode string // DefaultOrgName holds the default value on creation for the "org_name" field. DefaultOrgName string // DefaultStatus holds the default value on creation for the "status" field. DefaultStatus string // IDValidator is a validator for the "id" field. It is called by the builders before save. IDValidator func(int) error )
var Columns = []string{ FieldID, FieldNameFold, FieldOrgID, FieldAka, FieldCity, FieldCountry, FieldLogo, FieldName, FieldNameLong, FieldNotes, FieldSocialMedia, FieldState, FieldWebsite, FieldZipcode, FieldOrgName, FieldCreated, FieldUpdated, FieldStatus, }
Columns holds all SQL columns for campus fields.
Functions ¶
func AkaContains ¶
AkaContains applies the Contains predicate on the "aka" field.
func AkaContainsFold ¶
AkaContainsFold applies the ContainsFold predicate on the "aka" field.
func AkaEqualFold ¶
AkaEqualFold applies the EqualFold predicate on the "aka" field.
func AkaHasPrefix ¶
AkaHasPrefix applies the HasPrefix predicate on the "aka" field.
func AkaHasSuffix ¶
AkaHasSuffix applies the HasSuffix predicate on the "aka" field.
func CityContains ¶
CityContains applies the Contains predicate on the "city" field.
func CityContainsFold ¶
CityContainsFold applies the ContainsFold predicate on the "city" field.
func CityEqualFold ¶
CityEqualFold applies the EqualFold predicate on the "city" field.
func CityHasPrefix ¶
CityHasPrefix applies the HasPrefix predicate on the "city" field.
func CityHasSuffix ¶
CityHasSuffix applies the HasSuffix predicate on the "city" field.
func CityNotNil ¶
CityNotNil applies the NotNil predicate on the "city" field.
func Country ¶
Country applies equality check predicate on the "country" field. It's identical to CountryEQ.
func CountryContains ¶
CountryContains applies the Contains predicate on the "country" field.
func CountryContainsFold ¶
CountryContainsFold applies the ContainsFold predicate on the "country" field.
func CountryEqualFold ¶
CountryEqualFold applies the EqualFold predicate on the "country" field.
func CountryGTE ¶
CountryGTE applies the GTE predicate on the "country" field.
func CountryHasPrefix ¶
CountryHasPrefix applies the HasPrefix predicate on the "country" field.
func CountryHasSuffix ¶
CountryHasSuffix applies the HasSuffix predicate on the "country" field.
func CountryIsNil ¶
CountryIsNil applies the IsNil predicate on the "country" field.
func CountryLTE ¶
CountryLTE applies the LTE predicate on the "country" field.
func CountryNEQ ¶
CountryNEQ applies the NEQ predicate on the "country" field.
func CountryNotIn ¶
CountryNotIn applies the NotIn predicate on the "country" field.
func CountryNotNil ¶
CountryNotNil applies the NotNil predicate on the "country" field.
func Created ¶
Created applies equality check predicate on the "created" field. It's identical to CreatedEQ.
func CreatedGTE ¶
CreatedGTE applies the GTE predicate on the "created" field.
func CreatedLTE ¶
CreatedLTE applies the LTE predicate on the "created" field.
func CreatedNEQ ¶
CreatedNEQ applies the NEQ predicate on the "created" field.
func CreatedNotIn ¶
CreatedNotIn applies the NotIn predicate on the "created" field.
func HasFacilities ¶
HasFacilities applies the HasEdge predicate on the "facilities" edge.
func HasFacilitiesWith ¶
HasFacilitiesWith applies the HasEdge predicate on the "facilities" edge with a given conditions (other predicates).
func HasOrganization ¶
HasOrganization applies the HasEdge predicate on the "organization" edge.
func HasOrganizationWith ¶
func HasOrganizationWith(preds ...predicate.Organization) predicate.Campus
HasOrganizationWith applies the HasEdge predicate on the "organization" edge with a given conditions (other predicates).
func LogoContains ¶
LogoContains applies the Contains predicate on the "logo" field.
func LogoContainsFold ¶
LogoContainsFold applies the ContainsFold predicate on the "logo" field.
func LogoEqualFold ¶
LogoEqualFold applies the EqualFold predicate on the "logo" field.
func LogoHasPrefix ¶
LogoHasPrefix applies the HasPrefix predicate on the "logo" field.
func LogoHasSuffix ¶
LogoHasSuffix applies the HasSuffix predicate on the "logo" field.
func LogoNotNil ¶
LogoNotNil applies the NotNil predicate on the "logo" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameFold ¶ added in v1.16.0
NameFold applies equality check predicate on the "name_fold" field. It's identical to NameFoldEQ.
func NameFoldContains ¶ added in v1.16.0
NameFoldContains applies the Contains predicate on the "name_fold" field.
func NameFoldContainsFold ¶ added in v1.16.0
NameFoldContainsFold applies the ContainsFold predicate on the "name_fold" field.
func NameFoldEQ ¶ added in v1.16.0
NameFoldEQ applies the EQ predicate on the "name_fold" field.
func NameFoldEqualFold ¶ added in v1.16.0
NameFoldEqualFold applies the EqualFold predicate on the "name_fold" field.
func NameFoldGT ¶ added in v1.16.0
NameFoldGT applies the GT predicate on the "name_fold" field.
func NameFoldGTE ¶ added in v1.16.0
NameFoldGTE applies the GTE predicate on the "name_fold" field.
func NameFoldHasPrefix ¶ added in v1.16.0
NameFoldHasPrefix applies the HasPrefix predicate on the "name_fold" field.
func NameFoldHasSuffix ¶ added in v1.16.0
NameFoldHasSuffix applies the HasSuffix predicate on the "name_fold" field.
func NameFoldIn ¶ added in v1.16.0
NameFoldIn applies the In predicate on the "name_fold" field.
func NameFoldIsNil ¶ added in v1.16.0
NameFoldIsNil applies the IsNil predicate on the "name_fold" field.
func NameFoldLT ¶ added in v1.16.0
NameFoldLT applies the LT predicate on the "name_fold" field.
func NameFoldLTE ¶ added in v1.16.0
NameFoldLTE applies the LTE predicate on the "name_fold" field.
func NameFoldNEQ ¶ added in v1.16.0
NameFoldNEQ applies the NEQ predicate on the "name_fold" field.
func NameFoldNotIn ¶ added in v1.16.0
NameFoldNotIn applies the NotIn predicate on the "name_fold" field.
func NameFoldNotNil ¶ added in v1.16.0
NameFoldNotNil applies the NotNil predicate on the "name_fold" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NameLong ¶
NameLong applies equality check predicate on the "name_long" field. It's identical to NameLongEQ.
func NameLongContains ¶
NameLongContains applies the Contains predicate on the "name_long" field.
func NameLongContainsFold ¶
NameLongContainsFold applies the ContainsFold predicate on the "name_long" field.
func NameLongEQ ¶
NameLongEQ applies the EQ predicate on the "name_long" field.
func NameLongEqualFold ¶
NameLongEqualFold applies the EqualFold predicate on the "name_long" field.
func NameLongGT ¶
NameLongGT applies the GT predicate on the "name_long" field.
func NameLongGTE ¶
NameLongGTE applies the GTE predicate on the "name_long" field.
func NameLongHasPrefix ¶
NameLongHasPrefix applies the HasPrefix predicate on the "name_long" field.
func NameLongHasSuffix ¶
NameLongHasSuffix applies the HasSuffix predicate on the "name_long" field.
func NameLongIn ¶
NameLongIn applies the In predicate on the "name_long" field.
func NameLongIsNil ¶
NameLongIsNil applies the IsNil predicate on the "name_long" field.
func NameLongLT ¶
NameLongLT applies the LT predicate on the "name_long" field.
func NameLongLTE ¶
NameLongLTE applies the LTE predicate on the "name_long" field.
func NameLongNEQ ¶
NameLongNEQ applies the NEQ predicate on the "name_long" field.
func NameLongNotIn ¶
NameLongNotIn applies the NotIn predicate on the "name_long" field.
func NameLongNotNil ¶
NameLongNotNil applies the NotNil predicate on the "name_long" field.
func Notes ¶
Notes applies equality check predicate on the "notes" field. It's identical to NotesEQ.
func NotesContains ¶
NotesContains applies the Contains predicate on the "notes" field.
func NotesContainsFold ¶
NotesContainsFold applies the ContainsFold predicate on the "notes" field.
func NotesEqualFold ¶
NotesEqualFold applies the EqualFold predicate on the "notes" field.
func NotesHasPrefix ¶
NotesHasPrefix applies the HasPrefix predicate on the "notes" field.
func NotesHasSuffix ¶
NotesHasSuffix applies the HasSuffix predicate on the "notes" field.
func NotesIsNil ¶
NotesIsNil applies the IsNil predicate on the "notes" field.
func NotesNotIn ¶
NotesNotIn applies the NotIn predicate on the "notes" field.
func NotesNotNil ¶
NotesNotNil applies the NotNil predicate on the "notes" field.
func OrgID ¶
OrgID applies equality check predicate on the "org_id" field. It's identical to OrgIDEQ.
func OrgIDIsNil ¶
OrgIDIsNil applies the IsNil predicate on the "org_id" field.
func OrgIDNotIn ¶
OrgIDNotIn applies the NotIn predicate on the "org_id" field.
func OrgIDNotNil ¶
OrgIDNotNil applies the NotNil predicate on the "org_id" field.
func OrgName ¶
OrgName applies equality check predicate on the "org_name" field. It's identical to OrgNameEQ.
func OrgNameContains ¶
OrgNameContains applies the Contains predicate on the "org_name" field.
func OrgNameContainsFold ¶
OrgNameContainsFold applies the ContainsFold predicate on the "org_name" field.
func OrgNameEqualFold ¶
OrgNameEqualFold applies the EqualFold predicate on the "org_name" field.
func OrgNameGTE ¶
OrgNameGTE applies the GTE predicate on the "org_name" field.
func OrgNameHasPrefix ¶
OrgNameHasPrefix applies the HasPrefix predicate on the "org_name" field.
func OrgNameHasSuffix ¶
OrgNameHasSuffix applies the HasSuffix predicate on the "org_name" field.
func OrgNameIsNil ¶
OrgNameIsNil applies the IsNil predicate on the "org_name" field.
func OrgNameLTE ¶
OrgNameLTE applies the LTE predicate on the "org_name" field.
func OrgNameNEQ ¶
OrgNameNEQ applies the NEQ predicate on the "org_name" field.
func OrgNameNotIn ¶
OrgNameNotIn applies the NotIn predicate on the "org_name" field.
func OrgNameNotNil ¶
OrgNameNotNil applies the NotNil predicate on the "org_name" field.
func SocialMediaIsNil ¶
SocialMediaIsNil applies the IsNil predicate on the "social_media" field.
func SocialMediaNotNil ¶
SocialMediaNotNil applies the NotNil predicate on the "social_media" field.
func State ¶
State applies equality check predicate on the "state" field. It's identical to StateEQ.
func StateContains ¶
StateContains applies the Contains predicate on the "state" field.
func StateContainsFold ¶
StateContainsFold applies the ContainsFold predicate on the "state" field.
func StateEqualFold ¶
StateEqualFold applies the EqualFold predicate on the "state" field.
func StateHasPrefix ¶
StateHasPrefix applies the HasPrefix predicate on the "state" field.
func StateHasSuffix ¶
StateHasSuffix applies the HasSuffix predicate on the "state" field.
func StateIsNil ¶
StateIsNil applies the IsNil predicate on the "state" field.
func StateNotIn ¶
StateNotIn applies the NotIn predicate on the "state" field.
func StateNotNil ¶
StateNotNil applies the NotNil predicate on the "state" field.
func Status ¶
Status applies equality check predicate on the "status" field. It's identical to StatusEQ.
func StatusContains ¶
StatusContains applies the Contains predicate on the "status" field.
func StatusContainsFold ¶
StatusContainsFold applies the ContainsFold predicate on the "status" field.
func StatusEqualFold ¶
StatusEqualFold applies the EqualFold predicate on the "status" field.
func StatusHasPrefix ¶
StatusHasPrefix applies the HasPrefix predicate on the "status" field.
func StatusHasSuffix ¶
StatusHasSuffix applies the HasSuffix predicate on the "status" field.
func StatusNotIn ¶
StatusNotIn applies the NotIn predicate on the "status" field.
func Updated ¶
Updated applies equality check predicate on the "updated" field. It's identical to UpdatedEQ.
func UpdatedGTE ¶
UpdatedGTE applies the GTE predicate on the "updated" field.
func UpdatedLTE ¶
UpdatedLTE applies the LTE predicate on the "updated" field.
func UpdatedNEQ ¶
UpdatedNEQ applies the NEQ predicate on the "updated" field.
func UpdatedNotIn ¶
UpdatedNotIn applies the NotIn predicate on the "updated" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func Website ¶
Website applies equality check predicate on the "website" field. It's identical to WebsiteEQ.
func WebsiteContains ¶
WebsiteContains applies the Contains predicate on the "website" field.
func WebsiteContainsFold ¶
WebsiteContainsFold applies the ContainsFold predicate on the "website" field.
func WebsiteEqualFold ¶
WebsiteEqualFold applies the EqualFold predicate on the "website" field.
func WebsiteGTE ¶
WebsiteGTE applies the GTE predicate on the "website" field.
func WebsiteHasPrefix ¶
WebsiteHasPrefix applies the HasPrefix predicate on the "website" field.
func WebsiteHasSuffix ¶
WebsiteHasSuffix applies the HasSuffix predicate on the "website" field.
func WebsiteIsNil ¶
WebsiteIsNil applies the IsNil predicate on the "website" field.
func WebsiteLTE ¶
WebsiteLTE applies the LTE predicate on the "website" field.
func WebsiteNEQ ¶
WebsiteNEQ applies the NEQ predicate on the "website" field.
func WebsiteNotIn ¶
WebsiteNotIn applies the NotIn predicate on the "website" field.
func WebsiteNotNil ¶
WebsiteNotNil applies the NotNil predicate on the "website" field.
func Zipcode ¶
Zipcode applies equality check predicate on the "zipcode" field. It's identical to ZipcodeEQ.
func ZipcodeContains ¶
ZipcodeContains applies the Contains predicate on the "zipcode" field.
func ZipcodeContainsFold ¶
ZipcodeContainsFold applies the ContainsFold predicate on the "zipcode" field.
func ZipcodeEqualFold ¶
ZipcodeEqualFold applies the EqualFold predicate on the "zipcode" field.
func ZipcodeGTE ¶
ZipcodeGTE applies the GTE predicate on the "zipcode" field.
func ZipcodeHasPrefix ¶
ZipcodeHasPrefix applies the HasPrefix predicate on the "zipcode" field.
func ZipcodeHasSuffix ¶
ZipcodeHasSuffix applies the HasSuffix predicate on the "zipcode" field.
func ZipcodeIsNil ¶
ZipcodeIsNil applies the IsNil predicate on the "zipcode" field.
func ZipcodeLTE ¶
ZipcodeLTE applies the LTE predicate on the "zipcode" field.
func ZipcodeNEQ ¶
ZipcodeNEQ applies the NEQ predicate on the "zipcode" field.
func ZipcodeNotIn ¶
ZipcodeNotIn applies the NotIn predicate on the "zipcode" field.
func ZipcodeNotNil ¶
ZipcodeNotNil applies the NotNil predicate on the "zipcode" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Campus queries.
func ByAka ¶
func ByAka(opts ...sql.OrderTermOption) OrderOption
ByAka orders the results by the aka field.
func ByCity ¶
func ByCity(opts ...sql.OrderTermOption) OrderOption
ByCity orders the results by the city field.
func ByCountry ¶
func ByCountry(opts ...sql.OrderTermOption) OrderOption
ByCountry orders the results by the country field.
func ByCreated ¶
func ByCreated(opts ...sql.OrderTermOption) OrderOption
ByCreated orders the results by the created field.
func ByFacilities ¶
func ByFacilities(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByFacilities orders the results by facilities terms.
func ByFacilitiesCount ¶
func ByFacilitiesCount(opts ...sql.OrderTermOption) OrderOption
ByFacilitiesCount orders the results by facilities count.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByLogo ¶
func ByLogo(opts ...sql.OrderTermOption) OrderOption
ByLogo orders the results by the logo field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByNameFold ¶ added in v1.16.0
func ByNameFold(opts ...sql.OrderTermOption) OrderOption
ByNameFold orders the results by the name_fold field.
func ByNameLong ¶
func ByNameLong(opts ...sql.OrderTermOption) OrderOption
ByNameLong orders the results by the name_long field.
func ByNotes ¶
func ByNotes(opts ...sql.OrderTermOption) OrderOption
ByNotes orders the results by the notes field.
func ByOrgID ¶
func ByOrgID(opts ...sql.OrderTermOption) OrderOption
ByOrgID orders the results by the org_id field.
func ByOrgName ¶
func ByOrgName(opts ...sql.OrderTermOption) OrderOption
ByOrgName orders the results by the org_name field.
func ByOrganizationField ¶
func ByOrganizationField(field string, opts ...sql.OrderTermOption) OrderOption
ByOrganizationField orders the results by organization field.
func ByState ¶
func ByState(opts ...sql.OrderTermOption) OrderOption
ByState orders the results by the state field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByUpdated ¶
func ByUpdated(opts ...sql.OrderTermOption) OrderOption
ByUpdated orders the results by the updated field.
func ByWebsite ¶
func ByWebsite(opts ...sql.OrderTermOption) OrderOption
ByWebsite orders the results by the website field.
func ByZipcode ¶
func ByZipcode(opts ...sql.OrderTermOption) OrderOption
ByZipcode orders the results by the zipcode field.