Documentation
¶
Index ¶
- Constants
- Variables
- func Aka(v string) predicate.Carrier
- func AkaContains(v string) predicate.Carrier
- func AkaContainsFold(v string) predicate.Carrier
- func AkaEQ(v string) predicate.Carrier
- func AkaEqualFold(v string) predicate.Carrier
- func AkaFold(v string) predicate.Carrier
- func AkaFoldContains(v string) predicate.Carrier
- func AkaFoldContainsFold(v string) predicate.Carrier
- func AkaFoldEQ(v string) predicate.Carrier
- func AkaFoldEqualFold(v string) predicate.Carrier
- func AkaFoldGT(v string) predicate.Carrier
- func AkaFoldGTE(v string) predicate.Carrier
- func AkaFoldHasPrefix(v string) predicate.Carrier
- func AkaFoldHasSuffix(v string) predicate.Carrier
- func AkaFoldIn(vs ...string) predicate.Carrier
- func AkaFoldIsNil() predicate.Carrier
- func AkaFoldLT(v string) predicate.Carrier
- func AkaFoldLTE(v string) predicate.Carrier
- func AkaFoldNEQ(v string) predicate.Carrier
- func AkaFoldNotIn(vs ...string) predicate.Carrier
- func AkaFoldNotNil() predicate.Carrier
- func AkaGT(v string) predicate.Carrier
- func AkaGTE(v string) predicate.Carrier
- func AkaHasPrefix(v string) predicate.Carrier
- func AkaHasSuffix(v string) predicate.Carrier
- func AkaIn(vs ...string) predicate.Carrier
- func AkaIsNil() predicate.Carrier
- func AkaLT(v string) predicate.Carrier
- func AkaLTE(v string) predicate.Carrier
- func AkaNEQ(v string) predicate.Carrier
- func AkaNotIn(vs ...string) predicate.Carrier
- func AkaNotNil() predicate.Carrier
- func And(predicates ...predicate.Carrier) predicate.Carrier
- func Created(v time.Time) predicate.Carrier
- func CreatedEQ(v time.Time) predicate.Carrier
- func CreatedGT(v time.Time) predicate.Carrier
- func CreatedGTE(v time.Time) predicate.Carrier
- func CreatedIn(vs ...time.Time) predicate.Carrier
- func CreatedLT(v time.Time) predicate.Carrier
- func CreatedLTE(v time.Time) predicate.Carrier
- func CreatedNEQ(v time.Time) predicate.Carrier
- func CreatedNotIn(vs ...time.Time) predicate.Carrier
- func FacCount(v int) predicate.Carrier
- func FacCountEQ(v int) predicate.Carrier
- func FacCountGT(v int) predicate.Carrier
- func FacCountGTE(v int) predicate.Carrier
- func FacCountIn(vs ...int) predicate.Carrier
- func FacCountIsNil() predicate.Carrier
- func FacCountLT(v int) predicate.Carrier
- func FacCountLTE(v int) predicate.Carrier
- func FacCountNEQ(v int) predicate.Carrier
- func FacCountNotIn(vs ...int) predicate.Carrier
- func FacCountNotNil() predicate.Carrier
- func HasCarrierFacilities() predicate.Carrier
- func HasCarrierFacilitiesWith(preds ...predicate.CarrierFacility) predicate.Carrier
- func HasOrganization() predicate.Carrier
- func HasOrganizationWith(preds ...predicate.Organization) predicate.Carrier
- func ID(id int) predicate.Carrier
- func IDEQ(id int) predicate.Carrier
- func IDGT(id int) predicate.Carrier
- func IDGTE(id int) predicate.Carrier
- func IDIn(ids ...int) predicate.Carrier
- func IDLT(id int) predicate.Carrier
- func IDLTE(id int) predicate.Carrier
- func IDNEQ(id int) predicate.Carrier
- func IDNotIn(ids ...int) predicate.Carrier
- func Logo(v string) predicate.Carrier
- func LogoContains(v string) predicate.Carrier
- func LogoContainsFold(v string) predicate.Carrier
- func LogoEQ(v string) predicate.Carrier
- func LogoEqualFold(v string) predicate.Carrier
- func LogoGT(v string) predicate.Carrier
- func LogoGTE(v string) predicate.Carrier
- func LogoHasPrefix(v string) predicate.Carrier
- func LogoHasSuffix(v string) predicate.Carrier
- func LogoIn(vs ...string) predicate.Carrier
- func LogoIsNil() predicate.Carrier
- func LogoLT(v string) predicate.Carrier
- func LogoLTE(v string) predicate.Carrier
- func LogoNEQ(v string) predicate.Carrier
- func LogoNotIn(vs ...string) predicate.Carrier
- func LogoNotNil() predicate.Carrier
- func Name(v string) predicate.Carrier
- func NameContains(v string) predicate.Carrier
- func NameContainsFold(v string) predicate.Carrier
- func NameEQ(v string) predicate.Carrier
- func NameEqualFold(v string) predicate.Carrier
- func NameFold(v string) predicate.Carrier
- func NameFoldContains(v string) predicate.Carrier
- func NameFoldContainsFold(v string) predicate.Carrier
- func NameFoldEQ(v string) predicate.Carrier
- func NameFoldEqualFold(v string) predicate.Carrier
- func NameFoldGT(v string) predicate.Carrier
- func NameFoldGTE(v string) predicate.Carrier
- func NameFoldHasPrefix(v string) predicate.Carrier
- func NameFoldHasSuffix(v string) predicate.Carrier
- func NameFoldIn(vs ...string) predicate.Carrier
- func NameFoldIsNil() predicate.Carrier
- func NameFoldLT(v string) predicate.Carrier
- func NameFoldLTE(v string) predicate.Carrier
- func NameFoldNEQ(v string) predicate.Carrier
- func NameFoldNotIn(vs ...string) predicate.Carrier
- func NameFoldNotNil() predicate.Carrier
- func NameGT(v string) predicate.Carrier
- func NameGTE(v string) predicate.Carrier
- func NameHasPrefix(v string) predicate.Carrier
- func NameHasSuffix(v string) predicate.Carrier
- func NameIn(vs ...string) predicate.Carrier
- func NameLT(v string) predicate.Carrier
- func NameLTE(v string) predicate.Carrier
- func NameLong(v string) predicate.Carrier
- func NameLongContains(v string) predicate.Carrier
- func NameLongContainsFold(v string) predicate.Carrier
- func NameLongEQ(v string) predicate.Carrier
- func NameLongEqualFold(v string) predicate.Carrier
- func NameLongGT(v string) predicate.Carrier
- func NameLongGTE(v string) predicate.Carrier
- func NameLongHasPrefix(v string) predicate.Carrier
- func NameLongHasSuffix(v string) predicate.Carrier
- func NameLongIn(vs ...string) predicate.Carrier
- func NameLongIsNil() predicate.Carrier
- func NameLongLT(v string) predicate.Carrier
- func NameLongLTE(v string) predicate.Carrier
- func NameLongNEQ(v string) predicate.Carrier
- func NameLongNotIn(vs ...string) predicate.Carrier
- func NameLongNotNil() predicate.Carrier
- func NameNEQ(v string) predicate.Carrier
- func NameNotIn(vs ...string) predicate.Carrier
- func Not(p predicate.Carrier) predicate.Carrier
- func Notes(v string) predicate.Carrier
- func NotesContains(v string) predicate.Carrier
- func NotesContainsFold(v string) predicate.Carrier
- func NotesEQ(v string) predicate.Carrier
- func NotesEqualFold(v string) predicate.Carrier
- func NotesGT(v string) predicate.Carrier
- func NotesGTE(v string) predicate.Carrier
- func NotesHasPrefix(v string) predicate.Carrier
- func NotesHasSuffix(v string) predicate.Carrier
- func NotesIn(vs ...string) predicate.Carrier
- func NotesIsNil() predicate.Carrier
- func NotesLT(v string) predicate.Carrier
- func NotesLTE(v string) predicate.Carrier
- func NotesNEQ(v string) predicate.Carrier
- func NotesNotIn(vs ...string) predicate.Carrier
- func NotesNotNil() predicate.Carrier
- func Or(predicates ...predicate.Carrier) predicate.Carrier
- func OrgID(v int) predicate.Carrier
- func OrgIDEQ(v int) predicate.Carrier
- func OrgIDIn(vs ...int) predicate.Carrier
- func OrgIDIsNil() predicate.Carrier
- func OrgIDNEQ(v int) predicate.Carrier
- func OrgIDNotIn(vs ...int) predicate.Carrier
- func OrgIDNotNil() predicate.Carrier
- func OrgName(v string) predicate.Carrier
- func OrgNameContains(v string) predicate.Carrier
- func OrgNameContainsFold(v string) predicate.Carrier
- func OrgNameEQ(v string) predicate.Carrier
- func OrgNameEqualFold(v string) predicate.Carrier
- func OrgNameGT(v string) predicate.Carrier
- func OrgNameGTE(v string) predicate.Carrier
- func OrgNameHasPrefix(v string) predicate.Carrier
- func OrgNameHasSuffix(v string) predicate.Carrier
- func OrgNameIn(vs ...string) predicate.Carrier
- func OrgNameIsNil() predicate.Carrier
- func OrgNameLT(v string) predicate.Carrier
- func OrgNameLTE(v string) predicate.Carrier
- func OrgNameNEQ(v string) predicate.Carrier
- func OrgNameNotIn(vs ...string) predicate.Carrier
- func OrgNameNotNil() predicate.Carrier
- func SocialMediaIsNil() predicate.Carrier
- func SocialMediaNotNil() predicate.Carrier
- func Status(v string) predicate.Carrier
- func StatusContains(v string) predicate.Carrier
- func StatusContainsFold(v string) predicate.Carrier
- func StatusEQ(v string) predicate.Carrier
- func StatusEqualFold(v string) predicate.Carrier
- func StatusGT(v string) predicate.Carrier
- func StatusGTE(v string) predicate.Carrier
- func StatusHasPrefix(v string) predicate.Carrier
- func StatusHasSuffix(v string) predicate.Carrier
- func StatusIn(vs ...string) predicate.Carrier
- func StatusLT(v string) predicate.Carrier
- func StatusLTE(v string) predicate.Carrier
- func StatusNEQ(v string) predicate.Carrier
- func StatusNotIn(vs ...string) predicate.Carrier
- func Updated(v time.Time) predicate.Carrier
- func UpdatedEQ(v time.Time) predicate.Carrier
- func UpdatedGT(v time.Time) predicate.Carrier
- func UpdatedGTE(v time.Time) predicate.Carrier
- func UpdatedIn(vs ...time.Time) predicate.Carrier
- func UpdatedLT(v time.Time) predicate.Carrier
- func UpdatedLTE(v time.Time) predicate.Carrier
- func UpdatedNEQ(v time.Time) predicate.Carrier
- func UpdatedNotIn(vs ...time.Time) predicate.Carrier
- func ValidColumn(column string) bool
- func Website(v string) predicate.Carrier
- func WebsiteContains(v string) predicate.Carrier
- func WebsiteContainsFold(v string) predicate.Carrier
- func WebsiteEQ(v string) predicate.Carrier
- func WebsiteEqualFold(v string) predicate.Carrier
- func WebsiteGT(v string) predicate.Carrier
- func WebsiteGTE(v string) predicate.Carrier
- func WebsiteHasPrefix(v string) predicate.Carrier
- func WebsiteHasSuffix(v string) predicate.Carrier
- func WebsiteIn(vs ...string) predicate.Carrier
- func WebsiteIsNil() predicate.Carrier
- func WebsiteLT(v string) predicate.Carrier
- func WebsiteLTE(v string) predicate.Carrier
- func WebsiteNEQ(v string) predicate.Carrier
- func WebsiteNotIn(vs ...string) predicate.Carrier
- func WebsiteNotNil() predicate.Carrier
- type OrderOption
- func ByAka(opts ...sql.OrderTermOption) OrderOption
- func ByAkaFold(opts ...sql.OrderTermOption) OrderOption
- func ByCarrierFacilities(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByCarrierFacilitiesCount(opts ...sql.OrderTermOption) OrderOption
- func ByCreated(opts ...sql.OrderTermOption) OrderOption
- func ByFacCount(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByLogo(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByNameFold(opts ...sql.OrderTermOption) OrderOption
- func ByNameLong(opts ...sql.OrderTermOption) OrderOption
- func ByNotes(opts ...sql.OrderTermOption) OrderOption
- func ByOrgID(opts ...sql.OrderTermOption) OrderOption
- func ByOrgName(opts ...sql.OrderTermOption) OrderOption
- func ByOrganizationField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByUpdated(opts ...sql.OrderTermOption) OrderOption
- func ByWebsite(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the carrier type in the database. Label = "carrier" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldNameFold holds the string denoting the name_fold field in the database. FieldNameFold = "name_fold" // FieldAkaFold holds the string denoting the aka_fold field in the database. FieldAkaFold = "aka_fold" // FieldOrgID holds the string denoting the org_id field in the database. FieldOrgID = "org_id" // FieldAka holds the string denoting the aka field in the database. FieldAka = "aka" // FieldLogo holds the string denoting the logo field in the database. FieldLogo = "logo" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldNameLong holds the string denoting the name_long field in the database. FieldNameLong = "name_long" // FieldNotes holds the string denoting the notes field in the database. FieldNotes = "notes" // FieldSocialMedia holds the string denoting the social_media field in the database. FieldSocialMedia = "social_media" // FieldWebsite holds the string denoting the website field in the database. FieldWebsite = "website" // FieldOrgName holds the string denoting the org_name field in the database. FieldOrgName = "org_name" // FieldFacCount holds the string denoting the fac_count field in the database. FieldFacCount = "fac_count" // FieldCreated holds the string denoting the created field in the database. FieldCreated = "created" // FieldUpdated holds the string denoting the updated field in the database. FieldUpdated = "updated" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // EdgeCarrierFacilities holds the string denoting the carrier_facilities edge name in mutations. EdgeCarrierFacilities = "carrier_facilities" // EdgeOrganization holds the string denoting the organization edge name in mutations. EdgeOrganization = "organization" // Table holds the table name of the carrier in the database. Table = "carriers" // CarrierFacilitiesTable is the table that holds the carrier_facilities relation/edge. CarrierFacilitiesTable = "carrier_facilities" // CarrierFacilitiesInverseTable is the table name for the CarrierFacility entity. // It exists in this package in order to avoid circular dependency with the "carrierfacility" package. CarrierFacilitiesInverseTable = "carrier_facilities" // CarrierFacilitiesColumn is the table column denoting the carrier_facilities relation/edge. CarrierFacilitiesColumn = "carrier_id" // OrganizationTable is the table that holds the organization relation/edge. OrganizationTable = "carriers" // OrganizationInverseTable is the table name for the Organization entity. // It exists in this package in order to avoid circular dependency with the "organization" package. OrganizationInverseTable = "organizations" // OrganizationColumn is the table column denoting the organization relation/edge. OrganizationColumn = "org_id" )
Variables ¶
var ( // DefaultNameFold holds the default value on creation for the "name_fold" field. DefaultNameFold string // DefaultAkaFold holds the default value on creation for the "aka_fold" field. DefaultAkaFold string // DefaultAka holds the default value on creation for the "aka" field. DefaultAka string // DefaultNameLong holds the default value on creation for the "name_long" field. DefaultNameLong string // DefaultNotes holds the default value on creation for the "notes" field. DefaultNotes string // DefaultWebsite holds the default value on creation for the "website" field. DefaultWebsite string // DefaultOrgName holds the default value on creation for the "org_name" field. DefaultOrgName string // DefaultFacCount holds the default value on creation for the "fac_count" field. DefaultFacCount int // DefaultStatus holds the default value on creation for the "status" field. DefaultStatus string // IDValidator is a validator for the "id" field. It is called by the builders before save. IDValidator func(int) error )
var Columns = []string{ FieldID, FieldNameFold, FieldAkaFold, FieldOrgID, FieldAka, FieldLogo, FieldName, FieldNameLong, FieldNotes, FieldSocialMedia, FieldWebsite, FieldOrgName, FieldFacCount, FieldCreated, FieldUpdated, FieldStatus, }
Columns holds all SQL columns for carrier fields.
Functions ¶
func AkaContains ¶
AkaContains applies the Contains predicate on the "aka" field.
func AkaContainsFold ¶
AkaContainsFold applies the ContainsFold predicate on the "aka" field.
func AkaEqualFold ¶
AkaEqualFold applies the EqualFold predicate on the "aka" field.
func AkaFold ¶ added in v1.16.0
AkaFold applies equality check predicate on the "aka_fold" field. It's identical to AkaFoldEQ.
func AkaFoldContains ¶ added in v1.16.0
AkaFoldContains applies the Contains predicate on the "aka_fold" field.
func AkaFoldContainsFold ¶ added in v1.16.0
AkaFoldContainsFold applies the ContainsFold predicate on the "aka_fold" field.
func AkaFoldEqualFold ¶ added in v1.16.0
AkaFoldEqualFold applies the EqualFold predicate on the "aka_fold" field.
func AkaFoldGTE ¶ added in v1.16.0
AkaFoldGTE applies the GTE predicate on the "aka_fold" field.
func AkaFoldHasPrefix ¶ added in v1.16.0
AkaFoldHasPrefix applies the HasPrefix predicate on the "aka_fold" field.
func AkaFoldHasSuffix ¶ added in v1.16.0
AkaFoldHasSuffix applies the HasSuffix predicate on the "aka_fold" field.
func AkaFoldIsNil ¶ added in v1.16.0
AkaFoldIsNil applies the IsNil predicate on the "aka_fold" field.
func AkaFoldLTE ¶ added in v1.16.0
AkaFoldLTE applies the LTE predicate on the "aka_fold" field.
func AkaFoldNEQ ¶ added in v1.16.0
AkaFoldNEQ applies the NEQ predicate on the "aka_fold" field.
func AkaFoldNotIn ¶ added in v1.16.0
AkaFoldNotIn applies the NotIn predicate on the "aka_fold" field.
func AkaFoldNotNil ¶ added in v1.16.0
AkaFoldNotNil applies the NotNil predicate on the "aka_fold" field.
func AkaHasPrefix ¶
AkaHasPrefix applies the HasPrefix predicate on the "aka" field.
func AkaHasSuffix ¶
AkaHasSuffix applies the HasSuffix predicate on the "aka" field.
func Created ¶
Created applies equality check predicate on the "created" field. It's identical to CreatedEQ.
func CreatedGTE ¶
CreatedGTE applies the GTE predicate on the "created" field.
func CreatedLTE ¶
CreatedLTE applies the LTE predicate on the "created" field.
func CreatedNEQ ¶
CreatedNEQ applies the NEQ predicate on the "created" field.
func CreatedNotIn ¶
CreatedNotIn applies the NotIn predicate on the "created" field.
func FacCount ¶
FacCount applies equality check predicate on the "fac_count" field. It's identical to FacCountEQ.
func FacCountEQ ¶
FacCountEQ applies the EQ predicate on the "fac_count" field.
func FacCountGT ¶
FacCountGT applies the GT predicate on the "fac_count" field.
func FacCountGTE ¶
FacCountGTE applies the GTE predicate on the "fac_count" field.
func FacCountIn ¶
FacCountIn applies the In predicate on the "fac_count" field.
func FacCountIsNil ¶
FacCountIsNil applies the IsNil predicate on the "fac_count" field.
func FacCountLT ¶
FacCountLT applies the LT predicate on the "fac_count" field.
func FacCountLTE ¶
FacCountLTE applies the LTE predicate on the "fac_count" field.
func FacCountNEQ ¶
FacCountNEQ applies the NEQ predicate on the "fac_count" field.
func FacCountNotIn ¶
FacCountNotIn applies the NotIn predicate on the "fac_count" field.
func FacCountNotNil ¶
FacCountNotNil applies the NotNil predicate on the "fac_count" field.
func HasCarrierFacilities ¶
HasCarrierFacilities applies the HasEdge predicate on the "carrier_facilities" edge.
func HasCarrierFacilitiesWith ¶
func HasCarrierFacilitiesWith(preds ...predicate.CarrierFacility) predicate.Carrier
HasCarrierFacilitiesWith applies the HasEdge predicate on the "carrier_facilities" edge with a given conditions (other predicates).
func HasOrganization ¶
HasOrganization applies the HasEdge predicate on the "organization" edge.
func HasOrganizationWith ¶
func HasOrganizationWith(preds ...predicate.Organization) predicate.Carrier
HasOrganizationWith applies the HasEdge predicate on the "organization" edge with a given conditions (other predicates).
func LogoContains ¶
LogoContains applies the Contains predicate on the "logo" field.
func LogoContainsFold ¶
LogoContainsFold applies the ContainsFold predicate on the "logo" field.
func LogoEqualFold ¶
LogoEqualFold applies the EqualFold predicate on the "logo" field.
func LogoHasPrefix ¶
LogoHasPrefix applies the HasPrefix predicate on the "logo" field.
func LogoHasSuffix ¶
LogoHasSuffix applies the HasSuffix predicate on the "logo" field.
func LogoNotNil ¶
LogoNotNil applies the NotNil predicate on the "logo" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameFold ¶ added in v1.16.0
NameFold applies equality check predicate on the "name_fold" field. It's identical to NameFoldEQ.
func NameFoldContains ¶ added in v1.16.0
NameFoldContains applies the Contains predicate on the "name_fold" field.
func NameFoldContainsFold ¶ added in v1.16.0
NameFoldContainsFold applies the ContainsFold predicate on the "name_fold" field.
func NameFoldEQ ¶ added in v1.16.0
NameFoldEQ applies the EQ predicate on the "name_fold" field.
func NameFoldEqualFold ¶ added in v1.16.0
NameFoldEqualFold applies the EqualFold predicate on the "name_fold" field.
func NameFoldGT ¶ added in v1.16.0
NameFoldGT applies the GT predicate on the "name_fold" field.
func NameFoldGTE ¶ added in v1.16.0
NameFoldGTE applies the GTE predicate on the "name_fold" field.
func NameFoldHasPrefix ¶ added in v1.16.0
NameFoldHasPrefix applies the HasPrefix predicate on the "name_fold" field.
func NameFoldHasSuffix ¶ added in v1.16.0
NameFoldHasSuffix applies the HasSuffix predicate on the "name_fold" field.
func NameFoldIn ¶ added in v1.16.0
NameFoldIn applies the In predicate on the "name_fold" field.
func NameFoldIsNil ¶ added in v1.16.0
NameFoldIsNil applies the IsNil predicate on the "name_fold" field.
func NameFoldLT ¶ added in v1.16.0
NameFoldLT applies the LT predicate on the "name_fold" field.
func NameFoldLTE ¶ added in v1.16.0
NameFoldLTE applies the LTE predicate on the "name_fold" field.
func NameFoldNEQ ¶ added in v1.16.0
NameFoldNEQ applies the NEQ predicate on the "name_fold" field.
func NameFoldNotIn ¶ added in v1.16.0
NameFoldNotIn applies the NotIn predicate on the "name_fold" field.
func NameFoldNotNil ¶ added in v1.16.0
NameFoldNotNil applies the NotNil predicate on the "name_fold" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NameLong ¶
NameLong applies equality check predicate on the "name_long" field. It's identical to NameLongEQ.
func NameLongContains ¶
NameLongContains applies the Contains predicate on the "name_long" field.
func NameLongContainsFold ¶
NameLongContainsFold applies the ContainsFold predicate on the "name_long" field.
func NameLongEQ ¶
NameLongEQ applies the EQ predicate on the "name_long" field.
func NameLongEqualFold ¶
NameLongEqualFold applies the EqualFold predicate on the "name_long" field.
func NameLongGT ¶
NameLongGT applies the GT predicate on the "name_long" field.
func NameLongGTE ¶
NameLongGTE applies the GTE predicate on the "name_long" field.
func NameLongHasPrefix ¶
NameLongHasPrefix applies the HasPrefix predicate on the "name_long" field.
func NameLongHasSuffix ¶
NameLongHasSuffix applies the HasSuffix predicate on the "name_long" field.
func NameLongIn ¶
NameLongIn applies the In predicate on the "name_long" field.
func NameLongIsNil ¶
NameLongIsNil applies the IsNil predicate on the "name_long" field.
func NameLongLT ¶
NameLongLT applies the LT predicate on the "name_long" field.
func NameLongLTE ¶
NameLongLTE applies the LTE predicate on the "name_long" field.
func NameLongNEQ ¶
NameLongNEQ applies the NEQ predicate on the "name_long" field.
func NameLongNotIn ¶
NameLongNotIn applies the NotIn predicate on the "name_long" field.
func NameLongNotNil ¶
NameLongNotNil applies the NotNil predicate on the "name_long" field.
func Notes ¶
Notes applies equality check predicate on the "notes" field. It's identical to NotesEQ.
func NotesContains ¶
NotesContains applies the Contains predicate on the "notes" field.
func NotesContainsFold ¶
NotesContainsFold applies the ContainsFold predicate on the "notes" field.
func NotesEqualFold ¶
NotesEqualFold applies the EqualFold predicate on the "notes" field.
func NotesHasPrefix ¶
NotesHasPrefix applies the HasPrefix predicate on the "notes" field.
func NotesHasSuffix ¶
NotesHasSuffix applies the HasSuffix predicate on the "notes" field.
func NotesIsNil ¶
NotesIsNil applies the IsNil predicate on the "notes" field.
func NotesNotIn ¶
NotesNotIn applies the NotIn predicate on the "notes" field.
func NotesNotNil ¶
NotesNotNil applies the NotNil predicate on the "notes" field.
func OrgID ¶
OrgID applies equality check predicate on the "org_id" field. It's identical to OrgIDEQ.
func OrgIDIsNil ¶
OrgIDIsNil applies the IsNil predicate on the "org_id" field.
func OrgIDNotIn ¶
OrgIDNotIn applies the NotIn predicate on the "org_id" field.
func OrgIDNotNil ¶
OrgIDNotNil applies the NotNil predicate on the "org_id" field.
func OrgName ¶
OrgName applies equality check predicate on the "org_name" field. It's identical to OrgNameEQ.
func OrgNameContains ¶
OrgNameContains applies the Contains predicate on the "org_name" field.
func OrgNameContainsFold ¶
OrgNameContainsFold applies the ContainsFold predicate on the "org_name" field.
func OrgNameEqualFold ¶
OrgNameEqualFold applies the EqualFold predicate on the "org_name" field.
func OrgNameGTE ¶
OrgNameGTE applies the GTE predicate on the "org_name" field.
func OrgNameHasPrefix ¶
OrgNameHasPrefix applies the HasPrefix predicate on the "org_name" field.
func OrgNameHasSuffix ¶
OrgNameHasSuffix applies the HasSuffix predicate on the "org_name" field.
func OrgNameIsNil ¶
OrgNameIsNil applies the IsNil predicate on the "org_name" field.
func OrgNameLTE ¶
OrgNameLTE applies the LTE predicate on the "org_name" field.
func OrgNameNEQ ¶
OrgNameNEQ applies the NEQ predicate on the "org_name" field.
func OrgNameNotIn ¶
OrgNameNotIn applies the NotIn predicate on the "org_name" field.
func OrgNameNotNil ¶
OrgNameNotNil applies the NotNil predicate on the "org_name" field.
func SocialMediaIsNil ¶
SocialMediaIsNil applies the IsNil predicate on the "social_media" field.
func SocialMediaNotNil ¶
SocialMediaNotNil applies the NotNil predicate on the "social_media" field.
func Status ¶
Status applies equality check predicate on the "status" field. It's identical to StatusEQ.
func StatusContains ¶
StatusContains applies the Contains predicate on the "status" field.
func StatusContainsFold ¶
StatusContainsFold applies the ContainsFold predicate on the "status" field.
func StatusEqualFold ¶
StatusEqualFold applies the EqualFold predicate on the "status" field.
func StatusHasPrefix ¶
StatusHasPrefix applies the HasPrefix predicate on the "status" field.
func StatusHasSuffix ¶
StatusHasSuffix applies the HasSuffix predicate on the "status" field.
func StatusNotIn ¶
StatusNotIn applies the NotIn predicate on the "status" field.
func Updated ¶
Updated applies equality check predicate on the "updated" field. It's identical to UpdatedEQ.
func UpdatedGTE ¶
UpdatedGTE applies the GTE predicate on the "updated" field.
func UpdatedLTE ¶
UpdatedLTE applies the LTE predicate on the "updated" field.
func UpdatedNEQ ¶
UpdatedNEQ applies the NEQ predicate on the "updated" field.
func UpdatedNotIn ¶
UpdatedNotIn applies the NotIn predicate on the "updated" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func Website ¶
Website applies equality check predicate on the "website" field. It's identical to WebsiteEQ.
func WebsiteContains ¶
WebsiteContains applies the Contains predicate on the "website" field.
func WebsiteContainsFold ¶
WebsiteContainsFold applies the ContainsFold predicate on the "website" field.
func WebsiteEqualFold ¶
WebsiteEqualFold applies the EqualFold predicate on the "website" field.
func WebsiteGTE ¶
WebsiteGTE applies the GTE predicate on the "website" field.
func WebsiteHasPrefix ¶
WebsiteHasPrefix applies the HasPrefix predicate on the "website" field.
func WebsiteHasSuffix ¶
WebsiteHasSuffix applies the HasSuffix predicate on the "website" field.
func WebsiteIsNil ¶
WebsiteIsNil applies the IsNil predicate on the "website" field.
func WebsiteLTE ¶
WebsiteLTE applies the LTE predicate on the "website" field.
func WebsiteNEQ ¶
WebsiteNEQ applies the NEQ predicate on the "website" field.
func WebsiteNotIn ¶
WebsiteNotIn applies the NotIn predicate on the "website" field.
func WebsiteNotNil ¶
WebsiteNotNil applies the NotNil predicate on the "website" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Carrier queries.
func ByAka ¶
func ByAka(opts ...sql.OrderTermOption) OrderOption
ByAka orders the results by the aka field.
func ByAkaFold ¶ added in v1.16.0
func ByAkaFold(opts ...sql.OrderTermOption) OrderOption
ByAkaFold orders the results by the aka_fold field.
func ByCarrierFacilities ¶
func ByCarrierFacilities(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByCarrierFacilities orders the results by carrier_facilities terms.
func ByCarrierFacilitiesCount ¶
func ByCarrierFacilitiesCount(opts ...sql.OrderTermOption) OrderOption
ByCarrierFacilitiesCount orders the results by carrier_facilities count.
func ByCreated ¶
func ByCreated(opts ...sql.OrderTermOption) OrderOption
ByCreated orders the results by the created field.
func ByFacCount ¶
func ByFacCount(opts ...sql.OrderTermOption) OrderOption
ByFacCount orders the results by the fac_count field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByLogo ¶
func ByLogo(opts ...sql.OrderTermOption) OrderOption
ByLogo orders the results by the logo field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByNameFold ¶ added in v1.16.0
func ByNameFold(opts ...sql.OrderTermOption) OrderOption
ByNameFold orders the results by the name_fold field.
func ByNameLong ¶
func ByNameLong(opts ...sql.OrderTermOption) OrderOption
ByNameLong orders the results by the name_long field.
func ByNotes ¶
func ByNotes(opts ...sql.OrderTermOption) OrderOption
ByNotes orders the results by the notes field.
func ByOrgID ¶
func ByOrgID(opts ...sql.OrderTermOption) OrderOption
ByOrgID orders the results by the org_id field.
func ByOrgName ¶
func ByOrgName(opts ...sql.OrderTermOption) OrderOption
ByOrgName orders the results by the org_name field.
func ByOrganizationField ¶
func ByOrganizationField(field string, opts ...sql.OrderTermOption) OrderOption
ByOrganizationField orders the results by organization field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByUpdated ¶
func ByUpdated(opts ...sql.OrderTermOption) OrderOption
ByUpdated orders the results by the updated field.
func ByWebsite ¶
func ByWebsite(opts ...sql.OrderTermOption) OrderOption
ByWebsite orders the results by the website field.