Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.IxLan) predicate.IxLan
- func ArpSponge(v string) predicate.IxLan
- func ArpSpongeContains(v string) predicate.IxLan
- func ArpSpongeContainsFold(v string) predicate.IxLan
- func ArpSpongeEQ(v string) predicate.IxLan
- func ArpSpongeEqualFold(v string) predicate.IxLan
- func ArpSpongeGT(v string) predicate.IxLan
- func ArpSpongeGTE(v string) predicate.IxLan
- func ArpSpongeHasPrefix(v string) predicate.IxLan
- func ArpSpongeHasSuffix(v string) predicate.IxLan
- func ArpSpongeIn(vs ...string) predicate.IxLan
- func ArpSpongeIsNil() predicate.IxLan
- func ArpSpongeLT(v string) predicate.IxLan
- func ArpSpongeLTE(v string) predicate.IxLan
- func ArpSpongeNEQ(v string) predicate.IxLan
- func ArpSpongeNotIn(vs ...string) predicate.IxLan
- func ArpSpongeNotNil() predicate.IxLan
- func Created(v time.Time) predicate.IxLan
- func CreatedEQ(v time.Time) predicate.IxLan
- func CreatedGT(v time.Time) predicate.IxLan
- func CreatedGTE(v time.Time) predicate.IxLan
- func CreatedIn(vs ...time.Time) predicate.IxLan
- func CreatedLT(v time.Time) predicate.IxLan
- func CreatedLTE(v time.Time) predicate.IxLan
- func CreatedNEQ(v time.Time) predicate.IxLan
- func CreatedNotIn(vs ...time.Time) predicate.IxLan
- func Descr(v string) predicate.IxLan
- func DescrContains(v string) predicate.IxLan
- func DescrContainsFold(v string) predicate.IxLan
- func DescrEQ(v string) predicate.IxLan
- func DescrEqualFold(v string) predicate.IxLan
- func DescrGT(v string) predicate.IxLan
- func DescrGTE(v string) predicate.IxLan
- func DescrHasPrefix(v string) predicate.IxLan
- func DescrHasSuffix(v string) predicate.IxLan
- func DescrIn(vs ...string) predicate.IxLan
- func DescrIsNil() predicate.IxLan
- func DescrLT(v string) predicate.IxLan
- func DescrLTE(v string) predicate.IxLan
- func DescrNEQ(v string) predicate.IxLan
- func DescrNotIn(vs ...string) predicate.IxLan
- func DescrNotNil() predicate.IxLan
- func Dot1qSupport(v bool) predicate.IxLan
- func Dot1qSupportEQ(v bool) predicate.IxLan
- func Dot1qSupportNEQ(v bool) predicate.IxLan
- func HasInternetExchange() predicate.IxLan
- func HasInternetExchangeWith(preds ...predicate.InternetExchange) predicate.IxLan
- func HasIxPrefixes() predicate.IxLan
- func HasIxPrefixesWith(preds ...predicate.IxPrefix) predicate.IxLan
- func HasNetworkIxLans() predicate.IxLan
- func HasNetworkIxLansWith(preds ...predicate.NetworkIxLan) predicate.IxLan
- func ID(id int) predicate.IxLan
- func IDEQ(id int) predicate.IxLan
- func IDGT(id int) predicate.IxLan
- func IDGTE(id int) predicate.IxLan
- func IDIn(ids ...int) predicate.IxLan
- func IDLT(id int) predicate.IxLan
- func IDLTE(id int) predicate.IxLan
- func IDNEQ(id int) predicate.IxLan
- func IDNotIn(ids ...int) predicate.IxLan
- func IxID(v int) predicate.IxLan
- func IxIDEQ(v int) predicate.IxLan
- func IxIDIn(vs ...int) predicate.IxLan
- func IxIDIsNil() predicate.IxLan
- func IxIDNEQ(v int) predicate.IxLan
- func IxIDNotIn(vs ...int) predicate.IxLan
- func IxIDNotNil() predicate.IxLan
- func IxfIxpImportEnabled(v bool) predicate.IxLan
- func IxfIxpImportEnabledEQ(v bool) predicate.IxLan
- func IxfIxpImportEnabledNEQ(v bool) predicate.IxLan
- func IxfIxpMemberListURL(v string) predicate.IxLan
- func IxfIxpMemberListURLContains(v string) predicate.IxLan
- func IxfIxpMemberListURLContainsFold(v string) predicate.IxLan
- func IxfIxpMemberListURLEQ(v string) predicate.IxLan
- func IxfIxpMemberListURLEqualFold(v string) predicate.IxLan
- func IxfIxpMemberListURLGT(v string) predicate.IxLan
- func IxfIxpMemberListURLGTE(v string) predicate.IxLan
- func IxfIxpMemberListURLHasPrefix(v string) predicate.IxLan
- func IxfIxpMemberListURLHasSuffix(v string) predicate.IxLan
- func IxfIxpMemberListURLIn(vs ...string) predicate.IxLan
- func IxfIxpMemberListURLIsNil() predicate.IxLan
- func IxfIxpMemberListURLLT(v string) predicate.IxLan
- func IxfIxpMemberListURLLTE(v string) predicate.IxLan
- func IxfIxpMemberListURLNEQ(v string) predicate.IxLan
- func IxfIxpMemberListURLNotIn(vs ...string) predicate.IxLan
- func IxfIxpMemberListURLNotNil() predicate.IxLan
- func IxfIxpMemberListURLVisible(v string) predicate.IxLan
- func IxfIxpMemberListURLVisibleContains(v string) predicate.IxLan
- func IxfIxpMemberListURLVisibleContainsFold(v string) predicate.IxLan
- func IxfIxpMemberListURLVisibleEQ(v string) predicate.IxLan
- func IxfIxpMemberListURLVisibleEqualFold(v string) predicate.IxLan
- func IxfIxpMemberListURLVisibleGT(v string) predicate.IxLan
- func IxfIxpMemberListURLVisibleGTE(v string) predicate.IxLan
- func IxfIxpMemberListURLVisibleHasPrefix(v string) predicate.IxLan
- func IxfIxpMemberListURLVisibleHasSuffix(v string) predicate.IxLan
- func IxfIxpMemberListURLVisibleIn(vs ...string) predicate.IxLan
- func IxfIxpMemberListURLVisibleIsNil() predicate.IxLan
- func IxfIxpMemberListURLVisibleLT(v string) predicate.IxLan
- func IxfIxpMemberListURLVisibleLTE(v string) predicate.IxLan
- func IxfIxpMemberListURLVisibleNEQ(v string) predicate.IxLan
- func IxfIxpMemberListURLVisibleNotIn(vs ...string) predicate.IxLan
- func IxfIxpMemberListURLVisibleNotNil() predicate.IxLan
- func Mtu(v int) predicate.IxLan
- func MtuEQ(v int) predicate.IxLan
- func MtuGT(v int) predicate.IxLan
- func MtuGTE(v int) predicate.IxLan
- func MtuIn(vs ...int) predicate.IxLan
- func MtuIsNil() predicate.IxLan
- func MtuLT(v int) predicate.IxLan
- func MtuLTE(v int) predicate.IxLan
- func MtuNEQ(v int) predicate.IxLan
- func MtuNotIn(vs ...int) predicate.IxLan
- func MtuNotNil() predicate.IxLan
- func Name(v string) predicate.IxLan
- func NameContains(v string) predicate.IxLan
- func NameContainsFold(v string) predicate.IxLan
- func NameEQ(v string) predicate.IxLan
- func NameEqualFold(v string) predicate.IxLan
- func NameGT(v string) predicate.IxLan
- func NameGTE(v string) predicate.IxLan
- func NameHasPrefix(v string) predicate.IxLan
- func NameHasSuffix(v string) predicate.IxLan
- func NameIn(vs ...string) predicate.IxLan
- func NameIsNil() predicate.IxLan
- func NameLT(v string) predicate.IxLan
- func NameLTE(v string) predicate.IxLan
- func NameNEQ(v string) predicate.IxLan
- func NameNotIn(vs ...string) predicate.IxLan
- func NameNotNil() predicate.IxLan
- func Not(p predicate.IxLan) predicate.IxLan
- func Or(predicates ...predicate.IxLan) predicate.IxLan
- func RsAsn(v int) predicate.IxLan
- func RsAsnEQ(v int) predicate.IxLan
- func RsAsnGT(v int) predicate.IxLan
- func RsAsnGTE(v int) predicate.IxLan
- func RsAsnIn(vs ...int) predicate.IxLan
- func RsAsnIsNil() predicate.IxLan
- func RsAsnLT(v int) predicate.IxLan
- func RsAsnLTE(v int) predicate.IxLan
- func RsAsnNEQ(v int) predicate.IxLan
- func RsAsnNotIn(vs ...int) predicate.IxLan
- func RsAsnNotNil() predicate.IxLan
- func Status(v string) predicate.IxLan
- func StatusContains(v string) predicate.IxLan
- func StatusContainsFold(v string) predicate.IxLan
- func StatusEQ(v string) predicate.IxLan
- func StatusEqualFold(v string) predicate.IxLan
- func StatusGT(v string) predicate.IxLan
- func StatusGTE(v string) predicate.IxLan
- func StatusHasPrefix(v string) predicate.IxLan
- func StatusHasSuffix(v string) predicate.IxLan
- func StatusIn(vs ...string) predicate.IxLan
- func StatusLT(v string) predicate.IxLan
- func StatusLTE(v string) predicate.IxLan
- func StatusNEQ(v string) predicate.IxLan
- func StatusNotIn(vs ...string) predicate.IxLan
- func Updated(v time.Time) predicate.IxLan
- func UpdatedEQ(v time.Time) predicate.IxLan
- func UpdatedGT(v time.Time) predicate.IxLan
- func UpdatedGTE(v time.Time) predicate.IxLan
- func UpdatedIn(vs ...time.Time) predicate.IxLan
- func UpdatedLT(v time.Time) predicate.IxLan
- func UpdatedLTE(v time.Time) predicate.IxLan
- func UpdatedNEQ(v time.Time) predicate.IxLan
- func UpdatedNotIn(vs ...time.Time) predicate.IxLan
- func ValidColumn(column string) bool
- type OrderOption
- func ByArpSponge(opts ...sql.OrderTermOption) OrderOption
- func ByCreated(opts ...sql.OrderTermOption) OrderOption
- func ByDescr(opts ...sql.OrderTermOption) OrderOption
- func ByDot1qSupport(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByInternetExchangeField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByIxID(opts ...sql.OrderTermOption) OrderOption
- func ByIxPrefixes(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByIxPrefixesCount(opts ...sql.OrderTermOption) OrderOption
- func ByIxfIxpImportEnabled(opts ...sql.OrderTermOption) OrderOption
- func ByIxfIxpMemberListURL(opts ...sql.OrderTermOption) OrderOption
- func ByIxfIxpMemberListURLVisible(opts ...sql.OrderTermOption) OrderOption
- func ByMtu(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByNetworkIxLans(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByNetworkIxLansCount(opts ...sql.OrderTermOption) OrderOption
- func ByRsAsn(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func ByUpdated(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the ixlan type in the database. Label = "ix_lan" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldIxID holds the string denoting the ix_id field in the database. FieldIxID = "ix_id" // FieldArpSponge holds the string denoting the arp_sponge field in the database. FieldArpSponge = "arp_sponge" // FieldDescr holds the string denoting the descr field in the database. FieldDescr = "descr" // FieldDot1qSupport holds the string denoting the dot1q_support field in the database. FieldDot1qSupport = "dot1q_support" // FieldIxfIxpImportEnabled holds the string denoting the ixf_ixp_import_enabled field in the database. FieldIxfIxpImportEnabled = "ixf_ixp_import_enabled" // FieldIxfIxpMemberListURL holds the string denoting the ixf_ixp_member_list_url field in the database. FieldIxfIxpMemberListURL = "ixf_ixp_member_list_url" // FieldIxfIxpMemberListURLVisible holds the string denoting the ixf_ixp_member_list_url_visible field in the database. FieldIxfIxpMemberListURLVisible = "ixf_ixp_member_list_url_visible" // FieldMtu holds the string denoting the mtu field in the database. FieldMtu = "mtu" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldRsAsn holds the string denoting the rs_asn field in the database. FieldRsAsn = "rs_asn" // FieldCreated holds the string denoting the created field in the database. FieldCreated = "created" // FieldUpdated holds the string denoting the updated field in the database. FieldUpdated = "updated" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // EdgeInternetExchange holds the string denoting the internet_exchange edge name in mutations. EdgeInternetExchange = "internet_exchange" // EdgeIxPrefixes holds the string denoting the ix_prefixes edge name in mutations. EdgeIxPrefixes = "ix_prefixes" // EdgeNetworkIxLans holds the string denoting the network_ix_lans edge name in mutations. EdgeNetworkIxLans = "network_ix_lans" // Table holds the table name of the ixlan in the database. Table = "ix_lans" // InternetExchangeTable is the table that holds the internet_exchange relation/edge. InternetExchangeTable = "ix_lans" // InternetExchangeInverseTable is the table name for the InternetExchange entity. // It exists in this package in order to avoid circular dependency with the "internetexchange" package. InternetExchangeInverseTable = "internet_exchanges" // InternetExchangeColumn is the table column denoting the internet_exchange relation/edge. InternetExchangeColumn = "ix_id" // IxPrefixesTable is the table that holds the ix_prefixes relation/edge. IxPrefixesTable = "ix_prefixes" // IxPrefixesInverseTable is the table name for the IxPrefix entity. // It exists in this package in order to avoid circular dependency with the "ixprefix" package. IxPrefixesInverseTable = "ix_prefixes" // IxPrefixesColumn is the table column denoting the ix_prefixes relation/edge. IxPrefixesColumn = "ixlan_id" // NetworkIxLansTable is the table that holds the network_ix_lans relation/edge. NetworkIxLansTable = "network_ix_lans" // NetworkIxLansInverseTable is the table name for the NetworkIxLan entity. // It exists in this package in order to avoid circular dependency with the "networkixlan" package. NetworkIxLansInverseTable = "network_ix_lans" // NetworkIxLansColumn is the table column denoting the network_ix_lans relation/edge. NetworkIxLansColumn = "ixlan_id" )
Variables ¶
var ( // DefaultDescr holds the default value on creation for the "descr" field. DefaultDescr string // DefaultDot1qSupport holds the default value on creation for the "dot1q_support" field. DefaultDot1qSupport bool // DefaultIxfIxpImportEnabled holds the default value on creation for the "ixf_ixp_import_enabled" field. DefaultIxfIxpImportEnabled bool // DefaultIxfIxpMemberListURL holds the default value on creation for the "ixf_ixp_member_list_url" field. DefaultIxfIxpMemberListURL string // DefaultIxfIxpMemberListURLVisible holds the default value on creation for the "ixf_ixp_member_list_url_visible" field. DefaultIxfIxpMemberListURLVisible string // DefaultMtu holds the default value on creation for the "mtu" field. DefaultMtu int // DefaultName holds the default value on creation for the "name" field. DefaultName string // DefaultRsAsn holds the default value on creation for the "rs_asn" field. DefaultRsAsn int // DefaultStatus holds the default value on creation for the "status" field. DefaultStatus string // IDValidator is a validator for the "id" field. It is called by the builders before save. IDValidator func(int) error )
var Columns = []string{ FieldID, FieldIxID, FieldArpSponge, FieldDescr, FieldDot1qSupport, FieldIxfIxpImportEnabled, FieldIxfIxpMemberListURL, FieldIxfIxpMemberListURLVisible, FieldMtu, FieldName, FieldRsAsn, FieldCreated, FieldUpdated, FieldStatus, }
Columns holds all SQL columns for ixlan fields.
Functions ¶
func ArpSponge ¶
ArpSponge applies equality check predicate on the "arp_sponge" field. It's identical to ArpSpongeEQ.
func ArpSpongeContains ¶
ArpSpongeContains applies the Contains predicate on the "arp_sponge" field.
func ArpSpongeContainsFold ¶
ArpSpongeContainsFold applies the ContainsFold predicate on the "arp_sponge" field.
func ArpSpongeEQ ¶
ArpSpongeEQ applies the EQ predicate on the "arp_sponge" field.
func ArpSpongeEqualFold ¶
ArpSpongeEqualFold applies the EqualFold predicate on the "arp_sponge" field.
func ArpSpongeGT ¶
ArpSpongeGT applies the GT predicate on the "arp_sponge" field.
func ArpSpongeGTE ¶
ArpSpongeGTE applies the GTE predicate on the "arp_sponge" field.
func ArpSpongeHasPrefix ¶
ArpSpongeHasPrefix applies the HasPrefix predicate on the "arp_sponge" field.
func ArpSpongeHasSuffix ¶
ArpSpongeHasSuffix applies the HasSuffix predicate on the "arp_sponge" field.
func ArpSpongeIn ¶
ArpSpongeIn applies the In predicate on the "arp_sponge" field.
func ArpSpongeIsNil ¶
ArpSpongeIsNil applies the IsNil predicate on the "arp_sponge" field.
func ArpSpongeLT ¶
ArpSpongeLT applies the LT predicate on the "arp_sponge" field.
func ArpSpongeLTE ¶
ArpSpongeLTE applies the LTE predicate on the "arp_sponge" field.
func ArpSpongeNEQ ¶
ArpSpongeNEQ applies the NEQ predicate on the "arp_sponge" field.
func ArpSpongeNotIn ¶
ArpSpongeNotIn applies the NotIn predicate on the "arp_sponge" field.
func ArpSpongeNotNil ¶
ArpSpongeNotNil applies the NotNil predicate on the "arp_sponge" field.
func Created ¶
Created applies equality check predicate on the "created" field. It's identical to CreatedEQ.
func CreatedGTE ¶
CreatedGTE applies the GTE predicate on the "created" field.
func CreatedLTE ¶
CreatedLTE applies the LTE predicate on the "created" field.
func CreatedNEQ ¶
CreatedNEQ applies the NEQ predicate on the "created" field.
func CreatedNotIn ¶
CreatedNotIn applies the NotIn predicate on the "created" field.
func Descr ¶
Descr applies equality check predicate on the "descr" field. It's identical to DescrEQ.
func DescrContains ¶
DescrContains applies the Contains predicate on the "descr" field.
func DescrContainsFold ¶
DescrContainsFold applies the ContainsFold predicate on the "descr" field.
func DescrEqualFold ¶
DescrEqualFold applies the EqualFold predicate on the "descr" field.
func DescrHasPrefix ¶
DescrHasPrefix applies the HasPrefix predicate on the "descr" field.
func DescrHasSuffix ¶
DescrHasSuffix applies the HasSuffix predicate on the "descr" field.
func DescrIsNil ¶
DescrIsNil applies the IsNil predicate on the "descr" field.
func DescrNotIn ¶
DescrNotIn applies the NotIn predicate on the "descr" field.
func DescrNotNil ¶
DescrNotNil applies the NotNil predicate on the "descr" field.
func Dot1qSupport ¶
Dot1qSupport applies equality check predicate on the "dot1q_support" field. It's identical to Dot1qSupportEQ.
func Dot1qSupportEQ ¶
Dot1qSupportEQ applies the EQ predicate on the "dot1q_support" field.
func Dot1qSupportNEQ ¶
Dot1qSupportNEQ applies the NEQ predicate on the "dot1q_support" field.
func HasInternetExchange ¶
HasInternetExchange applies the HasEdge predicate on the "internet_exchange" edge.
func HasInternetExchangeWith ¶
func HasInternetExchangeWith(preds ...predicate.InternetExchange) predicate.IxLan
HasInternetExchangeWith applies the HasEdge predicate on the "internet_exchange" edge with a given conditions (other predicates).
func HasIxPrefixes ¶
HasIxPrefixes applies the HasEdge predicate on the "ix_prefixes" edge.
func HasIxPrefixesWith ¶
HasIxPrefixesWith applies the HasEdge predicate on the "ix_prefixes" edge with a given conditions (other predicates).
func HasNetworkIxLans ¶
HasNetworkIxLans applies the HasEdge predicate on the "network_ix_lans" edge.
func HasNetworkIxLansWith ¶
func HasNetworkIxLansWith(preds ...predicate.NetworkIxLan) predicate.IxLan
HasNetworkIxLansWith applies the HasEdge predicate on the "network_ix_lans" edge with a given conditions (other predicates).
func IxIDNotNil ¶
IxIDNotNil applies the NotNil predicate on the "ix_id" field.
func IxfIxpImportEnabled ¶
IxfIxpImportEnabled applies equality check predicate on the "ixf_ixp_import_enabled" field. It's identical to IxfIxpImportEnabledEQ.
func IxfIxpImportEnabledEQ ¶
IxfIxpImportEnabledEQ applies the EQ predicate on the "ixf_ixp_import_enabled" field.
func IxfIxpImportEnabledNEQ ¶
IxfIxpImportEnabledNEQ applies the NEQ predicate on the "ixf_ixp_import_enabled" field.
func IxfIxpMemberListURL ¶ added in v1.15.0
IxfIxpMemberListURL applies equality check predicate on the "ixf_ixp_member_list_url" field. It's identical to IxfIxpMemberListURLEQ.
func IxfIxpMemberListURLContains ¶ added in v1.15.0
IxfIxpMemberListURLContains applies the Contains predicate on the "ixf_ixp_member_list_url" field.
func IxfIxpMemberListURLContainsFold ¶ added in v1.15.0
IxfIxpMemberListURLContainsFold applies the ContainsFold predicate on the "ixf_ixp_member_list_url" field.
func IxfIxpMemberListURLEQ ¶ added in v1.15.0
IxfIxpMemberListURLEQ applies the EQ predicate on the "ixf_ixp_member_list_url" field.
func IxfIxpMemberListURLEqualFold ¶ added in v1.15.0
IxfIxpMemberListURLEqualFold applies the EqualFold predicate on the "ixf_ixp_member_list_url" field.
func IxfIxpMemberListURLGT ¶ added in v1.15.0
IxfIxpMemberListURLGT applies the GT predicate on the "ixf_ixp_member_list_url" field.
func IxfIxpMemberListURLGTE ¶ added in v1.15.0
IxfIxpMemberListURLGTE applies the GTE predicate on the "ixf_ixp_member_list_url" field.
func IxfIxpMemberListURLHasPrefix ¶ added in v1.15.0
IxfIxpMemberListURLHasPrefix applies the HasPrefix predicate on the "ixf_ixp_member_list_url" field.
func IxfIxpMemberListURLHasSuffix ¶ added in v1.15.0
IxfIxpMemberListURLHasSuffix applies the HasSuffix predicate on the "ixf_ixp_member_list_url" field.
func IxfIxpMemberListURLIn ¶ added in v1.15.0
IxfIxpMemberListURLIn applies the In predicate on the "ixf_ixp_member_list_url" field.
func IxfIxpMemberListURLIsNil ¶ added in v1.15.0
IxfIxpMemberListURLIsNil applies the IsNil predicate on the "ixf_ixp_member_list_url" field.
func IxfIxpMemberListURLLT ¶ added in v1.15.0
IxfIxpMemberListURLLT applies the LT predicate on the "ixf_ixp_member_list_url" field.
func IxfIxpMemberListURLLTE ¶ added in v1.15.0
IxfIxpMemberListURLLTE applies the LTE predicate on the "ixf_ixp_member_list_url" field.
func IxfIxpMemberListURLNEQ ¶ added in v1.15.0
IxfIxpMemberListURLNEQ applies the NEQ predicate on the "ixf_ixp_member_list_url" field.
func IxfIxpMemberListURLNotIn ¶ added in v1.15.0
IxfIxpMemberListURLNotIn applies the NotIn predicate on the "ixf_ixp_member_list_url" field.
func IxfIxpMemberListURLNotNil ¶ added in v1.15.0
IxfIxpMemberListURLNotNil applies the NotNil predicate on the "ixf_ixp_member_list_url" field.
func IxfIxpMemberListURLVisible ¶
IxfIxpMemberListURLVisible applies equality check predicate on the "ixf_ixp_member_list_url_visible" field. It's identical to IxfIxpMemberListURLVisibleEQ.
func IxfIxpMemberListURLVisibleContains ¶
IxfIxpMemberListURLVisibleContains applies the Contains predicate on the "ixf_ixp_member_list_url_visible" field.
func IxfIxpMemberListURLVisibleContainsFold ¶
IxfIxpMemberListURLVisibleContainsFold applies the ContainsFold predicate on the "ixf_ixp_member_list_url_visible" field.
func IxfIxpMemberListURLVisibleEQ ¶
IxfIxpMemberListURLVisibleEQ applies the EQ predicate on the "ixf_ixp_member_list_url_visible" field.
func IxfIxpMemberListURLVisibleEqualFold ¶
IxfIxpMemberListURLVisibleEqualFold applies the EqualFold predicate on the "ixf_ixp_member_list_url_visible" field.
func IxfIxpMemberListURLVisibleGT ¶
IxfIxpMemberListURLVisibleGT applies the GT predicate on the "ixf_ixp_member_list_url_visible" field.
func IxfIxpMemberListURLVisibleGTE ¶
IxfIxpMemberListURLVisibleGTE applies the GTE predicate on the "ixf_ixp_member_list_url_visible" field.
func IxfIxpMemberListURLVisibleHasPrefix ¶
IxfIxpMemberListURLVisibleHasPrefix applies the HasPrefix predicate on the "ixf_ixp_member_list_url_visible" field.
func IxfIxpMemberListURLVisibleHasSuffix ¶
IxfIxpMemberListURLVisibleHasSuffix applies the HasSuffix predicate on the "ixf_ixp_member_list_url_visible" field.
func IxfIxpMemberListURLVisibleIn ¶
IxfIxpMemberListURLVisibleIn applies the In predicate on the "ixf_ixp_member_list_url_visible" field.
func IxfIxpMemberListURLVisibleIsNil ¶ added in v1.4.0
IxfIxpMemberListURLVisibleIsNil applies the IsNil predicate on the "ixf_ixp_member_list_url_visible" field.
func IxfIxpMemberListURLVisibleLT ¶
IxfIxpMemberListURLVisibleLT applies the LT predicate on the "ixf_ixp_member_list_url_visible" field.
func IxfIxpMemberListURLVisibleLTE ¶
IxfIxpMemberListURLVisibleLTE applies the LTE predicate on the "ixf_ixp_member_list_url_visible" field.
func IxfIxpMemberListURLVisibleNEQ ¶
IxfIxpMemberListURLVisibleNEQ applies the NEQ predicate on the "ixf_ixp_member_list_url_visible" field.
func IxfIxpMemberListURLVisibleNotIn ¶
IxfIxpMemberListURLVisibleNotIn applies the NotIn predicate on the "ixf_ixp_member_list_url_visible" field.
func IxfIxpMemberListURLVisibleNotNil ¶ added in v1.4.0
IxfIxpMemberListURLVisibleNotNil applies the NotNil predicate on the "ixf_ixp_member_list_url_visible" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NameNotNil ¶
NameNotNil applies the NotNil predicate on the "name" field.
func RsAsn ¶
RsAsn applies equality check predicate on the "rs_asn" field. It's identical to RsAsnEQ.
func RsAsnIsNil ¶
RsAsnIsNil applies the IsNil predicate on the "rs_asn" field.
func RsAsnNotIn ¶
RsAsnNotIn applies the NotIn predicate on the "rs_asn" field.
func RsAsnNotNil ¶
RsAsnNotNil applies the NotNil predicate on the "rs_asn" field.
func Status ¶
Status applies equality check predicate on the "status" field. It's identical to StatusEQ.
func StatusContains ¶
StatusContains applies the Contains predicate on the "status" field.
func StatusContainsFold ¶
StatusContainsFold applies the ContainsFold predicate on the "status" field.
func StatusEqualFold ¶
StatusEqualFold applies the EqualFold predicate on the "status" field.
func StatusHasPrefix ¶
StatusHasPrefix applies the HasPrefix predicate on the "status" field.
func StatusHasSuffix ¶
StatusHasSuffix applies the HasSuffix predicate on the "status" field.
func StatusNotIn ¶
StatusNotIn applies the NotIn predicate on the "status" field.
func Updated ¶
Updated applies equality check predicate on the "updated" field. It's identical to UpdatedEQ.
func UpdatedGTE ¶
UpdatedGTE applies the GTE predicate on the "updated" field.
func UpdatedLTE ¶
UpdatedLTE applies the LTE predicate on the "updated" field.
func UpdatedNEQ ¶
UpdatedNEQ applies the NEQ predicate on the "updated" field.
func UpdatedNotIn ¶
UpdatedNotIn applies the NotIn predicate on the "updated" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the IxLan queries.
func ByArpSponge ¶
func ByArpSponge(opts ...sql.OrderTermOption) OrderOption
ByArpSponge orders the results by the arp_sponge field.
func ByCreated ¶
func ByCreated(opts ...sql.OrderTermOption) OrderOption
ByCreated orders the results by the created field.
func ByDescr ¶
func ByDescr(opts ...sql.OrderTermOption) OrderOption
ByDescr orders the results by the descr field.
func ByDot1qSupport ¶
func ByDot1qSupport(opts ...sql.OrderTermOption) OrderOption
ByDot1qSupport orders the results by the dot1q_support field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByInternetExchangeField ¶
func ByInternetExchangeField(field string, opts ...sql.OrderTermOption) OrderOption
ByInternetExchangeField orders the results by internet_exchange field.
func ByIxID ¶
func ByIxID(opts ...sql.OrderTermOption) OrderOption
ByIxID orders the results by the ix_id field.
func ByIxPrefixes ¶
func ByIxPrefixes(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByIxPrefixes orders the results by ix_prefixes terms.
func ByIxPrefixesCount ¶
func ByIxPrefixesCount(opts ...sql.OrderTermOption) OrderOption
ByIxPrefixesCount orders the results by ix_prefixes count.
func ByIxfIxpImportEnabled ¶
func ByIxfIxpImportEnabled(opts ...sql.OrderTermOption) OrderOption
ByIxfIxpImportEnabled orders the results by the ixf_ixp_import_enabled field.
func ByIxfIxpMemberListURL ¶ added in v1.15.0
func ByIxfIxpMemberListURL(opts ...sql.OrderTermOption) OrderOption
ByIxfIxpMemberListURL orders the results by the ixf_ixp_member_list_url field.
func ByIxfIxpMemberListURLVisible ¶
func ByIxfIxpMemberListURLVisible(opts ...sql.OrderTermOption) OrderOption
ByIxfIxpMemberListURLVisible orders the results by the ixf_ixp_member_list_url_visible field.
func ByMtu ¶
func ByMtu(opts ...sql.OrderTermOption) OrderOption
ByMtu orders the results by the mtu field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByNetworkIxLans ¶
func ByNetworkIxLans(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByNetworkIxLans orders the results by network_ix_lans terms.
func ByNetworkIxLansCount ¶
func ByNetworkIxLansCount(opts ...sql.OrderTermOption) OrderOption
ByNetworkIxLansCount orders the results by network_ix_lans count.
func ByRsAsn ¶
func ByRsAsn(opts ...sql.OrderTermOption) OrderOption
ByRsAsn orders the results by the rs_asn field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func ByUpdated ¶
func ByUpdated(opts ...sql.OrderTermOption) OrderOption
ByUpdated orders the results by the updated field.